(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    273207,       7021]
NotebookOptionsPosition[    229110,       6363]
NotebookOutlinePosition[    229508,       6379]
CellTagsIndexPosition[    229465,       6376]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}]], "Input",ExpressionUUID->"6a2415a9-3767-461c-a3d1-bd301397e620"],

Cell[CellGroupData[{

Cell["Preliminaries", "Item",
 CellChangeTimes->{{3.7995574970078573`*^9, 
  3.7995574986353*^9}},ExpressionUUID->"7405c490-1d13-4eec-8bd3-bb455794167d"],

Cell["\<\
 We allow for arbitrary \[Mu], \[Alpha], and fraction \[Rho] of rational \
consumers\
\>", "Item",
 CellChangeTimes->{{3.799732281312171*^9, 3.7997323072701797`*^9}, {
  3.8027524178067355`*^9, 
  3.802752421028407*^9}},ExpressionUUID->"6e4a96ce-9e23-4be3-90b0-\
fed99498172b"],

Cell["\<\
 Throughout, we operate with interior parameter values \[Mu], \[Alpha], \
\[Rho] \[Element] (0,1). We set \[Delta] = 1 for ease of exposition.\
\>", "Item",
 CellChangeTimes->{{3.7997323116429415`*^9, 3.7997323574237804`*^9}, {
  3.799733103192819*^9, 
  3.7997331104612875`*^9}},ExpressionUUID->"64bb3752-d78e-4974-9f1f-\
b86e0d265d27"],

Cell["\<\
Including the boundary cases is straightforward, as is behavior for c equal \
to thresholds.\
\>", "Item",
 CellChangeTimes->{{3.7997323116429415`*^9, 3.7997323640427933`*^9}, {
  3.7997331234503317`*^9, 
  3.7997331311883163`*^9}},ExpressionUUID->"ae15c27d-e77a-4f79-b775-\
9de309623cc1"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ulow", " ", "=", " ", "u"}], ";", 
  RowBox[{"uhigh", " ", "=", " ", 
   RowBox[{"u", "+", "\[CapitalDelta]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7997323803731165`*^9, 3.7997323866225123`*^9}, {
  3.8026904395218725`*^9, 
  3.802690462888689*^9}},ExpressionUUID->"9c901ce1-f37a-4219-a649-\
ac07f993361f"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Expected", " ", "Utility"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7995575144005346`*^9, 3.7995575247137733`*^9}, {
  3.8067289298102703`*^9, 
  3.8067289301405935`*^9}},ExpressionUUID->"41a54a3e-2d35-43ce-a99a-\
f095e2d046ee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exput", "=", 
  RowBox[{"ulow", "+", 
   RowBox[{"\[Mu]", 
    RowBox[{"(", 
     RowBox[{"uhigh", "-", "ulow"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.799557501379877*^9, 3.7995575106070833`*^9}, {
  3.7997323886895323`*^9, 
  3.799732394791256*^9}},ExpressionUUID->"b4383f3e-e3e8-402d-8e3d-\
d3e2b26a3873"],

Cell[BoxData[
 RowBox[{"u", "+", 
  RowBox[{"\[CapitalDelta]", " ", "\[Mu]"}]}]], "Output",
 CellChangeTimes->{
  3.799557511192576*^9, {3.7997323957626953`*^9, 3.7997324038521967`*^9}, 
   3.7997452946058273`*^9, 3.8000016823107333`*^9, {3.8026904649261365`*^9, 
   3.80269047947045*^9}, 3.8027523784290314`*^9, 3.8027524333678923`*^9, 
   3.8067289236598234`*^9, 
   3.806732332437236*^9},ExpressionUUID->"a321ed5a-f51f-42bd-8b66-\
8f51a2e3abb7"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Predicted", " ", "Expected", " ", "Utility", " ", "of", " ", "Motivated", 
   " ", "biased", " ", "Consumers"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799557531222378*^9, 3.79955754123398*^9}, {
  3.800688173604447*^9, 
  3.800688174337669*^9}},ExpressionUUID->"fab666ed-9271-4b6a-a2e9-\
893813eac33e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expmot", " ", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"\[Mu]", " ", "uhigh"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Mu]"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Alpha]", " ", "uhigh"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Alpha]"}], ")"}], "ulow"}]}], ")"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7995575444264655`*^9, 3.799557557664198*^9}, {
  3.799557591697337*^9, 3.7995575918134747`*^9}, {3.79973241310865*^9, 
  3.7997324343349433`*^9}},ExpressionUUID->"426f67df-e469-4f16-bd22-\
584a667bde74"],

Cell[BoxData[
 RowBox[{"u", "+", 
  RowBox[{"\[CapitalDelta]", " ", 
   RowBox[{"(", 
    RowBox[{"\[Alpha]", "+", "\[Mu]", "-", 
     RowBox[{"\[Alpha]", " ", "\[Mu]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.799557558968457*^9, 3.799557592261156*^9, 3.7997324562740154`*^9, 
   3.799745294837325*^9, 3.8000016826282463`*^9, {3.802690466648036*^9, 
   3.802690480732263*^9}, 3.802752378856926*^9, 3.8027524355407476`*^9, 
   3.8067289351491675`*^9, 
   3.8067323327489862`*^9},ExpressionUUID->"f9f05d52-3238-4adb-a445-\
7088b86d2369"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Predicted", " ", "Expected", " ", "Utility", " ", "of", " ", "Unmotivated",
    " ", "biased", " ", "Consumers"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7995575684105277`*^9, 3.799557569829459*^9}, {
  3.8006881759582243`*^9, 
  3.8006881766763735`*^9}},ExpressionUUID->"a05df26d-c811-4d35-bee7-\
018c1747baf2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expunmot", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"\[Mu]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Alpha]", " ", "ulow"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", "uhigh"}]}], ")"}]}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Mu]"}], ")"}], "ulow"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.799557584577143*^9, 3.79955760773062*^9}, {
  3.7997324742132473`*^9, 
  3.7997324903301754`*^9}},ExpressionUUID->"b68bde7d-d48b-4674-9644-\
0f7dda6dd8e9"],

Cell[BoxData[
 RowBox[{"u", "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", "\[CapitalDelta]", 
   " ", "\[Mu]"}]}]], "Output",
 CellChangeTimes->{
  3.79955760831653*^9, 3.7997324909006743`*^9, 3.7997452948750734`*^9, 
   3.8000016826848555`*^9, {3.8026904677557535`*^9, 3.8026904821776247`*^9}, 
   3.8027523792344875`*^9, 3.8027524370381784`*^9, 3.806728938930695*^9, 
   3.8067323330978265`*^9},ExpressionUUID->"07934fa1-cc13-467c-95c8-\
5b8c6e5634da"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"assumptions", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
    RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
    RowBox[{"u", ">", "0"}], ",", 
    RowBox[{"\[CapitalDelta]", ">", "0"}], ",", 
    RowBox[{"1", ">", "\[Rho]", ">", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.802752381782262*^9, 
  3.8027524048906717`*^9}},ExpressionUUID->"0f264897-e59f-4d6b-9a40-\
20c2ca81833c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
   RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
   RowBox[{"u", ">", "0"}], ",", 
   RowBox[{"\[CapitalDelta]", ">", "0"}], ",", 
   RowBox[{"1", ">", "\[Rho]", ">", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8027524104440727`*^9, 3.80275243831159*^9}, 
   3.8067289422909985`*^9, 
   3.806732333379118*^9},ExpressionUUID->"51685f5d-64a7-4edc-9b76-\
09024cffe76e"]
}, Open  ]],

Cell["Baseline -- Three targeting strategies", "Item",
 CellChangeTimes->{{3.7988016076380568`*^9, 3.798801612424301*^9}, {
  3.798803043702693*^9, 3.7988030447479305`*^9}, {3.7997325003731365`*^9, 
  3.7997325100162377`*^9}},ExpressionUUID->"9b3b4abd-4416-407b-a8b2-\
889f456c5feb"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Throughout", ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"q", "/", "p"}], "/", "prof"}], "/", "cw"}], " ", "denote", " ",
     "quantity"}], ",", " ", "prices", ",", " ", "profits", ",", " ", 
   RowBox[{"and", " ", "Consumer", " ", "Welfare"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997325777088594`*^9, 
  3.7997325905621576`*^9}},ExpressionUUID->"470ce5cd-e32f-4b27-9e5f-\
631654b6f3e7"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Full", "/", "Med"}], "/", "Excl"}], " ", "denote", " ", "the", 
    " ", "three", " ", "different", " ", "targeting", " ", "strategies"}], 
   ",", " ", 
   RowBox[{
   "the", " ", "interpretation", " ", "of", " ", "which", " ", "varies", " ", 
    "across", " ", "policy", " ", "settings"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997325928515344`*^9, 
  3.7997326225361233`*^9}},ExpressionUUID->"f1896b65-ee11-42ca-a3df-\
7c98638ecdbb"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Strategy", " ", "1"}], ":", " ", 
    RowBox[{"Cater", " ", "to", " ", "full", " ", "market"}]}], ",", " ", 
   RowBox[{
   "pricing", " ", "based", " ", "on", " ", "predicted", " ", "expected", " ",
     "utility", " ", "of", " ", "biased", " ", "unmotivated"}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7997325121066203`*^9, 3.799732528156344*^9}, {
  3.799732640023902*^9, 
  3.799732643009347*^9}},ExpressionUUID->"4e4b87ba-24cc-48ce-aeb3-\
82c8e035712f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qfull", "=", "1"}], ";", 
  RowBox[{"pfull", "=", "expunmot"}], ";", 
  RowBox[{"proffull", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"pfull", "-", "c"}], ")"}], "*", "qfull"}]}], ";", 
  RowBox[{"cwfull", "=", 
   RowBox[{"qfull", 
    RowBox[{"(", 
     RowBox[{"exput", "-", "pfull"}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988016276146317`*^9, 3.798801679214635*^9}, {
  3.798801733030669*^9, 3.7988017397965803`*^9}, {3.7988017767986155`*^9, 
  3.798801780219431*^9}, {3.7995567959333725`*^9, 3.799556801147259*^9}, {
  3.799557002460435*^9, 3.7995570198364563`*^9}, {3.7995576198664904`*^9, 
  3.7995576309186845`*^9}},ExpressionUUID->"d8dac42d-c8a0-4bd5-aacc-\
182a73866214"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Strategy", " ", "2"}], ":", " ", 
    RowBox[{"Intermediate", " ", "targeting"}]}], ",", " ", 
   RowBox[{
   "pricing", " ", "based", " ", "on", " ", "rational", " ", "consumers", " ",
     "and", " ", "hence", " ", "true", " ", "expected", " ", "utility"}]}], 
  " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799732534325762*^9, 
  3.79973256583134*^9}},ExpressionUUID->"7df3ec85-f965-4ae2-b4c5-\
6c572557e40f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qmed", "=", 
   RowBox[{"\[Rho]", "+", 
    RowBox[{"\[Mu]", 
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Rho]"}], ")"}]}]}]}], ";", 
  RowBox[{"pmed", "=", "exput"}], ";", 
  RowBox[{"profmed", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"pmed", "-", "c"}], ")"}], "*", "qmed"}]}], ";", 
  RowBox[{"cwmed", "=", 
   RowBox[{"qmed", 
    RowBox[{"(", 
     RowBox[{"exput", "-", "pmed"}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.798801681910467*^9, 3.7988017732840185`*^9}, {
  3.7988020770217133`*^9, 3.7988020794202943`*^9}, {3.7995568084373055`*^9, 
  3.799556827148677*^9}, {3.7995576763183317`*^9, 
  3.7995576817549114`*^9}},ExpressionUUID->"099e4df1-bbb7-40b7-8e21-\
250f3feb56a4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Strategy", " ", "3"}], ":", " ", 
     RowBox[{"Exclusive", " ", "targeting"}]}], ",", " ", 
    RowBox[{
    "pricing", " ", "based", " ", "on", " ", "predicted", " ", "expected", 
     " ", "utility", " ", "of", " ", "biased", " ", "motivated"}]}], " ", 
   "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.799732569339173*^9, 3.799732572394737*^9}, {
  3.79973262915635*^9, 
  3.799732653362239*^9}},ExpressionUUID->"12a70fb2-43df-4994-b7cd-\
989200de13b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qexcl", "=", 
   RowBox[{"\[Mu]", 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Rho]"}], ")"}]}]}], ";", 
  RowBox[{"pexcl", "=", "expmot"}], ";", 
  RowBox[{"profexcl", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"pexcl", "-", "c"}], ")"}], "*", "qexcl"}]}], ";", 
  RowBox[{"cwexcl", "=", 
   RowBox[{"qexcl", "*", 
    RowBox[{"(", 
     RowBox[{"exput", "-", "pexcl"}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.798801786253333*^9, 3.798801837643899*^9}, {
  3.799556831028976*^9, 3.7995568395202827`*^9}, {3.799557703758066*^9, 
  3.7995577098851995`*^9}},ExpressionUUID->"6a913437-5610-43bd-88b2-\
1bd790112172"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Check", " ", "that", " ", "above", " ", "characterizations", " ", "are", 
   " ", "correct"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799732658924004*^9, 
  3.7997326736061764`*^9}},ExpressionUUID->"a8eccb08-938e-4a71-9562-\
73d9eac6fb55"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"qfull", ",", "pfull", ",", "proffull", ",", "cwfull"}], "}"}], 
   ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.798802257906923*^9, 3.798802268476923*^9}, {
  3.7995576372983227`*^9, 3.7995576490037947`*^9}, {3.8027524474363146`*^9, 
  3.8027524494125786`*^9}},ExpressionUUID->"b9c2caed-7d39-4a0e-9641-\
1a3c7d4dabaf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"u", "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", "\[CapitalDelta]", 
     " ", "\[Mu]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "c"}], "+", "u", "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", "\[CapitalDelta]", 
     " ", "\[Mu]"}]}], ",", 
   RowBox[{"\[Alpha]", " ", "\[CapitalDelta]", " ", "\[Mu]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7995576493043327`*^9, 3.799732676160448*^9, 3.799745295006179*^9, 
   3.8000016828662524`*^9, {3.802690475530511*^9, 3.802690487806941*^9}, 
   3.802752450140616*^9, 3.8067290321748185`*^9, 
   3.8067323347188697`*^9},ExpressionUUID->"38aad657-f5e2-4c3c-af55-\
7de229ff5065"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"qmed", ",", "pmed", ",", "profmed", ",", "cwmed"}], "}"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.798802261110664*^9, 3.798802278243803*^9}, {
  3.799557686699483*^9, 3.799557693331645*^9}, {3.802752454011321*^9, 
  3.802752455259325*^9}},ExpressionUUID->"f8601c24-d016-4cfd-9991-\
f82053056e0f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Mu]", "+", "\[Rho]", "-", 
    RowBox[{"\[Mu]", " ", "\[Rho]"}]}], ",", 
   RowBox[{"u", "+", 
    RowBox[{"\[CapitalDelta]", " ", "\[Mu]"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "c"}], "+", "u", "+", 
      RowBox[{"\[CapitalDelta]", " ", "\[Mu]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Mu]", "+", "\[Rho]", "-", 
      RowBox[{"\[Mu]", " ", "\[Rho]"}]}], ")"}]}], ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.798802262171794*^9, 3.798802278858161*^9}, 
   3.7988025166841583`*^9, 3.798803134358277*^9, 3.7989533863822966`*^9, 
   3.7989537904605465`*^9, 3.7989637209805584`*^9, 3.7989637767142053`*^9, 
   3.7991393330671563`*^9, 3.7993778696161275`*^9, 3.799378238373389*^9, 
   3.799388752891217*^9, 3.7993889775634184`*^9, 3.799396598101678*^9, 
   3.799483087822217*^9, {3.799483685663538*^9, 3.799483715002228*^9}, 
   3.799556844009856*^9, 3.7995576940861287`*^9, 3.799732677981952*^9, 
   3.799745295037454*^9, 3.8000016828974943`*^9, 3.8026904892210217`*^9, 
   3.802752455836736*^9, 3.806729034313708*^9, 
   3.806732335039168*^9},ExpressionUUID->"3fb67d0c-c068-46cf-8428-\
8b87fae672e6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"qexcl", ",", "pexcl", ",", "profexcl", ",", "cwexcl"}], "}"}], 
   ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7988022849110417`*^9, 3.7988022903723664`*^9}, {
  3.7995577140224257`*^9, 3.7995577214574366`*^9}, {3.802752462319929*^9, 
  3.8027524634905987`*^9}},ExpressionUUID->"fbd227a8-d2e4-4541-8fcb-\
b49d13fc3737"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Mu]", "-", 
    RowBox[{"\[Mu]", " ", "\[Rho]"}]}], ",", 
   RowBox[{"u", "+", 
    RowBox[{"\[CapitalDelta]", " ", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Mu]", "-", 
       RowBox[{"\[Alpha]", " ", "\[Mu]"}]}], ")"}]}]}], ",", 
   RowBox[{"\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "c"}], "+", "u", "+", 
      RowBox[{"\[CapitalDelta]", " ", 
       RowBox[{"(", 
        RowBox[{"\[Alpha]", "+", "\[Mu]", "-", 
         RowBox[{"\[Alpha]", " ", "\[Mu]"}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Rho]"}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", "\[Alpha]"}], " ", "\[CapitalDelta]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.798802291067507*^9, 3.798802516716045*^9, 3.7988031343842077`*^9, 
   3.7989533864135447`*^9, 3.798953790491823*^9, 3.79896372099619*^9, 
   3.7989637767454877`*^9, 3.799139333094736*^9, 3.799377869638258*^9, 
   3.7993782383890142`*^9, 3.799388764119499*^9, 3.7993889775783777`*^9, 
   3.7993965981351075`*^9, 3.799483087870096*^9, {3.799483685710433*^9, 
   3.7994837150491343`*^9}, 3.7995568462532115`*^9, 3.7995577219051332`*^9, 
   3.7997326800886216`*^9, 3.799745295106449*^9, 3.8000016832244654`*^9, 
   3.8026904902586803`*^9, 3.8027524638626437`*^9, 3.806729036063672*^9, 
   3.8067323353488708`*^9},ExpressionUUID->"b54db5a1-ef89-4b76-a12a-\
79b3be94e6a8"]
}, Open  ]],

Cell[" Solution of Baseline Model", "Item",
 CellChangeTimes->{{3.7997326881293764`*^9, 
  3.7997326913400593`*^9}},ExpressionUUID->"c6af4016-272c-4e1e-b7e6-\
861eba37da2e"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Step", " ", 
   RowBox[{"A", ":", " ", 
    RowBox[{
    "Get", " ", "cost", " ", "thresholds", " ", "such", " ", "that", " ", 
     "firm", " ", "is", " ", "indifferent", " ", "between", " ", "two", " ", 
     "targeting", " ", "strategies"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997326935310974`*^9, 
  3.799732721764711*^9}},ExpressionUUID->"63eb4e3c-56d8-4b9a-b61d-\
f7d77a85e086"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"c1", ":", " ", 
    RowBox[{"between", " ", "full", " ", "and", " ", "med"}]}], ";", " ", 
   RowBox[{"c2", ":", " ", 
    RowBox[{"between", " ", "med", " ", "and", " ", "excl"}]}], ";", " ", 
   RowBox[{"c3", ":", " ", 
    RowBox[{"between", " ", "full", " ", "and", " ", "excl"}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.798801841015849*^9, 3.7988018447727933`*^9}, {
  3.7993916152542653`*^9, 3.7993917014804053`*^9}, {3.799732715910928*^9, 
  3.7997327423702955`*^9}},ExpressionUUID->"25056652-8a45-4a8e-a7ac-\
28349be60574"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"proffull", "\[Equal]", "profmed"}], ",", "c"}], "]"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.8027524879114475`*^9, 
  3.802752492341264*^9}},ExpressionUUID->"8b0d2854-4a32-46ea-8581-\
c8184744bff1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"u", "+", 
     RowBox[{"\[CapitalDelta]", " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        FractionBox["\[Alpha]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}]]}], ")"}]}]}]}], 
   "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8026905079704533`*^9, {3.802752468116377*^9, 3.8027524926941643`*^9}, 
   3.8067290394940615`*^9, 
   3.8067323361591988`*^9},ExpressionUUID->"1cdc293e-af76-4cf8-a6f3-\
01d6c58f756c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"c1", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"c", "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"proffull", "\[Equal]", "profmed"}], ",", "c"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", "assumptions"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7988018488459377`*^9, 3.7988018829889097`*^9}, {
   3.7988023587984414`*^9, 3.798802359188368*^9}, 3.8026905199216366`*^9, {
   3.8027524822745085`*^9, 
   3.8027524842001567`*^9}},ExpressionUUID->"181ff33e-82ef-4c76-90d8-\
bed61944b824"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"profmed", "\[Equal]", "profexcl"}], ",", "c"}], "]"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.802752499037119*^9, 
  3.802752502838729*^9}},ExpressionUUID->"20c2220c-912f-46db-8848-\
a043cbd9c1bd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"u", "+", 
     FractionBox[
      RowBox[{"\[CapitalDelta]", " ", "\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{"\[Rho]", "+", 
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]", "+", "\[Rho]", "-", 
            RowBox[{"\[Mu]", " ", "\[Rho]"}]}], ")"}]}]}], ")"}]}], 
      "\[Rho]"]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8026905272512445`*^9, {3.802752474884349*^9, 3.8027525035004425`*^9}, 
   3.8067290438544044`*^9, 
   3.806732336519495*^9},ExpressionUUID->"d45eb9e9-a628-4817-b9fc-\
f208c856af2a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"c2", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"c", "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"profmed", "\[Equal]", "profexcl"}], ",", "c"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", "assumptions"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7988018864942513`*^9, 3.7988019002365017`*^9}, {
   3.798802361357566*^9, 3.79880236266008*^9}, 3.80269053135345*^9, {
   3.8027525096409187`*^9, 
   3.8027525116809053`*^9}},ExpressionUUID->"37fec7e3-2963-4c36-a8a1-\
394861116a92"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"proffull", "\[Equal]", "profexcl"}], ",", "c"}], "]"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.802752514394082*^9, 
  3.8027525180944877`*^9}},ExpressionUUID->"ad5b2eb1-1f39-47db-b953-\
e207c8b53ad5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"u", "+", 
     RowBox[{"\[CapitalDelta]", " ", 
      RowBox[{"(", 
       RowBox[{"\[Mu]", "+", 
        RowBox[{"\[Alpha]", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "\[Mu]", "+", 
           FractionBox["1", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Mu]", "-", 
             RowBox[{"\[Mu]", " ", "\[Rho]"}]}]]}], ")"}]}]}], ")"}]}]}]}], 
   "}"}], "}"}]], "Output",
 CellChangeTimes->{3.8026905413524218`*^9, 3.802752518693244*^9, 
  3.8067323372992125`*^9},ExpressionUUID->"7014942e-2ee8-4893-aedc-\
b1696d5515e8"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"c3", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"c", "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"proffull", "\[Equal]", "profexcl"}], ",", "c"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", "assumptions"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798802364446306*^9, 3.798802388413209*^9}, {
  3.8027525228050594`*^9, 
  3.802752528611662*^9}},ExpressionUUID->"f9061049-d7cb-4b19-adf9-\
abe5c17d0839"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Can", " ", "be", " ", "established", " ", "that", " ", "unique", " ", 
   "cutoff", " ", "in", " ", "\[Rho]", " ", "exists", " ", "which", " ", 
   "determines", " ", "ordering", " ", "of", " ", "thresholds", " ", 
   RowBox[{"(", 
    RowBox[{"verification", " ", "below"}], ")"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997327869935465`*^9, 3.799732812607029*^9}, {
  3.799732854125965*^9, 
  3.799732855999874*^9}},ExpressionUUID->"d5fc4db5-cb5c-4c28-a4db-\
86a06e38108a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rhotilde", "=", 
  RowBox[{"\[Rho]", "/.", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"c1", "\[Equal]", "c2"}], ",", "\[Rho]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.798802594694541*^9, 3.7988026006127453`*^9}, {
   3.7995568816422567`*^9, 3.7995569024270883`*^9}, {3.799556936516564*^9, 
   3.799556937071861*^9}, {3.7995577681221123`*^9, 3.7995577682224207`*^9}, 
   3.7997328314698734`*^9},ExpressionUUID->"21089384-efc9-4d88-bc28-\
98164d0734df"],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", "+", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", "\[Mu]"}], ")"}], " ", "\[Mu]"}], "-", 
   SqrtBox[
    RowBox[{"5", "+", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "\[Mu]"}], ")"}], " ", "\[Mu]"}]}]]}], 
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], "2"]}]]], "Output",
 CellChangeTimes->{
  3.798802601285942*^9, 3.7988031345018916`*^9, 3.798953386761177*^9, 
   3.7989537905986385`*^9, 3.7989637214973783`*^9, 3.79896377684579*^9, 
   3.7991393333991528`*^9, 3.799377870086094*^9, 3.799378238504874*^9, 
   3.7993889777259827`*^9, 3.7993965984956875`*^9, 3.799483089022629*^9, {
   3.7994836859328084`*^9, 3.7994837152565527`*^9}, 3.7995568611202135`*^9, {
   3.799556895462411*^9, 3.799556902965873*^9}, 3.7995569372565002`*^9, {
   3.799557764210625*^9, 3.799557768476373*^9}, {3.7997328453348675`*^9, 
   3.799732858136312*^9}, 3.799745296294075*^9, 3.8000016845846252`*^9, 
   3.802690546426653*^9, 3.8027525327452116`*^9, 3.8067290497843027`*^9, 
   3.8067323382980547`*^9},ExpressionUUID->"6ca4bdc3-4b6b-48e4-8ec7-\
fe7f19d69066"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Check", " ", "that", " ", "rhotilde", " ", "is", " ", "interior"}],
   " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997328604411373`*^9, 
  3.7997328643511047`*^9}},ExpressionUUID->"fc51aec0-efc6-4d10-886f-\
13050d03c0eb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"1", ">", "rhotilde", ">", "0"}], ",", 
   RowBox[{"1", ">", "\[Mu]", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7995569045018773`*^9, 3.799556931573223*^9}, {
   3.7995577709147563`*^9, 3.799557772619523*^9}, 
   3.7997328314698734`*^9},ExpressionUUID->"2dcb4386-38f7-4c29-a82d-\
9ffcfa6b7090"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7995577732208214`*^9, {3.799732847361969*^9, 3.799732867615102*^9}, 
   3.799745296325347*^9, 3.8000016846314926`*^9, 3.8026905487336617`*^9, 
   3.8027525348845825`*^9, 3.8067290512746873`*^9, 
   3.8067323387584558`*^9},ExpressionUUID->"748f439f-b663-4313-a8e2-\
e1309b60b03e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Use \[Rho] relative to cutoff to obtain ordering and potential strategies\
\>", "Item",
 CellChangeTimes->{{3.799732871573194*^9, 
  3.79973288469659*^9}},ExpressionUUID->"911d2092-8d65-4d2b-9c54-\
4e91a8f194ce"],

Cell["\<\
 Case 1 : Rho large = > lots of rational consumers = > c1 < c3 < c2 \
\>", "Item",
 CellChangeTimes->{{3.7988026672085724`*^9, 3.798802698996589*^9}, {
  3.7988028175665035`*^9, 
  3.79880282137029*^9}},ExpressionUUID->"382e3174-b931-4bf7-8e56-\
ed8e489651f3"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["assumptions", "rhohigh"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Rho]", ">", "rhotilde"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8027526136040406`*^9, 
  3.8027526418906527`*^9}},ExpressionUUID->"de1bbb3d-5af2-4028-9e16-\
845df852123b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c1", "<", "c3", "<", "c2"}], ",", 
   RowBox[{"{", 
    SubscriptBox["assumptions", "rhohigh"], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7988024767210407`*^9, 3.798802484427436*^9}, {
   3.798802605046814*^9, 3.7988026292530785`*^9}, {3.799390266030838*^9, 
   3.7993902870087466`*^9}, {3.79955694574144*^9, 3.7995569473454714`*^9}, 
   3.7997328314854946`*^9, {3.799732926942707*^9, 3.799732931508727*^9}, {
   3.802690556730452*^9, 3.8026905610484223`*^9}, {3.802752545916257*^9, 
   3.80275261140816*^9}, {3.802752644603699*^9, 
   3.8027526508368635`*^9}},ExpressionUUID->"ea5b7a21-6467-407a-9bf6-\
a05c4a8fdf4b"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.79880261670763*^9, 3.798802629624155*^9}, 
   3.79880313452882*^9, 3.798953386798941*^9, 3.798953790614266*^9, 
   3.798963721582032*^9, 3.7989637768679266`*^9, 3.799139333414775*^9, 
   3.799377870117343*^9, 3.7993782385204954`*^9, 3.799388977740943*^9, {
   3.799390283051508*^9, 3.799390288137827*^9}, 3.7993965985276165`*^9, 
   3.799483089073495*^9, {3.7994836859707346`*^9, 3.7994837152964725`*^9}, {
   3.799556942185772*^9, 3.7995569479000053`*^9}, 3.7995577758123856`*^9, 
   3.7997328898310556`*^9, 3.799732932125775*^9, 3.799745296610471*^9, 
   3.8000016848320465`*^9, {3.8026905535194545`*^9, 3.8026905615673037`*^9}, {
   3.8027525844319572`*^9, 3.8027526059510574`*^9}, 3.802752651599071*^9, 
   3.806729055964476*^9, 
   3.806732339908137*^9},ExpressionUUID->"7052c0eb-e13b-419a-bb36-\
9443fae046bb"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"In", " ", "this", " ", 
     RowBox[{"case", ":", " ", 
      RowBox[{
       RowBox[{"For", " ", "c"}], " ", "<", " ", 
       RowBox[{"c1", " ", "Full", " ", "targeting"}]}]}]}], ";", " ", 
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"c1", ",", "c2"}], ")"}], " ", "Medium", " ", 
      "Targeting"}]}]}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2", " ", "Exclusive", " ", "Targeting"}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7988027022638397`*^9, 3.798802705739564*^9}, {
  3.798802785819434*^9, 3.798802811148637*^9}, {3.7993917188709383`*^9, 
  3.799391796670725*^9}, {3.7993919890097218`*^9, 3.7993919914392223`*^9}, {
  3.7993920591938624`*^9, 3.7993921095910435`*^9}, {3.7993921627832823`*^9, 
  3.7993922087426167`*^9}, {3.7993922815347204`*^9, 3.7993923090541344`*^9}, {
  3.7993925851228046`*^9, 3.799392632873086*^9}, {3.799732959066842*^9, 
  3.7997329677721214`*^9}},ExpressionUUID->"1551b1d3-d25a-4281-9b6f-\
7f8bc3109c6a"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Logic", " ", "is", " ", "identical", " ", "to", " ", "that", " ", "of", 
   " ", "Return", " ", "Policy", " ", "thresholds", " ", "in", " ", 
   "Baseline", " ", "Model", " ", "with", " ", "only", " ", "one", " ", 
   "consumer", " ", "type"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997329740744505`*^9, 3.7997329924109244`*^9}, {
  3.7997332596340866`*^9, 
  3.7997332622414455`*^9}},ExpressionUUID->"f51cc864-da4e-434c-af0c-\
8073f675af4c"],

Cell[" Case 2: Rho small => few rational consumers => c1 > c3 > c2", "Item",
 CellChangeTimes->{{3.7988028236083403`*^9, 3.798802833250518*^9}, {
  3.7988029131717787`*^9, 
  3.798802920474251*^9}},ExpressionUUID->"56e8200d-b2cb-4685-86f9-\
64aaee20fa00"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["assumptions", "rholow"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}], ",", 
     RowBox[{"0", "<", "\[Rho]", "<", "rhotilde"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.802752661690284*^9, 
  3.8027526667967434`*^9}},ExpressionUUID->"936afdc4-d514-4d76-9aee-\
764840cbac98"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c1", ">", "c3", ">", "c2"}], ",", 
   SubscriptBox["assumptions", "rholow"]}], "]"}]], "Input",
 CellChangeTimes->{{3.7988028404193754`*^9, 3.7988028494592113`*^9}, 
   3.7995569658496885`*^9, 3.799732831501116*^9, {3.7997330010495677`*^9, 
   3.7997330017676477`*^9}, {3.802690566722233*^9, 3.802690569048259*^9}, {
   3.8027526735589266`*^9, 
   3.8027526798752007`*^9}},ExpressionUUID->"7dc3201c-8971-4372-8426-\
053d9611c96e"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8027526803608212`*^9, 3.8067290627247086`*^9, 
  3.8067323403827696`*^9},ExpressionUUID->"31f954c1-c9bf-409e-9b08-\
e6f83e68bb94"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"In", " ", "this", " ", 
    RowBox[{"case", ":", " ", 
     RowBox[{"c", " ", "<", " ", 
      RowBox[{"c3", " ", "Full", " ", "Targeting"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", ">", " ", 
     RowBox[{"c3", " ", "Exclusive", " ", "Targeting"}]}], ";", " ", 
    RowBox[{"never", " ", "rational", " ", "targeting"}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.798802922785103*^9, 3.798802925020131*^9}, {
  3.798803012083324*^9, 
  3.7988030273723717`*^9}},ExpressionUUID->"b1a20859-7efa-4fc2-ab67-\
e2acabcd5458"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Overall", ":", " ", 
    RowBox[{"Can", " ", "define", " ", "ctildelow"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Min", 
     RowBox[{"{", 
      RowBox[{"c1", ",", "c3"}], "}"}], " ", "and", " ", "ctildehigh"}], " ", 
    "=", " ", 
    RowBox[{"Max", 
     RowBox[{"{", 
      RowBox[{"c2", ",", "c3"}], "}"}], " ", "to", " ", "have", " ", 
     "pricing", " ", "determined", " ", "by", " ", "these", " ", "two", " ", 
     "thresholds"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997330142366304`*^9, 
  3.799733038123391*^9}},ExpressionUUID->"1b32a5a8-5e41-49fb-a1c2-\
00a2827895b1"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.80672907018502*^9, 
  3.806729070654501*^9}},ExpressionUUID->"7fa5522d-21a4-43b7-9f10-\
d0b8dd82a3f3"],

Cell["Cooling Off: Three Candidates", "Item",
 CellChangeTimes->{{3.7988030489895535`*^9, 
  3.7988030548269844`*^9}},ExpressionUUID->"5badd8a7-863a-4521-83f6-\
87e706831304"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Same", " ", "as", " ", "before"}], ",", " ", 
   RowBox[{
   "first", " ", "define", " ", "strategies", " ", "which", " ", "carry", " ",
     "over"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799733049971574*^9, 
  3.799733060734476*^9}},ExpressionUUID->"76879b96-6c8b-489d-a12a-\
30ce983b3b45"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "co", " ", "at", " ", "end", " ", "of", " ", "variables", " ", "denotes", 
   " ", "cooling", " ", "off"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799733063343026*^9, 
  3.799733072221339*^9}},ExpressionUUID->"0bd5e45e-649a-4f72-8646-\
706613e4f195"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qfullco", "=", "1"}], ";", 
  RowBox[{"pfullco", "=", "expunmot"}], ";", 
  RowBox[{"proffullco", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"pfullco", "-", "c"}], ")"}], "*", "qfullco"}]}], ";", 
  RowBox[{"cwfullco", "=", 
   RowBox[{"qfullco", 
    RowBox[{"(", 
     RowBox[{"exput", "-", "pfullco"}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988016276146317`*^9, 3.798801679214635*^9}, {
  3.798801733030669*^9, 3.7988017397965803`*^9}, {3.7988017767986155`*^9, 
  3.798801780219431*^9}, {3.798803094013217*^9, 3.798803105139426*^9}, {
  3.799556985013983*^9, 3.7995569917171497`*^9}, {3.799557794912015*^9, 
  3.799557803819972*^9}},ExpressionUUID->"cb4d73a8-0921-4cc5-94aa-\
918903982824"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qmedco", "=", 
   RowBox[{"\[Rho]", "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Rho]"}], ")"}], 
     RowBox[{"\[Mu]", "^", "2"}]}]}]}], ";", 
  RowBox[{"pmedco", "=", "exput"}], ";", 
  RowBox[{"profmedco", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"pmedco", "-", "c"}], ")"}], "*", "qmedco"}]}], ";", 
  RowBox[{"cwmedco", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"exput", "-", "pmedco"}], ")"}], "*", "qmedco"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.798801681910467*^9, 3.7988017732840185`*^9}, {
  3.7988020770217133`*^9, 3.7988020794202943`*^9}, {3.7988030731828537`*^9, 
  3.79880307336337*^9}, {3.798803109349172*^9, 3.7988031194033117`*^9}, {
  3.7995578106400337`*^9, 
  3.799557836810591*^9}},ExpressionUUID->"912145e2-7031-4b67-9b3a-\
3e2db7ede3fc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qexclco", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Rho]"}], ")"}], 
    RowBox[{"\[Mu]", "^", "2"}]}]}], ";", 
  RowBox[{"pexclco", "=", "expmot"}], ";", 
  RowBox[{"profexclco", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"pexclco", "-", "c"}], ")"}], "*", "qexclco"}]}], ";", 
  RowBox[{"cwexclco", "=", 
   RowBox[{"qexclco", "*", 
    RowBox[{"(", 
     RowBox[{"exput", "-", "pexclco"}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.798801786253333*^9, 3.798801837643899*^9}, {
  3.798803083621934*^9, 3.798803083772601*^9}, {3.79880312209309*^9, 
  3.7988031332751846`*^9}, {3.7995578420253263`*^9, 
  3.7995578606579747`*^9}},ExpressionUUID->"c820932f-5d89-4342-9e17-\
53371b9eeae1"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Check", " ", "that", " ", "above", " ", "characterizations", " ", "are", 
   " ", "correct"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7988031463671384`*^9, 3.7988031487568045`*^9}, {
  3.799733082934278*^9, 
  3.7997330970384316`*^9}},ExpressionUUID->"ffff0042-80b9-4ddb-986b-\
3a01ae82d65b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"qfullco", ",", "pfullco", ",", "proffullco", ",", "cwfullco"}], 
    "}"}], ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.798803149597521*^9, 3.7988031604365377`*^9}, {
  3.7995578731072407`*^9, 3.799557881197648*^9}, {3.8027526877571983`*^9, 
  3.8027526899301877`*^9}},ExpressionUUID->"b5f36179-d2de-42a5-96ae-\
d13632886719"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"u", "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", "\[CapitalDelta]", 
     " ", "\[Mu]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "c"}], "+", "u", "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", "\[CapitalDelta]", 
     " ", "\[Mu]"}]}], ",", 
   RowBox[{"\[Alpha]", " ", "\[CapitalDelta]", " ", "\[Mu]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7988031611087475`*^9, 3.798953387030772*^9, 3.7989537908149796`*^9, 
   3.7989637218531365`*^9, 3.7989637770840483`*^9, 3.799139333631153*^9, 
   3.799377870440207*^9, 3.7993782387522264`*^9, 3.7993889779344254`*^9, 
   3.799396598807926*^9, 3.7994830895714626`*^9, {3.7994836863407445`*^9, 
   3.7994837156465464`*^9}, 3.7995578817307386`*^9, 3.7997331365877256`*^9, 
   3.799745297227679*^9, 3.800001685148472*^9, 3.802690579682206*^9, 
   3.8027526902713957`*^9, 3.806729080476882*^9, 
   3.8067323406572185`*^9},ExpressionUUID->"3e0400a8-3c29-4485-8cb7-\
720f401f0485"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"qmedco", ",", "pmedco", ",", "profmedco", ",", "cwmedco"}], 
    "}"}], ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.799557892574461*^9, 3.7995578999466515`*^9}, {
  3.8027526920590553`*^9, 
  3.8027526931447916`*^9}},ExpressionUUID->"04e499b6-1cb5-4285-a810-\
728680d68183"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["\[Mu]", "2"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}], "+", "\[Rho]"}], ",", 
   RowBox[{"u", "+", 
    RowBox[{"\[CapitalDelta]", " ", "\[Mu]"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "c"}], "+", "u", "+", 
      RowBox[{"\[CapitalDelta]", " ", "\[Mu]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Mu]", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}], "+", "\[Rho]"}], 
     ")"}]}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.799557900447456*^9, 3.7997331383923397`*^9, 
  3.7997452972433023`*^9, 3.800001685170596*^9, 3.802690581465331*^9, 
  3.8027526934713974`*^9, 3.8067290822771873`*^9, 
  3.8067323408580227`*^9},ExpressionUUID->"81544420-9924-43c5-a4cf-\
8c44cd01a8e0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"qexclco", ",", "pexclco", ",", "profexclco", ",", "cwexclco"}], 
    "}"}], ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7995579217203126`*^9, 3.7995579276371202`*^9}, {
  3.802752695749363*^9, 
  3.8027526968024807`*^9}},ExpressionUUID->"be9b2d71-c986-484e-8633-\
1e99cbc74118"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["\[Mu]", "2"]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}], ",", 
   RowBox[{"u", "+", 
    RowBox[{"\[CapitalDelta]", " ", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Mu]", "-", 
       RowBox[{"\[Alpha]", " ", "\[Mu]"}]}], ")"}]}]}], ",", 
   RowBox[{
    SuperscriptBox["\[Mu]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "c"}], "+", "u", "+", 
      RowBox[{"\[CapitalDelta]", " ", 
       RowBox[{"(", 
        RowBox[{"\[Alpha]", "+", "\[Mu]", "-", 
         RowBox[{"\[Alpha]", " ", "\[Mu]"}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Rho]"}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", "\[Alpha]"}], " ", "\[CapitalDelta]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
    SuperscriptBox["\[Mu]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.79955792815429*^9, 3.799733140244912*^9, 
  3.799745297281107*^9, 3.800001685201913*^9, 3.8026905829443026`*^9, 
  3.8027526971270185`*^9, 3.8067290845169525`*^9, 
  3.806732341052263*^9},ExpressionUUID->"403336f9-9aad-4984-89a8-\
fb59e9f3c31c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Get", " ", "cutoffs", " ", "as", " ", "before"}], ";", " ", 
   RowBox[{
   "co", " ", "at", " ", "end", " ", "of", " ", "variable", " ", "denotes", 
    " ", "cooling", " ", "off"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.79880316893678*^9, 3.798803172180099*^9}, {
  3.799733142704712*^9, 
  3.7997331611184907`*^9}},ExpressionUUID->"e70a6a5f-2189-443b-89a2-\
a21afad060bf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"proffullco", "\[Equal]", "profmedco"}], ",", "c"}], "]"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.802690590969623*^9, 3.8026905973930616`*^9}, {
  3.8027526996219206`*^9, 
  3.8027527037685013`*^9}},ExpressionUUID->"2cbfacea-e0fe-4b1e-899c-\
56842bab3d6e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"u", "+", 
     RowBox[{"\[CapitalDelta]", " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        FractionBox["\[Alpha]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}]]}], ")"}]}]}]}], 
   "}"}], "}"}]], "Output",
 CellChangeTimes->{3.8026905976973667`*^9, 3.8027527044690266`*^9, 
  3.8067290880861073`*^9, 
  3.806732341647792*^9},ExpressionUUID->"c2e458ab-140a-43db-b106-\
82102800062f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"c1co", " ", "=", " ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"c", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"proffullco", "\[Equal]", "profmedco"}], ",", "c"}], "]"}], 
      "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.798803173597308*^9, 3.7988031913967085`*^9}, 
   3.802690599890087*^9},ExpressionUUID->"95a02e93-68b9-4b25-b026-\
98ada59743ea"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"profmedco", "\[Equal]", "profexclco"}], ",", "c"}], "]"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.802690604553548*^9, 3.802690609385236*^9}, {
  3.80275271029601*^9, 
  3.8027527181171956`*^9}},ExpressionUUID->"8e38b163-245b-4b7d-9b7f-\
cda313ea6e2a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"u", "+", 
     FractionBox[
      RowBox[{"\[CapitalDelta]", " ", "\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{"\[Rho]", "+", 
         RowBox[{"\[Alpha]", " ", "\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]", "+", "\[Rho]", "-", 
            RowBox[{"\[Mu]", " ", "\[Rho]"}]}], ")"}]}]}], ")"}]}], 
      "\[Rho]"]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.802690609736965*^9, 3.802752718656454*^9, 
  3.806729091727764*^9, 
  3.8067323419483557`*^9},ExpressionUUID->"010f686d-31d4-4b8b-8cdf-\
d970a9e89fdd"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"c2co", " ", "=", " ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"c", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"profmedco", "\[Equal]", "profexclco"}], ",", "c"}], "]"}], 
      "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988031943669257`*^9, 3.7988032160757065`*^9}, 
   3.80269061364944*^9},ExpressionUUID->"d2258e74-d9b6-462c-838b-\
e3716a5ea626"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"proffullco", "\[Equal]", "profexclco"}], ",", "c"}], "]"}], ",",
    "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.802690615466248*^9, 3.802690621384492*^9}, {
  3.8027527254224615`*^9, 
  3.802752728885107*^9}},ExpressionUUID->"8c2c439e-ac41-4f07-b612-\
0d1db9560130"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"u", "+", 
     RowBox[{"\[CapitalDelta]", " ", 
      RowBox[{"(", 
       RowBox[{"\[Alpha]", "+", "\[Mu]", "-", 
        RowBox[{"\[Alpha]", " ", "\[Mu]"}], "-", 
        FractionBox["\[Alpha]", 
         RowBox[{"1", "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}]}]]}], ")"}]}]}]}], 
   "}"}], "}"}]], "Output",
 CellChangeTimes->{3.802690621808536*^9, 3.8027527297782803`*^9, 
  3.806729095256222*^9, 
  3.8067323426080437`*^9},ExpressionUUID->"812a98e7-64c7-43b7-96a2-\
82d0fe42bfb0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"c3co", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"c", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"proffullco", "\[Equal]", "profexclco"}], ",", "c"}], "]"}], 
      "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7988032195025826`*^9, 3.7988032292834234`*^9}, 
   3.8026906238882914`*^9},ExpressionUUID->"1a9da96d-0356-4663-a938-\
5db5db6cb14d"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Determined", " ", "\[Rho]", " ", "threshold", " ", "which", " ", 
   "determines", " ", "ordering"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997331791226892`*^9, 
  3.799733190411435*^9}},ExpressionUUID->"1a94108a-e7b5-4c27-9cf7-\
0795e0ff6465"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rhotildeco", "=", 
  RowBox[{"\[Rho]", "/.", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"c1co", "\[Equal]", "c2co"}], ",", "\[Rho]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.79880329636618*^9, 3.798803307059558*^9}, {
   3.7988033580451593`*^9, 3.7988033650514235`*^9}, {3.799557956162197*^9, 
   3.7995579611695623`*^9}, 
   3.799732831523247*^9},ExpressionUUID->"69d711fc-9c40-45dd-b1f3-\
ed5eda87c430"],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "+", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], "2"], " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "\[Mu]"}], ")"}]}], "-", 
   SqrtBox[
    RowBox[{"1", "+", 
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], "2"], " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "\[Mu]"}], ")"}]}]}]]}], 
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], "2"], " ", "\[Mu]", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "\[Mu]"}], ")"}]}]]], "Output",
 CellChangeTimes->{
  3.798803365813384*^9, 3.79895338738512*^9, 3.7989537909153795`*^9, 
   3.7989637222541804`*^9, 3.79896377718433*^9, 3.799139333916506*^9, 
   3.7993778708567886`*^9, 3.7993782388746023`*^9, 3.7993889781348896`*^9, 
   3.799396599086256*^9, 3.799483090201279*^9, {3.799483686519268*^9, 
   3.7994837158151007`*^9}, 3.7995579618083076`*^9, 3.7997331930967684`*^9, 
   3.7997452983618717`*^9, 3.800001686173379*^9, 3.8026906271201925`*^9, 
   3.802752736593669*^9, 3.8067290994163537`*^9, 
   3.806732343138136*^9},ExpressionUUID->"60eaed8d-e043-46a9-b756-\
c1dd90b8d2db"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Check", " ", "that", " ", "threshold", " ", "is", " ", "interior"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7997331957723956`*^9, 
  3.7997332015894127`*^9}},ExpressionUUID->"bdcb36b2-3c0e-4f2d-9713-\
0dad3a78dd61"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"1", ">", "rhotildeco", ">", "0"}], ",", 
   RowBox[{"1", ">", "\[Mu]", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7995579708332205`*^9, 3.7995579711023006`*^9}, 
   3.799732831523247*^9},ExpressionUUID->"1dcc1f65-f400-44c1-98d4-\
b0bc5d1a4afe"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.79955797170378*^9, 3.7997332038642836`*^9, 
  3.7997452985845776`*^9, 3.800001686389696*^9, 3.802690629941965*^9, 
  3.8027527403828173`*^9, 3.8067291013760557`*^9, 
  3.806732343469486*^9},ExpressionUUID->"7600c097-01e9-4484-911c-\
db471b1de402"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["assumptions", "rhohighco"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Rho]", ">", "rhotildeco"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8027527416273274`*^9, 
  3.8027527588516865`*^9}},ExpressionUUID->"0600f997-9171-48ab-bd0e-\
7f3aa8fa5b3a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["assumptions", "rholowco"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}], ",", 
     RowBox[{"0", "<", "\[Rho]", "<", "rhotildeco"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8027527608927374`*^9, 
  3.8027527841855965`*^9}},ExpressionUUID->"c476df4c-c0f1-4d1a-bc8e-\
c41de6fffeaa"],

Cell["\<\
Case 1: Rho large = > lots of rational consumers = > c1co < c3co < c2co\
\>", "Item",
 CellChangeTimes->{{3.7988033812909927`*^9, 3.7988033969633512`*^9}, {
  3.7988034636021757`*^9, 3.7988034675865593`*^9}, {3.79939334607812*^9, 
  3.799393346079115*^9}},ExpressionUUID->"9e1c9251-18f7-4f74-b4c0-\
93f93c305d3b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c1co", "<", "c3co", "<", "c2co"}], ",", 
   SubscriptBox["assumptions", "rhohighco"]}], "]"}]], "Input",
 CellChangeTimes->{{3.799393280820256*^9, 3.799393289910965*^9}, 
   3.7993966147167706`*^9, {3.7995579792857637`*^9, 3.799557981822715*^9}, 
   3.7997328315388737`*^9, {3.7997332086090517`*^9, 3.799733209465255*^9}, 
   3.8026906359294596`*^9, {3.802752792554162*^9, 
   3.8027527990065956`*^9}},ExpressionUUID->"6e261341-809f-4522-a8ca-\
eb835e43ecd8"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7988034087817855`*^9, 3.798953387400774*^9, 3.798953790939785*^9, 
   3.7989637222854233`*^9, 3.798963777215644*^9, 3.7991393339320555`*^9, 
   3.7993778708880315`*^9, 3.7993782388902273`*^9, 3.7993889781508465`*^9, 
   3.7993932923434243`*^9, {3.79939659937061*^9, 3.799396628970107*^9}, 
   3.799396692632557*^9, 3.7994830902501483`*^9, {3.799483686598112*^9, 
   3.7994837158509893`*^9}, {3.7995579756447897`*^9, 3.7995579823462505`*^9}, 
   3.79973321006667*^9, 3.7997452987851105`*^9, 3.800001686605795*^9, {
   3.8026906334334445`*^9, 3.8026906365665607`*^9}, 3.802752800551221*^9, 
   3.806729110856851*^9, 
   3.8067323440321293`*^9},ExpressionUUID->"379f34f4-1478-42bc-b4ec-\
20697ae642d5"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"In", " ", "this", " ", 
     RowBox[{"case", ":", " ", 
      RowBox[{
       RowBox[{"For", " ", "c"}], " ", "<", " ", 
       RowBox[{"c1co", " ", "Full", " ", "targeting"}]}]}]}], ";", " ", 
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"c1co", ",", "c2co"}], ")"}], " ", "Medium", " ", 
      "Targeting"}]}]}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2co", " ", "Exclusive", " ", "Targeting"}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7988034399873667`*^9, 3.798803446315445*^9}, {
   3.7993912982318306`*^9, 3.799391417158266*^9}, {3.7993934866242733`*^9, 
   3.7993935052385*^9}, 3.799393746311534*^9, {3.7993939200617456`*^9, 
   3.7993939522742386`*^9}, {3.7993940834245253`*^9, 
   3.7993941014393325`*^9}, {3.799394170426775*^9, 3.799394210294524*^9}, {
   3.799394618195222*^9, 3.7993947393348846`*^9}, 3.7993952152335215`*^9, {
   3.799395326053032*^9, 3.7993953656072865`*^9}, {3.7993954024381933`*^9, 
   3.7993954650634737`*^9}, {3.7993955043944435`*^9, 
   3.7993955191260242`*^9}, {3.799395606336919*^9, 3.799395647821667*^9}, {
   3.7993956831444187`*^9, 3.799395692734391*^9}, {3.799733217317257*^9, 
   3.7997332189217496`*^9}},ExpressionUUID->"d42f8d21-7344-4ad3-81a9-\
5b440513b905"],

Cell["\<\
 Case 2: Rho small => few rational consumers => c1co > c3co > c2co\
\>", "Item",
 CellChangeTimes->{{3.798803454475623*^9, 
  3.7988034614419527`*^9}},ExpressionUUID->"077bfdff-6351-40cb-9143-\
1d29b43f740a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c1co", ">", "c3co", ">", "c2co"}], ",", 
   SubscriptBox["assumptions", "rholowco"]}], "]"}]], "Input",
 CellChangeTimes->{{3.7988034733551335`*^9, 3.7988034807154455`*^9}, 
   3.799558002184067*^9, 3.7997328315544963`*^9, {3.7997332253389473`*^9, 
   3.7997332262441783`*^9}, 3.802690640545877*^9, {3.802752808406152*^9, 
   3.8027528130390406`*^9}},ExpressionUUID->"f6774197-c53d-480f-9c4b-\
e7ae29fc2dc3"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7988034809148755`*^9, 3.7989533874632344`*^9, 3.798953791015297*^9, 
   3.798963722370043*^9, 3.7989637773003335`*^9, 3.7991393340167446`*^9, 
   3.7993778710039015`*^9, 3.799378238974845*^9, 3.799388978211684*^9, 
   3.7993965994728537`*^9, 3.799483090415945*^9, {3.7994836867057695`*^9, 
   3.799483716008557*^9}, {3.7995579995764885`*^9, 3.799558002600895*^9}, 
   3.7997332268986015`*^9, 3.7997452990859313`*^9, 3.8000016868375874`*^9, {
   3.802690638965497*^9, 3.802690640970088*^9}, 3.802752813682136*^9, 
   3.806729112586702*^9, 
   3.806732344749287*^9},ExpressionUUID->"ccf9fbb8-1b6c-4a42-8818-\
584cfbbdfce0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"In", " ", "this", " ", 
    RowBox[{"case", ":", " ", 
     RowBox[{"c", " ", "<", " ", 
      RowBox[{"c3co", " ", "Full", " ", "Targeting"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", ">", " ", 
     RowBox[{"c3co", " ", "Exclusive", " ", "Targeting"}]}], ";", " ", 
    RowBox[{"never", " ", "rational", " ", "targeting"}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.798803505234871*^9, 
  3.7988035082109118`*^9}},ExpressionUUID->"2c04ad27-d846-4f07-85bf-\
2b82d1fa36e4"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Analysis", " ", "follows", " ", "RP", " ", "in", " ", "Baseline", " ", 
   "Model", " ", "with", " ", "only", " ", "one", " ", "consumer", " ", 
   "type"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799733234703757*^9, 
  3.799733253458144*^9}},ExpressionUUID->"e8627278-3b73-4a8a-b694-\
695f48a58a10"],

Cell[" Impact of CO", "Item",
 CellChangeTimes->{{3.7988035128256044`*^9, 
  3.7988035163062286`*^9}},ExpressionUUID->"5594ba39-5f53-4ff3-a93d-\
bdc6d8102bc4"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "First", " ", "establish", " ", "relative", " ", "ordering", " ", "of", " ",
    "rho", " ", "cutoffs"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997332698460126`*^9, 
  3.799733280891925*^9}},ExpressionUUID->"9bcae843-8104-4b33-9da5-\
c3244fecb26c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Reduce", "[", 
    RowBox[{"rhotilde", ">", "rhotildeco"}], "]"}], ",", 
   RowBox[{"1", ">", "\[Mu]", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.798803527911128*^9, 3.798803536706645*^9}, {
  3.799558017426149*^9, 3.7995580206676993`*^9}, {3.799732831585739*^9, 
  3.7997328316013603`*^9}, {3.802752822276368*^9, 
  3.8027528320254536`*^9}},ExpressionUUID->"8d5e2ef0-d4c3-439b-b8f7-\
dbd792e9faea"],

Cell[BoxData[
 RowBox[{
  RowBox[{"1", "+", 
   RowBox[{"2", " ", "\[Mu]"}]}], "<", 
  SqrtBox["5"]}]], "Output",
 CellChangeTimes->{{3.7988035339929*^9, 3.798803537234231*^9}, 
   3.7989533875323267`*^9, 3.7989537910999107`*^9, 3.7989637224702835`*^9, 
   3.7989637773693085`*^9, 3.79913933408578*^9, 3.799377871104158*^9, 
   3.799378239052958*^9, 3.7993889782765107`*^9, 3.79939659960815*^9, 
   3.7994830906253843`*^9, {3.7994836868344264`*^9, 3.7994837161332307`*^9}, {
   3.799558014580969*^9, 3.7995580218906403`*^9}, 3.799745299823692*^9, 
   3.8000016874549675`*^9, 3.802690643878846*^9, {3.802752817466115*^9, 
   3.802752833173789*^9}, 3.806729123428557*^9, 
   3.806732345319316*^9},ExpressionUUID->"c7bfa451-993c-4d30-80d5-\
6d5db9efe3f1"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Ordering", " ", "is", " ", "ambiguous", " ", "and", " ", "depends", " ", 
   "on", " ", "fraction", " ", "of", " ", "motivated", " ", "consumers", " ", 
   "in", " ", "a", " ", "given", " ", "period"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799733283837834*^9, 
  3.799733296504754*^9}},ExpressionUUID->"e6f16eb6-92cd-4cb4-be86-\
3698c995cd10"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "Characterize", " ", "this", " ", "cutoffmu", " ", "so", " ", "that", " ", 
    "rhotilde"}], " ", ">", " ", 
   RowBox[{"rhotildeco", " ", "iff", " ", "\[Mu]"}], " ", "<", " ", 
   "cutoffmu"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997332985254593`*^9, 
  3.799733332741846*^9}},ExpressionUUID->"3a8a2582-99e8-46e5-8ac1-\
bdef4e2076c0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cutoffmu", "=", 
  RowBox[{"\[Mu]", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"rhotilde", "\[Equal]", "rhotildeco"}], ",", "\[Mu]"}], "]"}], 
    "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.799558153514103*^9, 3.7995581834772663`*^9}, {
  3.7997328316169806`*^9, 
  3.7997328316169806`*^9}},ExpressionUUID->"0cdcc241-8b26-47de-aee2-\
0254a8a3f85d"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    SqrtBox["5"]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.79955816798885*^9, 3.799558183962861*^9}, 
   3.799733334770071*^9, 3.7997453001293373`*^9, 3.8000016876777864`*^9, 
   3.802690651345001*^9, 3.8027528439464755`*^9, 3.8067291257273464`*^9, 
   3.8067323457893534`*^9},ExpressionUUID->"0aaf3387-3131-4d77-a275-\
16b53f59e1b0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Check", " ", "that", " ", "cutoffmu", " ", "is", " ", "interior"}],
   " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8067291311178255`*^9, 
  3.8067291379443817`*^9}},ExpressionUUID->"29b983b4-b905-45b3-9281-\
8574417b2469"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"1", ">", "cutoffmu", ">", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.799558185914744*^9, 
  3.7995581924534245`*^9}},ExpressionUUID->"92a315d8-f84b-416d-92d9-\
4531b5410f75"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.7995581928700123`*^9, 3.7997333373714705`*^9, 
  3.7997453001827393`*^9, 3.800001687878437*^9, 3.8026906536235*^9, 
  3.8027528462013063`*^9, 3.8067291281873875`*^9, 
  3.8067323460091257`*^9},ExpressionUUID->"1132fc93-e481-4b93-9c25-\
619262cf65b6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"rhotilde", ">", "rhotildeco"}], ",", 
     RowBox[{"0", "<", "\[Mu]", "<", "cutoffmu"}]}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"rhotilde", "<", "rhotildeco"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "cutoffmu"}]}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.7995581992503047`*^9, 3.799558220647253*^9}, {
  3.7997328316234875`*^9, 3.7997328316234875`*^9}, {3.79973334566165*^9, 
  3.799733359297506*^9}},ExpressionUUID->"b3a89059-6cee-44d1-8524-\
8e3c486a2055"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.7995582103197947`*^9, 3.7995582210325828`*^9}, {
   3.799733341350396*^9, 3.7997333599368935`*^9}, 3.7997453004299326`*^9, 
   3.80000168807912*^9, 3.8026906563337946`*^9, 3.802752848270262*^9, 
   3.806729141962942*^9, 
   3.806732346219133*^9},ExpressionUUID->"a8ad9cf1-facb-4414-8cfc-\
90638ec546bc"]
}, Open  ]],

Cell["\<\
Towards assessing the impact: First get generic comparisons given targeting \
behavior pre & post policy introduction\
\>", "Item",
 CellChangeTimes->{{3.7994835774557905`*^9, 3.799483581194724*^9}, {
  3.7997333676207633`*^9, 
  3.7997333865256653`*^9}},ExpressionUUID->"cbc52bfd-7df4-4860-914f-\
6894d8394fac"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{" ", "1.", ")"}], " ", "Cooling", " ", "Off"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7994835839667673`*^9, 
  3.799483596189886*^9}},ExpressionUUID->"7d6893c2-17a7-4a6e-b12e-\
49c18f204787"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"A", ":", " ", 
   RowBox[{"Full", " ", "to", " ", "Full"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799483598167594*^9, 3.7994836023244405`*^9}, {
  3.799483722505161*^9, 
  3.7994837235334153`*^9}},ExpressionUUID->"f35fe078-ce56-434d-9df0-\
b5886e0e3d61"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"qfullco", "-", "qfull"}], "==", "0"}], ",", 
     RowBox[{
      RowBox[{"pfullco", "-", "pfull"}], "==", "0"}], ",", 
     RowBox[{
      RowBox[{"cwfullco", "-", "cwfull"}], "==", "0"}]}], "}"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7994836039451036`*^9, 3.7994837135481186`*^9}, {
  3.7995591699841676`*^9, 3.7995591714050097`*^9}, {3.802752855973654*^9, 
  3.802752857065971*^9}},ExpressionUUID->"bfb8440f-f35f-49c2-9886-\
095a3a49f3ef"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.7994836494160156`*^9, 3.7994837191710587`*^9}, {
   3.799559165705161*^9, 3.7995591743974648`*^9}, 3.799745300498968*^9, 
   3.8000016881260576`*^9, {3.802690658785447*^9, 3.8026906608803425`*^9}, 
   3.8027528573933115`*^9, 3.806729146341711*^9, 
   3.806732346837901*^9},ExpressionUUID->"926a898e-c84d-4c69-a883-\
aedd460e384d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"B", ":", " ", 
   RowBox[{"Full", " ", "to", " ", "Med"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799483727905716*^9, 
  3.799483730438927*^9}},ExpressionUUID->"0e587610-bb34-4d58-abbe-\
fe93dffb605b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"qmedco", "-", "qfull"}], "<", "0"}], ",", 
     RowBox[{
      RowBox[{"pmedco", "-", "pfull"}], ">", "0"}], ",", 
     RowBox[{
      RowBox[{"cwmedco", "-", "cwfull"}], "<", "0"}]}], "}"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.799483736482733*^9, 3.7994837685481744`*^9}, 
   3.7995591780549006`*^9, 3.8026906683134356`*^9, {3.8027528652677565`*^9, 
   3.802752866280801*^9}},ExpressionUUID->"a377e6a3-b3fb-4d52-b726-\
c02375bf7fd8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.7994837488808064`*^9, 3.7994837691356015`*^9}, {
   3.7995591761175957`*^9, 3.79955917845572*^9}, 3.7997453005457954`*^9, 
   3.800001688157231*^9, {3.8026906648160396`*^9, 3.802690668680725*^9}, 
   3.802752866622356*^9, 3.8067291478218184`*^9, 
   3.8067323470578623`*^9},ExpressionUUID->"8a3ed59a-b772-442c-bdc8-\
d2738500a163"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"C", ":", " ", 
   RowBox[{"Full", " ", "to", " ", "Excl"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799483774722682*^9, 
  3.799483794443741*^9}},ExpressionUUID->"002105cc-82fc-4fc4-853c-\
4a936952a4b0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"qexclco", "-", "qfull"}], "<", "0"}], ",", 
     RowBox[{
      RowBox[{"pexclco", "-", "pfull"}], ">", "0"}], ",", 
     RowBox[{
      RowBox[{"cwexclco", "-", "cwfull"}], "<", "0"}]}], "}"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7994837809220605`*^9, 3.7994837901412477`*^9}, 
   3.7995591808311014`*^9, 3.802690672241918*^9, {3.8027528726819563`*^9, 
   3.8027528737200456`*^9}},ExpressionUUID->"5946f446-cd82-423b-831a-\
442b9c11eba0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.799483791084699*^9, 3.799559181247579*^9, 3.7997453005835705`*^9, 
   3.8000016881949835`*^9, {3.802690670457896*^9, 3.802690672476059*^9}, 
   3.80275287405669*^9, 3.8067291494719763`*^9, 
   3.8067323475279293`*^9},ExpressionUUID->"3d15a109-ae23-4ed6-b6dc-\
ff73208351e3"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"D", ":", " ", 
   RowBox[{"Med", " ", "to", " ", "Full"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799483799284389*^9, 
  3.799483802100854*^9}},ExpressionUUID->"47812704-9240-4c6c-8555-\
5918028e87fe"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"qfullco", "-", "qmed"}], ">", "0"}], ",", 
     RowBox[{
      RowBox[{"pfullco", "-", "pmed"}], "<", "0"}], ",", 
     RowBox[{
      RowBox[{"cwfullco", "-", "cwmed"}], ">", "0"}]}], "}"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.799483807530322*^9, 3.7994838223337083`*^9}, 
   3.7995591837856607`*^9, 3.8026906764728374`*^9, {3.8027528794247737`*^9, 
   3.802752882039772*^9}},ExpressionUUID->"831ff0ee-f037-41f5-be60-\
b8c8668658cb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.799483813497385*^9, 3.799483822662827*^9}, 
   3.799559184102008*^9, 3.7997453006304846`*^9, 3.80000168824187*^9, {
   3.8026906746619377`*^9, 3.802690676747664*^9}, 3.802752882369543*^9, 
   3.806729151042325*^9, 
   3.806732347808025*^9},ExpressionUUID->"1b83eb1d-1db5-4e63-a389-\
90ef851c9c24"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"E", ":", " ", 
   RowBox[{"Med", " ", "to", " ", "Med"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7994838268267145`*^9, 
  3.7994838291384974`*^9}},ExpressionUUID->"dae5b866-d1d7-4cf2-8128-\
ca020700d56c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"qmedco", "-", "qmed"}], "<", "0"}], ",", 
     RowBox[{
      RowBox[{"pmedco", "-", "pmed"}], "==", "0"}], ",", 
     RowBox[{
      RowBox[{"cwmedco", "-", "cwmed"}], "==", "0"}]}], "}"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7994838345231185`*^9, 3.799483854436798*^9}, 
   3.799559186128592*^9, 3.8026906799689665`*^9, {3.802752888039959*^9, 
   3.8027528891127357`*^9}},ExpressionUUID->"1b173c7f-4194-4645-8551-\
de691f552bca"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.799483851556512*^9, 3.799483854758984*^9}, 
   3.799559186461253*^9, 3.799745300661682*^9, 3.800001688273162*^9, 
   3.8026906803068695`*^9, 3.8027528894682302`*^9, 3.8067291535121613`*^9, 
   3.8067323480393887`*^9},ExpressionUUID->"b6b8eda7-e819-4694-b4cf-\
acb2386e42e8"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"F", ":", " ", 
   RowBox[{"Med", " ", "to", " ", "Excl"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7994838588589644`*^9, 
  3.799483862098297*^9}},ExpressionUUID->"4b205124-8c98-450e-9c0a-\
c18f3e570f09"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"qexclco", "-", "qmed"}], "<", "0"}], ",", 
     RowBox[{
      RowBox[{"pexclco", "-", "pmed"}], ">", "0"}], ",", 
     RowBox[{
      RowBox[{"cwexclco", "-", "cwmed"}], "<", "0"}]}], "}"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.799483869602216*^9, 3.7994838840216284`*^9}, 
   3.7995591913897133`*^9, 3.8026906836980343`*^9, {3.8027528963442755`*^9, 
   3.802752897393572*^9}},ExpressionUUID->"edcf4baa-02b7-441c-909c-\
7a6a05e7b890"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.7994838771101236`*^9, 3.7994838844136252`*^9}, 
   3.799559191643462*^9, 3.799745300715147*^9, 3.800001688311053*^9, 
   3.8026906841596327`*^9, 3.8027528977597656`*^9, 3.806729155153532*^9, 
   3.8067323482696424`*^9},ExpressionUUID->"0ecefc65-bb59-4174-b2b1-\
780a12f888e3"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"G", ":", " ", 
   RowBox[{"Excl", " ", "to", " ", "Full"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7994838877945614`*^9, 3.7994838909959955`*^9}, {
  3.7994839534507236`*^9, 
  3.799483953753913*^9}},ExpressionUUID->"2f557585-5eee-4c59-9a3e-\
d6de02001d1a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"qfullco", "-", "qexcl"}], ">", "0"}], ",", 
     RowBox[{
      RowBox[{"pfullco", "-", "pexcl"}], "<", "0"}], ",", 
     RowBox[{
      RowBox[{"cwfullco", "-", "cwexcl"}], ">", "0"}]}], "}"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7994838989616475`*^9, 3.7994839092504883`*^9}, 
   3.7995591938273077`*^9, 3.802690686881379*^9, {3.8027529037739954`*^9, 
   3.8027529048893204`*^9}},ExpressionUUID->"468e7c10-21ca-4a3e-9d78-\
d005beb0e95c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{3.799483909801014*^9, 3.7995591940650826`*^9, 
  3.7997453007620564`*^9, 3.8000016883422256`*^9, 3.802690688518389*^9, 
  3.8027529052393904`*^9, 3.8067291585522113`*^9, 
  3.8067323485094013`*^9},ExpressionUUID->"86cea88b-c5d2-4d3f-9bc5-\
e8c277efbb1b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"H", ":", " ", 
    RowBox[{"Excl", " ", "to", " ", "Med"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Exploit", " ", "that", " ", "we", " ", "know", " ", "that", " ", 
     "\[Rho]"}], " ", ">", " ", 
    RowBox[{
    "rhotildeco", " ", "is", " ", "necessary", " ", "so", " ", "that", " ", 
     "medium", " ", "targeting", " ", "can", " ", "materialize", " ", "post", 
     " ", "policy"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.799483918531684*^9, 3.7994839211078215`*^9}, {
  3.7994839553227167`*^9, 3.799483955578032*^9}, {3.802690739002525*^9, 
  3.802690761696537*^9}},ExpressionUUID->"408ebb22-84cd-4a6f-a939-\
b4f7dc129766"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Reduce", "[", 
      RowBox[{
       RowBox[{"qmedco", "-", "qexcl"}], ">", "0"}], "]"}], ",", 
     RowBox[{
      RowBox[{"pmedco", "-", "pexcl"}], "<", "0"}], ",", 
     RowBox[{
      RowBox[{"cwmedco", "-", "cwexcl"}], ">", "0"}]}], "}"}], ",", 
   SubscriptBox["assumptions", "rhohighco"]}], "]"}]], "Input",
 CellChangeTimes->{{3.79948392322715*^9, 3.799483941197515*^9}, 
   3.79955919712068*^9, 3.8026906918013844`*^9, {3.8026907644013925`*^9, 
   3.8026907656412125`*^9}, {3.802752912960253*^9, 
   3.8027529345497694`*^9}},ExpressionUUID->"6d819ec8-21fb-4bcf-8e5c-\
561b6ec08b55"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Rho]", "+", 
     RowBox[{"\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{"\[Mu]", "+", "\[Rho]"}], ")"}]}]}], ">", 
    RowBox[{"\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"\[Mu]", " ", "\[Rho]"}]}], ")"}]}]}], ",", "True", ",", 
   "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.799483932528684*^9, 3.799559197405272*^9, 3.799745300984788*^9, 
   3.800001688558504*^9, 3.8026906923638544`*^9, 3.802690766130554*^9, {
   3.8027529200089216`*^9, 3.802752936366606*^9}, 3.8067291627938576`*^9, 
   3.8067323500196676`*^9},ExpressionUUID->"30ddf808-e573-4936-afe4-\
f19f4516e29a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"\[CapitalDelta]q", " ", "cannot", " ", "be", " ", "signed"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.80269085146772*^9, 
  3.8026908613449206`*^9}},ExpressionUUID->"eed68b5d-2a11-448e-9321-\
1fbcf0803b84"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Cutoff", " ", "\[Rho]", " ", "such", " ", "that", " ", "\[CapitalDelta]q", 
   " ", "switches", " ", "signs", " ", "lies", " ", "above", " ", 
   "rhotildeco"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8027529618946714`*^9, 
  3.802752976409172*^9}},ExpressionUUID->"8c1c3639-cf0b-43c1-bde2-\
23679b2aa919"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Rho]", "+", 
           RowBox[{"\[Mu]", " ", 
            RowBox[{"(", 
             RowBox[{"\[Mu]", "+", "\[Rho]"}], ")"}]}]}], "==", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[Mu]", " ", "\[Rho]"}]}], ")"}]}]}], ",", "\[Rho]"}], 
        "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ">", "rhotildeco"}], ",", 
   RowBox[{"1", ">", "\[Mu]", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8026907830263557`*^9, 
  3.8026908295921645`*^9}},ExpressionUUID->"c0938977-9ac8-4d14-9140-\
dc63fb1cf07a"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.8026907960339575`*^9, 3.8026908300670795`*^9}, 
   3.8026908637394943`*^9, 3.802752957819157*^9, 3.806729182564105*^9, 
   3.8067323504572973`*^9},ExpressionUUID->"8c9ee89f-9266-49c6-a2af-\
1a5b53a47442"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"I", ":", " ", 
   RowBox[{"Excl", " ", "to", " ", "Excl"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799483950226322*^9, 
  3.7994839613695335`*^9}},ExpressionUUID->"6f3887f6-6597-4868-834b-\
b5ca2d1095b7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"qexclco", "-", "qexcl"}], "<", "0"}], ",", 
     RowBox[{
      RowBox[{"pexclco", "-", "pexcl"}], "==", "0"}], ",", 
     RowBox[{
      RowBox[{"cwexclco", "-", "cwexcl"}], ">", "0"}]}], "}"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.79948396552242*^9, 3.7994839796358256`*^9}, 
   3.7995592006152687`*^9, 3.802690708481845*^9, {3.8027529840816593`*^9, 
   3.80275298515386*^9}},ExpressionUUID->"9c02b00a-20ff-44a6-833f-\
a31723f6cff2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.799483979981366*^9, 3.7995592008314505`*^9, 3.7997453012910795`*^9, 
   3.8000016885963564`*^9, {3.8026907061788855`*^9, 3.802690708751385*^9}, 
   3.8026908651775384`*^9, 3.8027529857306213`*^9, 3.806729186003172*^9, 
   3.806732350668132*^9},ExpressionUUID->"cf7927dc-47bc-454d-a20a-\
f6d574a1640a"]
}, Open  ]],

Cell["Generic Cost Threshold Comparison", "Item",
 CellChangeTimes->{{3.7997454421442423`*^9, 
  3.799745448365984*^9}},ExpressionUUID->"1b846c01-075e-47b6-94fe-\
6ce22e4f644c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c3co", ">", "c3"}], ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7997454872112007`*^9, 3.799745488800229*^9}, {
  3.802690868460565*^9, 3.80269087165663*^9}, {3.8027529940990205`*^9, 
  3.802752995225285*^9}},ExpressionUUID->"c24fa1ba-ffd9-4b34-b54e-\
e9bd07f58f6b"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.799745489100789*^9, 3.8000016886119175`*^9, {3.80269086659855*^9, 
   3.802690877252493*^9}, 3.802752996586156*^9, 3.806729188743217*^9, 
   3.8067323508694925`*^9},ExpressionUUID->"245a019c-2d41-4d62-9dcb-\
406626fb5f01"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c2co", ">", "c2"}], ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.799745450601281*^9, 3.799745471649747*^9}, 
   3.802690879121935*^9, {3.802753001773073*^9, 
   3.8027530028258452`*^9}},ExpressionUUID->"9e268e35-f19f-416f-90e3-\
605bac5a04ed"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.799745461019602*^9, 3.799745472204394*^9}, 
   3.800001688643155*^9, 3.8026908794573774`*^9, 3.8027530031370907`*^9, 
   3.806729190233426*^9, 
   3.8067323510672035`*^9},ExpressionUUID->"e1f767e2-cccd-4f0e-ab63-\
a098105adeb3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c1co", ">", "c1"}], ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7997454781540184`*^9, 3.799745481232319*^9}, 
   3.802690881177231*^9, {3.8027530078395867`*^9, 
   3.8027530099371433`*^9}},ExpressionUUID->"26ea7fae-9152-4145-a878-\
4831a68e20aa"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.799745481833753*^9, 3.8000016886587496`*^9, 
  3.802690881400646*^9, 3.802753010267761*^9, 3.806729191805123*^9, 
  3.8067323512796216`*^9},ExpressionUUID->"9a78ace3-f37c-4ed6-a60d-\
3eedaad94450"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Targeting", " ", "Behavior", " ", "can", " ", "never", " ", "become", " ", 
   "more", " ", "exclusive", " ", "with", " ", "cooling", " ", "off", " ", 
   "period"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997455700625544`*^9, 
  3.7997455826600904`*^9}},ExpressionUUID->"2c5b1b14-f1c7-4c22-96d6-\
f25321e08128"],

Cell["\<\
Targeting behavior uniquely determines price, quantity and CW movement except \
for Exclusive -> Med in which case quantity movement is ambiguous\
\>", "Item",
 CellChangeTimes->{{3.799733396935176*^9, 
  3.7997334230699043`*^9}},ExpressionUUID->"45c101b3-7f6b-4f55-b074-\
cfeae5df464b"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "only", " ", "need", " ", "to", " ", "assess", " ", "which", " ", 
    "targeting", " ", "behavior", " ", "combination", " ", "can", " ", 
    "materialize", " ", "and", " ", "check", " ", "Excl"}], "\[Rule]", 
   RowBox[{"Med", " ", "if", " ", "it", " ", "is", " ", "relevant"}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.799558090341831*^9, 3.7995580983937197`*^9}, {
  3.799558133327933*^9, 3.7995581424231696`*^9}, {3.799732831654752*^9, 
  3.7997328316703568`*^9}, {3.7997334359453983`*^9, 
  3.799733453776888*^9}},ExpressionUUID->"5e29c698-fade-4f62-afe6-\
079fbb2276b1"],

Cell[CellGroupData[{

Cell["\<\
Case 1: \[Mu] sufficiently small (\[Mu]<cutoffmu) then rhotildeco < rhotilde\
\>", "Item",
 CellChangeTimes->{{3.7995582365193667`*^9, 3.799558244385645*^9}, {
  3.799733459692193*^9, 
  3.7997334959555655`*^9}},ExpressionUUID->"8c1f2f0b-e745-4832-b213-\
dcf45ac9ae20"],

Cell["\<\
Case 1.1: rho very small (\[Rho]<rhotildeco): c3, c3co determine targeting\
\>", "Item",
 CellChangeTimes->{{3.7988035225075827`*^9, 3.798803544643381*^9}, {
   3.7993800901961184`*^9, 3.799380096779191*^9}, 3.799732831685979*^9, {
   3.7997334845310707`*^9, 
   3.799733485401783*^9}},ExpressionUUID->"df532079-9fdc-41ea-915b-\
115041347db6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c3co", ">", "c3"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"rhotildeco", ">", "\[Rho]", ">", "0"}], ",", 
     RowBox[{"0", "<", "\[Mu]", "<", "cutoffmu"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7988035482864475`*^9, 3.7988035663561296`*^9}, 
   3.7995582511578836`*^9, 3.802690895785618*^9, {3.8027530589908247`*^9, 
   3.802753060091796*^9}},ExpressionUUID->"ae61f027-2f5c-44b7-be12-\
6fbc3d24725b"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.798803554631523*^9, 3.798803566945586*^9}, 
   3.798953387547945*^9, 3.7989537911156054`*^9, 3.798963722501524*^9, 
   3.7989637774006243`*^9, 3.7991393341170597`*^9, 3.799377871119784*^9, 
   3.799378239090731*^9, 3.799388978294463*^9, 3.7993965996361403`*^9, 
   3.799483090667273*^9, {3.799483686868333*^9, 3.7994837161671476`*^9}, {
   3.7995582488218746`*^9, 3.7995582521604156`*^9}, 3.799559212772834*^9, 
   3.7997453015323963`*^9, 3.8000016887278833`*^9, {3.8026908838359213`*^9, 
   3.802690896123293*^9}, 3.802753019056196*^9, {3.802753055746711*^9, 
   3.8027530605719543`*^9}, 3.8067292907522573`*^9, 
   3.8067323516882772`*^9},ExpressionUUID->"850eb9e0-78d5-4098-9fe2-\
6a4f3b8f2642"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"c", " ", "<", " ", 
    RowBox[{"c3", ":", " ", 
     RowBox[{"Full", " ", "in", " ", "both"}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c3", ",", "c3co"}], ")"}]}], ":", " ", 
    RowBox[{"Exclusive", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Full", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c3co", ":", " ", 
     RowBox[{"Exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7988035708790283`*^9, 3.798803615292313*^9}, {
  3.7997335067378798`*^9, 3.799733517096617*^9}, {3.80275310247042*^9, 
  3.802753103114029*^9}, {3.802753137035857*^9, 
  3.8027531372117596`*^9}},ExpressionUUID->"fe676a93-ff82-4ad5-b5f6-\
ae74efddd4b7"],

Cell["\<\
Case 1.2: rho small, not very small (rhotildeco<\[Rho]<rhotilde), c3 and \
c1co,c2co determine targeting\
\>", "Item",
 CellChangeTimes->{{3.798803620672899*^9, 3.79880364295527*^9}, {
  3.799380099871936*^9, 3.799380114356086*^9}, {3.799732831839599*^9, 
  3.799732831870845*^9}, {3.7997334986636357`*^9, 
  3.799733498901643*^9}},ExpressionUUID->"8d8465d5-e189-4d95-addb-\
92ff440c1821"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c3", "<", "c1co"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"rhotildeco", "<", "\[Rho]", "<", "rhotilde"}], ",", 
     RowBox[{"0", "<", "\[Mu]", "<", "cutoffmu"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7988036792511697`*^9, 3.798803683156685*^9}, {
   3.7993801360290775`*^9, 3.7993801487272797`*^9}, {3.7993801973070803`*^9, 
   3.799380197855822*^9}, 3.7995582647265167`*^9, {3.7997328319020834`*^9, 
   3.7997328319020834`*^9}, {3.8026909008890233`*^9, 
   3.8026909302822027`*^9}},ExpressionUUID->"c1faaf62-684b-4e71-9089-\
da1a93bece7e"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7988036806204777`*^9, 3.798803685099461*^9}, 
   3.798953387616995*^9, 3.798953791162402*^9, 3.798963722601773*^9, 
   3.79896377746311*^9, 3.799139334170392*^9, 3.799377871220018*^9, 
   3.7993782391375866`*^9, {3.79938014468511*^9, 3.7993801493126965`*^9}, 
   3.799380198441571*^9, 3.799388978375247*^9, 3.7993966000091043`*^9, 
   3.799483091161796*^9, {3.7994836869590616`*^9, 3.799483716251944*^9}, 
   3.799558265853978*^9, 3.7995592163238344`*^9, {3.7997335301599207`*^9, 
   3.7997335536224174`*^9}, 3.799745301933112*^9, 3.8000016890821486`*^9, {
   3.802690927890374*^9, 3.802690930593584*^9}, 3.8027530670801735`*^9, 
   3.8067292960003433`*^9, 
   3.80673235219792*^9},ExpressionUUID->"bfc2e347-e4ac-4b18-855b-\
e47c4ae710d1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c1co", "<", "c2co"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"rhotildeco", "<", "\[Rho]", "<", "rhotilde"}], ",", 
     RowBox[{"0", "<", "\[Mu]", "<", "cutoffmu"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.802690935719796*^9, 
  3.802690948529529*^9}},ExpressionUUID->"ce227395-1bcc-4d68-a5d0-\
9fe4cdae6c32"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.8026909374024715`*^9, 3.8026909497761097`*^9}, 
   3.80275306944661*^9, 3.8067292976203423`*^9, 
   3.806732352699263*^9},ExpressionUUID->"697c5f6c-0e13-4302-97a7-\
26e6c5cfc689"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"c", " ", "<", " ", 
    RowBox[{"c3", ":", " ", 
     RowBox[{"Full", " ", "in", " ", "Both"}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c3", ",", "c1co"}], ")"}]}], ":", " ", 
    RowBox[{"Exclusive", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Full", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1co", ",", "c2co"}], ")"}]}], ":", " ", 
    RowBox[{"Exclusive", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Medium", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2co", ":", " ", 
     RowBox[{"Exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",ExpressionUUID->"aef00b03-a8d0-48bd-a71c-6fabb5925403"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "Check", " ", "whether", " ", "\[CapitalDelta]q", " ", "can", " ", "be", 
    " ", "signed", " ", "in", " ", "case", " ", "Excl"}], "\[Rule]", "Med"}], 
  " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997335702782073`*^9, 3.7997335839307175`*^9}, {
  3.8027532171352882`*^9, 
  3.802753218324932*^9}},ExpressionUUID->"ccbb51c5-8705-4dbd-b8a9-\
5ef8c99b76d5"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"For", " ", "\[Rho]"}], " ", "->", " ", "rhotildeco"}], ",", " ", 
   RowBox[{"\[CapitalDelta]q", " ", "<", " ", "0"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8027532215730047`*^9, 
  3.8027532446866503`*^9}},ExpressionUUID->"ce457090-b5cb-4ed0-b92b-\
0e03e42e40c7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Reduce", "[", 
     RowBox[{"qexcl", ">", "qmedco"}], "]"}], "/.", 
    RowBox[{"\[Rho]", "\[Rule]", "rhotildeco"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"0", "<", "\[Mu]", "<", "cutoffmu"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.799484106431319*^9, 3.7994841196690583`*^9}, {
   3.799558276381818*^9, 3.799558302307803*^9}, 3.7997328319020834`*^9, {
   3.7997337010314803`*^9, 3.799733702190407*^9}, {3.8027531557491927`*^9, 
   3.802753209115199*^9}},ExpressionUUID->"b4b39af6-479b-44db-900e-\
0f2faefa2010"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.799484120194624*^9, {3.7995582719457397`*^9, 3.7995583030276423`*^9}, 
   3.7995592182133512`*^9, 3.799733702981981*^9, 3.799745302202403*^9, 
   3.800001689298097*^9, 3.802690952506611*^9, {3.8027531518143635`*^9, 
   3.8027532110405035`*^9}, 3.806729304510605*^9, 
   3.8067323529798164`*^9},ExpressionUUID->"47921449-0fea-45ef-afd8-\
0902f4c25c55"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"For", " ", "\[Rho]"}], " ", "\[Rule]", " ", "rhotilde"}], ",", 
   " ", 
   RowBox[{"\[Mu]", " ", "sufficiently", " ", 
    RowBox[{"small", ":", " ", 
     RowBox[{"\[CapitalDelta]q", " ", ">", " ", "0"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8027533463594017`*^9, 3.8027533620216017`*^9}, {
  3.8067293286515656`*^9, 
  3.806729328851629*^9}},ExpressionUUID->"c46d2c36-fc65-4e71-b054-\
c7dbde082040"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Reduce", "[", 
      RowBox[{"qexcl", "<", "qmedco"}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{"\[Rho]", "\[Rule]", "rhotilde"}], "}"}]}], "]"}], "/.", 
   RowBox[{"\[Mu]", "\[Rule]", "0.01"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8027532562520227`*^9, 
  3.802753365098689*^9}},ExpressionUUID->"da87d639-9de1-4a7d-9f32-\
7b102d4cbb7a"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.8027532771505413`*^9, 3.802753365858571*^9}, {
   3.80672930706222*^9, 3.8067293314233217`*^9}, 
   3.806732354379715*^9},ExpressionUUID->"505e1519-ee94-45aa-bda6-\
bc4cc1aad49a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Both", " ", "cases", " ", "are", " ", "possible"}], ";", " ", 
   RowBox[{
   "sign", " ", "of", " ", "\[CapitalDelta]q", " ", "is", " ", 
    "ambiguous"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7995592197177067`*^9, 3.7995592223903823`*^9}, {
  3.799733586221223*^9, 
  3.799733600023141*^9}},ExpressionUUID->"55036f34-5064-4621-81e9-\
642160d01a32"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.798803689391982*^9, 3.7988037478436604`*^9}, {
   3.799380338182757*^9, 3.799380363761894*^9}, 
   3.7997335656821594`*^9},ExpressionUUID->"ff491822-8a88-494e-a1fe-\
5c7ad0a27cd5"],

Cell["\<\
Case 1.3: rho large (\[Rho]>rhotilde), c1,c2 and c1co,c2co determine targeting\
\>", "Item",
 CellChangeTimes->{{3.7988037522109795`*^9, 3.7988037625952096`*^9}, {
   3.7988039440031*^9, 3.7988039441217422`*^9}, 3.7997328319242134`*^9, {
   3.799733603231866*^9, 
   3.799733618025487*^9}},ExpressionUUID->"49b10ca6-7f41-4ca2-9fcd-\
da96d4f45d33"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c1", "<", "c1co", "<", "c2co"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Rho]", ">", "rhotilde"}], ",", 
     RowBox[{"0", "<", "\[Mu]", "<", "cutoffmu"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.798803767933931*^9, 3.798803806611539*^9}, {
   3.799559232627595*^9, 3.799559243079148*^9}, 3.799732831971084*^9, {
   3.802690959388198*^9, 
   3.8026909630810537`*^9}},ExpressionUUID->"bc876d78-4b8f-4a1f-a3ca-\
e949aec15ad0"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7988037805642233`*^9, 3.798803807313616*^9}, 
   3.798953387648168*^9, 3.79895379120022*^9, 3.7989637226395445`*^9, 
   3.7989637774853787`*^9, 3.799139334201638*^9, 3.7993778712733965`*^9, 
   3.7993782391753445`*^9, 3.7993889784500465`*^9, 3.7993966003526287`*^9, 
   3.7994830917157793`*^9, {3.7994836870498185`*^9, 3.7994837163476295`*^9}, {
   3.7995592276383157`*^9, 3.799559243711928*^9}, 3.799733621249836*^9, 
   3.7997453025029545`*^9, 3.800001689545456*^9, {3.802690956367338*^9, 
   3.802690963595807*^9}, 3.8027533713587275`*^9, 3.8067293343332987`*^9, 
   3.8067323549095316`*^9},ExpressionUUID->"ef9dbc99-e641-495f-9d9b-\
bfb3ac99e726"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c2", "<", "c2co"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Rho]", ">", "rhotilde"}], ",", 
     RowBox[{"0", "<", "\[Mu]", "<", "cutoffmu"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7993792971856203`*^9, 3.7993793039576335`*^9}, {
   3.7995592485109873`*^9, 3.7995592506014805`*^9}, 3.799732831971084*^9, 
   3.8026909708969545`*^9},ExpressionUUID->"3d84409f-2aeb-4841-a68a-\
bbab948282b8"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7993793043363514`*^9, 3.799388978491935*^9, 3.7993966003865542`*^9, 
   3.799483091765657*^9, {3.7994836870867276`*^9, 3.799483716386554*^9}, {
   3.799559245949462*^9, 3.7995592509804068`*^9}, 3.7997336236099033`*^9, 
   3.799745302718992*^9, 3.800001689730356*^9, 3.802690971739375*^9, 
   3.8027533737562437`*^9, 3.8067293357611237`*^9, 
   3.806732355147932*^9},ExpressionUUID->"07b6c95d-fc22-450a-b795-\
0e6e21c2207b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c1co", "<", "c2"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Rho]", ">", "rhotilde"}], ",", 
     RowBox[{"0", "<", "\[Mu]", "<", "cutoffmu"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.798803809100873*^9, 3.798803829724721*^9}, {
   3.7995592549122515`*^9, 3.7995592550906672`*^9}, 3.799732831986706*^9, 
   3.8026909740339956`*^9, {3.8027533786598473`*^9, 3.8027533814695845`*^9}, {
   3.8027534175687532`*^9, 
   3.8027534443028755`*^9}},ExpressionUUID->"33735d13-6713-4e9e-8679-\
d449b6b710d1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"1", "+", 
   RowBox[{
    SuperscriptBox["\[Mu]", "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], "2"]}], "+", 
   SuperscriptBox["\[Rho]", "2"]}], "<", 
  RowBox[{
   RowBox[{"\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "\[Mu]"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], "2"]}], "+", 
   RowBox[{"3", " ", "\[Rho]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7988038305056286`*^9, 3.7989533877485237`*^9, 3.798953791231495*^9, 
   3.798963722786663*^9, 3.7989637775166206`*^9, 3.7991393343019295`*^9, 
   3.799377871436119*^9, 3.7993782392065907`*^9, 3.7993889785537696`*^9, 
   3.7993966006760874`*^9, 3.7994830921767406`*^9, {3.7994836871247025`*^9, 
   3.799483716419468*^9}, {3.7995592528538723`*^9, 3.7995592561937304`*^9}, 
   3.799733625978326*^9, 3.7997453031304502`*^9, 3.800001690116061*^9, 
   3.8026909745792246`*^9, {3.802753400361701*^9, 3.8027534444690113`*^9}, 
   3.8067293381812887`*^9, 
   3.8067323558290997`*^9},ExpressionUUID->"36c57532-8f6b-47ef-984e-\
879a9903c56d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Relative", " ", "position", " ", "of", " ", "c1co", " ", "to", " ", "c2", 
   " ", "ambiguous"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799733629655383*^9, 
  3.7997336385932236`*^9}},ExpressionUUID->"161a8f00-978a-43f7-b7f1-\
4f9864464c4c"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Two", " ", "possible", " ", "Scenarios"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7988039289194*^9, 
  3.798803936939949*^9}},ExpressionUUID->"bf0263dc-c4e6-41f6-b8a5-\
0ddfe0903bde"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Case", " ", "1.3", 
      RowBox[{"a", " ", "--"}], " ", "c1co"}], " ", "<", " ", 
     RowBox[{"c2", " ", 
      RowBox[{"(", 
       RowBox[{"rho", " ", "large"}], ")"}]}]}], ":", " ", 
    RowBox[{"c", " ", "<", " ", "c1"}], ":", " ", 
    RowBox[{"Full", " ", "in", " ", "Both"}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1", ",", "c1co"}], ")"}]}], ":", " ", 
    RowBox[{"Medium", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Full", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"c", " ", "\[Element]", " ", 
       RowBox[{"(", 
        RowBox[{"c1co", ",", "c2"}], ")"}]}], ":", " ", 
      RowBox[{"Medium", " ", "Pre"}]}], " ", "&"}], " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c2", ",", "c2co"}], ")"}]}], ":", " ", 
    RowBox[{"Exclusive", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Medium", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2co", ":", " ", 
     RowBox[{"Exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7988039385027704`*^9, 3.798804014972263*^9}, {
  3.7993795243656373`*^9, 3.7993795298155565`*^9}, {3.7993795719791794`*^9, 
  3.7993795742133894`*^9}, {3.7997338751615577`*^9, 
  3.7997338752927656`*^9}},ExpressionUUID->"c2034ead-6bef-45b7-b470-\
8c94c6e63239"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Case", " ", "1.3", 
      RowBox[{"b", " ", "--"}], " ", "c1co"}], " ", ">", " ", 
     RowBox[{"c2", " ", 
      RowBox[{"(", 
       RowBox[{"rho", " ", "not", " ", "too", " ", "large"}], ")"}]}]}], ":", 
    " ", 
    RowBox[{"c", " ", "<", " ", "c1"}], ":", " ", 
    RowBox[{"Full", " ", "in", " ", "Both"}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1", ",", "c2"}], ")"}]}], ":", " ", 
    RowBox[{"Medium", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Full", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c2", ",", "c1co"}], ")"}]}], ":", " ", 
    RowBox[{"Exclusive", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Full", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1co", ",", "c2co"}], ")"}]}], ":", " ", 
    RowBox[{"Exclusive", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Medium", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2co", ":", " ", 
     RowBox[{"Exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.798804021019129*^9, 3.7988040643791323`*^9}, {
  3.7993795329390388`*^9, 3.7993795693747797`*^9}, {3.7997338695768456`*^9, 
  3.7997338719835987`*^9}},ExpressionUUID->"b4ddc541-4f58-40b6-9541-\
5b6dc283435b"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "Check", " ", "whether", " ", "quantity", " ", "can", " ", "be", " ", 
    "signed", " ", "in", " ", "case", " ", "Excl"}], "\[Rule]", "Med"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.799733661394964*^9, 
  3.7997336715756454`*^9}},ExpressionUUID->"91159531-0ea8-4ea7-a348-\
5b82970e5184"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"qexcl", ">", "qmedco"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Rho]", ">", "rhotilde"}], ",", 
     RowBox[{"0", "<", "\[Mu]", "<", "cutoffmu"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.79973367616997*^9, 3.7997336898898945`*^9}, 
   3.802690978650511*^9},ExpressionUUID->"a0ef544f-cdc7-4f4e-a02c-\
2b7061b780f4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", "\[Mu]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}], ">", "\[Rho]"}]], "Output",
 CellChangeTimes->{
  3.79973369060736*^9, 3.799745303420692*^9, 3.80000169037908*^9, {
   3.802690977086452*^9, 3.802690978983036*^9}, 3.8027534738299894`*^9, 
   3.806729343956825*^9, 
   3.8067323563496323`*^9},ExpressionUUID->"7d4e129a-45d9-4681-b3de-\
1aa91abbde2b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"qexcl", ">", "qmedco"}], "/.", 
    RowBox[{"\[Rho]", "\[Rule]", "rhotilde"}]}], "/.", 
   RowBox[{"\[Mu]", "\[Rule]", "cutoffmu"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.802753480656396*^9, 
  3.802753501392598*^9}},ExpressionUUID->"0f81ffdd-9123-4092-a7a7-\
c08f2a10d48b"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.802753501754445*^9, 3.8067293452722235`*^9, 
  3.8067323565681553`*^9},ExpressionUUID->"58e85d0c-e64a-4402-9542-\
e852258fbe8b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"qexcl", "<", "qmedco"}], "/.", 
    RowBox[{"\[Rho]", "\[Rule]", "rhotilde"}]}], "/.", 
   RowBox[{"\[Mu]", "\[Rule]", "0.01"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8027535097758856`*^9, 3.8027535104956274`*^9}, {
  3.8067293491027565`*^9, 
  3.8067293505840826`*^9}},ExpressionUUID->"1f84b684-3d04-44e4-aff3-\
de18901d9116"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.80275351087883*^9, {3.8067293472739363`*^9, 3.8067293511427174`*^9}, 
   3.8067323567682877`*^9},ExpressionUUID->"fbb12477-45f2-40b9-8b10-\
3ef7d717e9cb"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"\[CapitalDelta]q", " ", "ambiguous"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8027535130512257`*^9, 
  3.802753522952111*^9}},ExpressionUUID->"dab112af-35d5-4242-a0ee-\
bebdda2e6523"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Both", " ", "cases", " ", "are", " ", "possible"}], ";", " ", 
   RowBox[{
   "sign", " ", "of", " ", "\[CapitalDelta]q", " ", "is", " ", 
    "ambiguous"}]}], " ", "*)"}]], "Input",ExpressionUUID->"1ad79906-e234-\
4b9f-9374-5b8172cf37be"],

Cell[CellGroupData[{

Cell["\<\
 Case 2 : \[Mu]  large  = > different cutoff ordering (rhotildeco > rhotilde)\
\>", "Item",
 CellChangeTimes->{{3.7995592914329576`*^9, 3.799559311517046*^9}, {
  3.799733715383545*^9, 
  3.7997337219564786`*^9}},ExpressionUUID->"52dbb6d4-bbf6-4753-86ae-\
5aa2b122f513"],

Cell["\<\
Case 2.1 : rho very small (\[Rho] < rhotilde) : c3, c3co determine targeting\
\>", "Item",
 CellChangeTimes->{{3.7995593182498894`*^9, 3.799559325068369*^9}, 
   3.799732832002328*^9, {3.799733728210995*^9, 
   3.7997337307176433`*^9}},ExpressionUUID->"f50e9d9f-0d05-4bb4-b9ce-\
1ccce6ae23c4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c3co", ">", "c3"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Rho]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "cutoffmu"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.799559343701335*^9, 3.7995593461082497`*^9}, 
   3.802690981121887*^9},ExpressionUUID->"a65062b2-2131-456b-b16f-\
f7f3e603b16e"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.799559341067417*^9, 3.7995593467396927`*^9}, 
   3.799733724774235*^9, 3.7997453036369*^9, 3.800001690579693*^9, 
   3.802690981312335*^9, 3.8027535269710255`*^9, 3.8067293558944263`*^9, 
   3.8067323572380095`*^9},ExpressionUUID->"9e5590a4-9584-462e-818a-\
ce3752656a50"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"c", " ", "<", " ", 
    RowBox[{"c3", ":", " ", 
     RowBox[{"Full", " ", "in", " ", "both"}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c3", ",", "c3co"}], ")"}]}], ":", " ", 
    RowBox[{"Exclusive", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Full", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c3co", ":", " ", 
     RowBox[{"Exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",ExpressionUUID->"95fd4b48-b4bb-430d-b190-e54ce0cf4a0d"],

Cell["\<\
Case 2.2 : rho small, not very small (rhotilde < \[Rho] < rhotildeco), c3co \
and c1, c2 determine targeting\
\>", "Item",
 CellChangeTimes->{{3.7995593614805045`*^9, 3.7995593758597555`*^9}, {
  3.799732832055719*^9, 3.7997328320869474`*^9}, {3.799733753876004*^9, 
  3.799733754330552*^9}},ExpressionUUID->"d16b9172-9c56-44e8-a132-\
906fd0ce0d39"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c3co", ">", "c2"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"rhotilde", "<", "\[Rho]", "<", "rhotildeco"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "cutoffmu"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7995593903731213`*^9, 3.7995594128264866`*^9}, {
   3.799732832102569*^9, 3.799732832102569*^9}, {3.802690983585949*^9, 
   3.8026909872174225`*^9}, 
   3.802691120267429*^9},ExpressionUUID->"562f40d4-081b-4cfd-8b6f-\
96af6996f6e7"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.799559397337171*^9, 3.79955941348137*^9}, 
   3.799733765001597*^9, 3.799745304053152*^9, 3.800001690887149*^9, {
   3.802690984515448*^9, 3.802690988175815*^9}, 3.8026911208194838`*^9, 
   3.802753532532558*^9, 3.8067293585405664`*^9, 
   3.806732358039313*^9},ExpressionUUID->"27725d7b-9e4c-4daa-9e97-\
5c19f70af934"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c2", ">", "c1"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"rhotilde", "<", "\[Rho]", "<", "rhotildeco"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "cutoffmu"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8026911270150614`*^9, 
  3.8026911287128053`*^9}},ExpressionUUID->"f92e5d60-4002-49a5-a131-\
c964af7e7619"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8026911294485517`*^9, 3.8027535348968396`*^9, 
  3.8067293603932753`*^9, 
  3.8067323588779325`*^9},ExpressionUUID->"132ed257-47a0-4e38-93e2-\
b0b4840dd4c1"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"c", " ", "<", " ", 
    RowBox[{"c1", ":", " ", 
     RowBox[{"Full", " ", "in", " ", "Both"}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1", ",", "c2"}], ")"}]}], ":", " ", 
    RowBox[{"Medium", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Full", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c2", ",", "c3co"}], ")"}]}], ":", " ", 
    RowBox[{"Excl", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Full", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c3co", ":", " ", 
     RowBox[{"Excl", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.79955942691696*^9, 3.799559476020021*^9}, 
   3.799733774970148*^9},ExpressionUUID->"248f2ee6-dee2-4c65-9bf4-\
f1498cb70dc6"],

Cell["\<\
Case 2.3 : rho large (\[Rho] > rhotildeco), c1, c2 and c1co, c2co determine \
targeting\
\>", "Item",
 CellChangeTimes->{{3.7995595398508625`*^9, 3.7995595444181757`*^9}, 
   3.799732832132557*^9, {3.799733866622388*^9, 3.799733866923168*^9}, {
   3.799738489234538*^9, 
   3.7997385043164883`*^9}},ExpressionUUID->"4ef815b1-1130-49bc-9fc4-\
ebb394a83c2f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c1", "<", "c1co", "<", "c2co"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Rho]", ">", "rhotildeco"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "cutoffmu"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.8026909903054295`*^9},ExpressionUUID->"84c490bb-78f3-4acf-a08b-\
00fd67d11c1d"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.7997338086738744`*^9, 3.7997453042849164`*^9, 
  3.800001691134525*^9, 3.802690990656514*^9, 3.802753557474859*^9, 
  3.80672936250344*^9, 
  3.806732359359264*^9},ExpressionUUID->"cbb21208-422a-413b-bd64-\
f81f96bcd164"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c2co", ">", "c2"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Rho]", ">", "rhotildeco"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "cutoffmu"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7995595529868593`*^9, 3.7995595731292353`*^9}, {
   3.7995596481811705`*^9, 3.7995596483658514`*^9}, 3.7997328321513667`*^9, 
   3.8026909936491375`*^9},ExpressionUUID->"c27940f1-48be-4b40-8a00-\
b34f1992e63b"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7995595572688336`*^9, 3.7995595734293737`*^9}, 
   3.7995596489303856`*^9, 3.79973381427801*^9, 3.7997453044852743`*^9, 
   3.8000016913351145`*^9, 3.802690993875867*^9, 3.8027535587969995`*^9, 
   3.8067293639946713`*^9, 
   3.806732359608344*^9},ExpressionUUID->"7edd8da6-1d56-433e-b56c-\
e641df44c9b6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c1co", ">", "c2"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Rho]", ">", "rhotildeco"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "cutoffmu"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7995595865642257`*^9, 3.7995595910907764`*^9}, {
   3.7995596535284595`*^9, 3.7995596537818813`*^9}, 3.799732832166989*^9, 
   3.802690996257248*^9, 
   3.8026911108979635`*^9},ExpressionUUID->"0498c2b1-30a1-4320-874e-\
872ddf69c7d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"1", "+", 
   RowBox[{
    SuperscriptBox["\[Mu]", "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], "2"]}], "+", 
   SuperscriptBox["\[Rho]", "2"]}], ">", 
  RowBox[{
   RowBox[{"\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "\[Mu]"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], "2"]}], "+", 
   RowBox[{"3", " ", "\[Rho]"}]}]}]], "Output",
 CellChangeTimes->{
  3.799559591676553*^9, {3.7995596545307856`*^9, 3.799559664624696*^9}, 
   3.799733821143321*^9, 3.7997453048925557`*^9, 3.8000016917205033`*^9, {
   3.802691107773096*^9, 3.80269113271107*^9}, 3.8027535613605404`*^9, 
   3.8067293662274895`*^9, 
   3.806732360259329*^9},ExpressionUUID->"965bb7be-82a2-4dee-9e18-\
b33b8aada296"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "c2", " ", "can", " ", "lie", " ", "either", " ", "above", " ", "or", " ", 
   "below", " ", "c1co"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997338291668253`*^9, 
  3.7997338369595265`*^9}},ExpressionUUID->"e924949a-bf9e-4842-a64d-\
ddf041736896"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Case", " ", "2.3", 
      RowBox[{"a", " ", "--"}], " ", "c1co"}], " ", "<", " ", 
     RowBox[{"c2", " ", 
      RowBox[{"(", 
       RowBox[{"rho", " ", "large"}], ")"}]}]}], ":", " ", 
    RowBox[{"c", " ", "<", " ", "c1"}], ":", " ", 
    RowBox[{"Full", " ", "in", " ", "Both"}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1", ",", "c1co"}], ")"}]}], ":", " ", 
    RowBox[{"Medium", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Full", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"c", " ", "\[Element]", " ", 
       RowBox[{"(", 
        RowBox[{"c1co", ",", "c2"}], ")"}]}], ":", " ", 
      RowBox[{"Medium", " ", "Pre"}]}], " ", "&"}], " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c2", ",", "c2co"}], ")"}]}], ":", " ", 
    RowBox[{"Exclusive", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Medium", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2co", ":", " ", 
     RowBox[{"Exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7988039385027704`*^9, 3.798804014972263*^9}, {
  3.7993795243656373`*^9, 3.7993795298155565`*^9}, {3.7993795719791794`*^9, 
  3.7993795742133894`*^9}, {3.799733859983443*^9, 
  3.7997338600991154`*^9}},ExpressionUUID->"0bef379c-15ef-4d45-8c6e-\
83331fc0ba0f"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Case", " ", "2.3", 
      RowBox[{"b", " ", "--"}], " ", "c1co"}], " ", ">", " ", 
     RowBox[{"c2", " ", 
      RowBox[{"(", 
       RowBox[{"rho", " ", "not", " ", "too", " ", "large"}], ")"}]}]}], ":", 
    " ", 
    RowBox[{"c", " ", "<", " ", "c1"}], ":", " ", 
    RowBox[{"Full", " ", "in", " ", "Both"}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1", ",", "c2"}], ")"}]}], ":", " ", 
    RowBox[{"Medium", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Full", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c2", ",", "c1co"}], ")"}]}], ":", " ", 
    RowBox[{"Exclusive", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Full", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1co", ",", "c2co"}], ")"}]}], ":", " ", 
    RowBox[{"Exclusive", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Medium", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2co", ":", " ", 
     RowBox[{"Exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.798804021019129*^9, 3.7988040643791323`*^9}, {
  3.7993795329390388`*^9, 3.7993795693747797`*^9}, {3.799733863609226*^9, 
  3.799733863815877*^9}},ExpressionUUID->"8ea902be-a67a-4932-b4af-\
dad4d60e30c9"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "Check", " ", "whether", " ", "quantity", " ", "can", " ", "be", " ", 
    "signed", " ", "in", " ", "case", " ", "Excl"}], "\[Rule]", "Med"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.799733661394964*^9, 
  3.7997336715756454`*^9}},ExpressionUUID->"d1ca531d-d3ce-4db1-99d5-\
e2ac68890615"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"qexcl", ">", "qmedco"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Rho]", ">", "rhotildeco"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "cutoffmu"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.799733897240491*^9, 3.799733905077855*^9}, {
  3.802691138785807*^9, 3.80269113926502*^9}, {3.802753579681423*^9, 
  3.802753581640609*^9}},ExpressionUUID->"ba8b0e2c-e1a6-44b6-b124-\
1d4855b8dd0c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", "\[Mu]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}], ">", "\[Rho]"}]], "Output",
 CellChangeTimes->{{3.799733902802971*^9, 3.799733905679267*^9}, 
   3.799745305139939*^9, 3.800001691967951*^9, {3.8026911348046403`*^9, 
   3.802691139822791*^9}, {3.80275357200242*^9, 3.802753582275812*^9}, 
   3.8067293693646407`*^9, 
   3.8067323607080073`*^9},ExpressionUUID->"1f81a15e-3d74-4d56-87dc-\
04fec6a086f9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"qexcl", ">", "qmedco"}], "/.", 
    RowBox[{"\[Rho]", "\[Rule]", "rhotildeco"}]}], "/.", 
   RowBox[{"\[Mu]", "\[Rule]", "cutoffmu"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8027535954984245`*^9, 
  3.8027535956863375`*^9}},ExpressionUUID->"8b916296-9309-44e2-a5e8-\
a8722df916a9"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.802753605572198*^9, 3.806729370764865*^9, 
  3.8067323609182453`*^9},ExpressionUUID->"861266a1-4504-46fe-be94-\
9a61bd1d0ab7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"qexcl", ">", "qmedco"}], "/.", 
    RowBox[{"\[Rho]", "\[Rule]", "0.99"}]}], "/.", 
   RowBox[{"\[Mu]", "\[Rule]", "cutoffmu"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8027536010878296`*^9, 
  3.802753621343994*^9}},ExpressionUUID->"73ec23df-9ff3-44f4-9b3d-\
ed9833022465"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{{3.802753603308919*^9, 3.802753621705392*^9}, 
   3.8067293721335382`*^9, 
   3.8067323611695423`*^9},ExpressionUUID->"47359eae-ade2-410b-b618-\
0ba07bec9a1d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Same", " ", "as", " ", "before"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.802753573586892*^9, 
  3.8027535762242785`*^9}},ExpressionUUID->"d3ba4789-1217-4490-b66e-\
db26f47c0803"],

Cell["\<\
Overall: All possible combinations with weakly more inclusive \
post-intervention targeting behavior are possible; signs of \[CapitalDelta]q, \
\[CapitalDelta]p, \[CapitalDelta]CW are determined by targeting except for \
Excl->Med\
\>", "Item",
 CellChangeTimes->{{3.7997339153762307`*^9, 3.799733946726879*^9}, {
  3.800689491569193*^9, 
  3.800689505497964*^9}},ExpressionUUID->"bf3f932d-09ce-4aea-a2c4-\
5ee9b969ea7f"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.799559478409231*^9, 3.7995594902894235`*^9}, 
   3.7995595285194225`*^9},ExpressionUUID->"0faf7d25-bde5-455a-ac9e-\
ec26a688bcc6"],

Cell[CellGroupData[{

Cell["", "Item",
 CellChangeTimes->{{3.7989531850698404`*^9, 3.7989531855710473`*^9}, {
  3.809692421736904*^9, 
  3.80969242413337*^9}},ExpressionUUID->"c9a590ed-fa41-42aa-b916-\
016a1621b293"],

Cell["Return Policy", "Item",
 CellChangeTimes->{{3.7989531850698404`*^9, 3.798953193370515*^9}, 
   3.8096924077164245`*^9},ExpressionUUID->"0d45dcbe-7096-431f-a19f-\
5b92e7e2889e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Again", " ", "three", " ", "targeting", " ", "strategies"}], ",", 
   " ", 
   RowBox[{"identical", " ", "to", " ", "baseline", " ", 
    RowBox[{"(", 
     RowBox[{
     "presence", " ", "of", " ", "rational", " ", "consumers", " ", "only", 
      " ", "changes", " ", "quantities"}], ")"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799734136713382*^9, 
  3.7997341581246552`*^9}},ExpressionUUID->"de383d5e-6962-4d9a-adef-\
28fd784098e6"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Relevant", " ", 
    RowBox[{"prices", ":", " ", 
     RowBox[{"motivated", " ", "utility"}]}]}], ",", " ", 
   RowBox[{"unmotivated", " ", "prediction", " ", "for", " ", "motivated"}], 
   ",", " ", 
   RowBox[{"unmotivated", " ", "utility"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7995612758848457`*^9, 3.799561297504511*^9}, {
  3.7997341636851406`*^9, 
  3.799734167416004*^9}},ExpressionUUID->"7412bdf7-ebe9-4610-a52c-\
632c8d6645e8"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Initialize", " ", "unmotivated", " ", "biased", " ", 
   RowBox[{"consumers", "'"}], " ", "prediction", " ", "for", " ", 
   "motivated", " ", "state"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997341732931786`*^9, 3.799734175112951*^9}, {
  3.799734244470657*^9, 
  3.7997342565347013`*^9}},ExpressionUUID->"e07b8348-6b24-4abd-b573-\
74c8777a16d8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"uunmotmot", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"\[Alpha]", " ", "ulow"}], " ", "+", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", "uhigh"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.799734211278014*^9, 
  3.7997342353906436`*^9}},ExpressionUUID->"4de908da-3be7-4ce6-a980-\
9fa784096b14"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Initialize", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Prices", "/", "Quantities"}], "/", "Profits"}], "/", 
    "Surplus"}], " ", "for", " ", "three", " ", "strategies"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7997342641770873`*^9, 
  3.7997342778976374`*^9}},ExpressionUUID->"aad8fc6a-08b9-49e5-9b98-\
881429b7e406"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qfullrp", "=", "1"}], ";", 
  RowBox[{"pfullrp", "=", "ulow"}], ";", 
  RowBox[{"proffullrp", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"pfullrp", "-", "c"}], ")"}], "*", "qfullrp"}]}], ";", 
  RowBox[{"cwfullrp", "=", 
   RowBox[{"qfullrp", "*", 
    RowBox[{"(", 
     RowBox[{"exput", "-", "pfullrp"}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7989532088148623`*^9, 3.798953258262805*^9}, {
  3.799561302399861*^9, 3.799561315589545*^9}, {3.799734199431275*^9, 
  3.799734200233324*^9}},ExpressionUUID->"d5a28efb-d0fe-45ae-8501-\
944ed62ab8ca"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qmedrp", "=", "\[Mu]"}], ";", 
  RowBox[{"pmedrp", "=", "uunmotmot"}], ";", 
  RowBox[{"profmedrp", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"pmedrp", "-", "c"}], ")"}], "*", "qmedrp"}]}], ";", 
  RowBox[{"cwmedrp", "=", 
   RowBox[{"qmedrp", "*", 
    RowBox[{"(", 
     RowBox[{"uhigh", "-", "pmedrp"}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.798953264493266*^9, 3.798953287896304*^9}, {
  3.7989533350615015`*^9, 3.7989533838758574`*^9}, {3.79956133373518*^9, 
  3.799561339974492*^9}, {3.799561394958027*^9, 3.79956139649376*^9}, {
  3.799734189436165*^9, 3.799734191008898*^9}, {3.7997342380513635`*^9, 
  3.799734240542863*^9}},ExpressionUUID->"c40c45f4-6ecf-4a13-814b-\
0a25aea92360"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qexclrp", "=", 
   RowBox[{"\[Mu]", 
    RowBox[{"(", 
     RowBox[{"\[Rho]", "+", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Rho]"}], ")"}]}]}], ")"}]}]}], ";", 
  RowBox[{"pexclrp", "=", "uhigh"}], ";", 
  RowBox[{"profexclrp", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"pexclrp", "-", "c"}], ")"}], "*", "qexclrp"}]}], ";", 
  RowBox[{"cwexclrp", "=", 
   RowBox[{"qexclrp", "*", 
    RowBox[{"(", 
     RowBox[{"uhigh", "-", "pexclrp"}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7989536239702067`*^9, 3.7989536626576023`*^9}, {
  3.799561426026603*^9, 3.799561450463837*^9}, {3.799734193716917*^9, 
  3.7997341955530977`*^9}, {3.8026911554096537`*^9, 
  3.802691156536652*^9}},ExpressionUUID->"2455a6c6-67f9-4237-b418-\
cea0fda020c7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Check", " ", "that", " ", "above", " ", "characterizations", " ", "are", 
    " ", "correct"}], " ", "*)"}], "\n", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"qfullrp", ",", "pfullrp", ",", "proffullrp", ",", "cwfullrp"}],
       "}"}], ",", "assumptions"}], "]"}], "\n", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"qmedrp", ",", "pmedrp", ",", "profmedrp", ",", "cwmedrp"}], 
      "}"}], ",", "assumptions"}], "]"}], "\n", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"qexclrp", ",", "pexclrp", ",", "profexclrp", ",", "cwexclrp"}],
       "}"}], ",", "assumptions"}], "]"}], "\n"}]}]], "Input",
 CellChangeTimes->{{3.7989536762569942`*^9, 3.7989536789647293`*^9}, {
  3.799734509068655*^9, 3.799734558535033*^9}, {3.8027536591298304`*^9, 
  3.8027536677140026`*^9}},ExpressionUUID->"22cabbf4-01b7-47c5-beb9-\
d68e71515811"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "u", ",", 
   RowBox[{
    RowBox[{"-", "c"}], "+", "u"}], ",", 
   RowBox[{"\[CapitalDelta]", " ", "\[Mu]"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7997345794212065`*^9, 3.799745305324793*^9, 3.8000016922062874`*^9, 
   3.802691240114987*^9, {3.80275366113472*^9, 3.802753668318185*^9}, 
   3.8067293926437745`*^9, 
   3.806732361478118*^9},ExpressionUUID->"896c7785-614f-417c-96b1-\
cca78434981b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[Mu]", ",", 
   RowBox[{"u", "+", "\[CapitalDelta]", "-", 
    RowBox[{"\[Alpha]", " ", "\[CapitalDelta]"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "c"}], "+", "u", "+", "\[CapitalDelta]", "-", 
      RowBox[{"\[Alpha]", " ", "\[CapitalDelta]"}]}], ")"}], " ", "\[Mu]"}], 
   ",", 
   RowBox[{"\[Alpha]", " ", "\[CapitalDelta]", " ", "\[Mu]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7997345794212065`*^9, 3.799745305324793*^9, 3.8000016922062874`*^9, 
   3.802691240114987*^9, {3.80275366113472*^9, 3.802753668318185*^9}, 
   3.8067293926437745`*^9, 
   3.8067323614882193`*^9},ExpressionUUID->"5a5828b9-7a9e-46cb-bee8-\
2f5b16a9203b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{"\[Mu]", "+", "\[Rho]", "-", 
      RowBox[{"\[Mu]", " ", "\[Rho]"}]}], ")"}]}], ",", 
   RowBox[{"u", "+", "\[CapitalDelta]"}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "c"}], "+", "u", "+", "\[CapitalDelta]"}], ")"}], " ", 
    "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{"\[Mu]", "+", "\[Rho]", "-", 
      RowBox[{"\[Mu]", " ", "\[Rho]"}]}], ")"}]}], ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7997345794212065`*^9, 3.799745305324793*^9, 3.8000016922062874`*^9, 
   3.802691240114987*^9, {3.80275366113472*^9, 3.802753668318185*^9}, 
   3.8067293926437745`*^9, 
   3.806732361497212*^9},ExpressionUUID->"9e052636-1a90-444d-94fe-\
9fa7db4e5020"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Get", " ", "thresholds", " ", "as", " ", "before"}], ",", " ", 
   RowBox[{"rp", " ", "denotes", " ", "Return", " ", "Policy"}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.799734921157484*^9, 
  3.7997349416171603`*^9}},ExpressionUUID->"7c57a6d6-80a7-4435-9015-\
610c5d2c80f9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"proffullrp", "\[Equal]", "profmedrp"}], ",", "c"}], "]"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.802753700849951*^9, 
  3.80275371466372*^9}},ExpressionUUID->"3faf2a0c-748e-41e3-b07f-\
89731a9033c2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"u", "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", "\[CapitalDelta]",
        " ", "\[Mu]"}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Mu]"}]]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.802753715178752*^9, 3.806729395423785*^9, 
  3.8067323617283707`*^9},ExpressionUUID->"a9f0d50d-4f06-457f-b074-\
97bcc771a449"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"c1rp", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"c", "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"proffullrp", "\[Equal]", "profmedrp"}], ",", "c"}], "]"}], 
       "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", "assumptions"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.79895372395417*^9, 3.798953741886464*^9}, {
   3.7995615293441367`*^9, 3.799561532791226*^9}, {3.802753674672695*^9, 
   3.802753675520857*^9}, 
   3.8027537183216486`*^9},ExpressionUUID->"cb419960-ed25-4f23-8487-\
06fe6c1aa8cf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"profmedrp", "\[Equal]", "profexclrp"}], ",", "c"}], "]"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.8027537262156973`*^9, 
  3.802753731498068*^9}},ExpressionUUID->"e831348c-8096-4acf-b57f-\
f28c8d92e40b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"u", "+", "\[CapitalDelta]", "-", 
     FractionBox[
      RowBox[{"\[Alpha]", " ", "\[CapitalDelta]"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}]]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8027537318879547`*^9, 3.806729398624481*^9, 
  3.8067323619993153`*^9},ExpressionUUID->"dff4d4d8-3f4f-4503-b800-\
4c0e6e120d95"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"c2rp", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"c", "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"profmedrp", "\[Equal]", "profexclrp"}], ",", "c"}], "]"}], 
       "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", "assumptions"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7989537440549383`*^9, 3.798953757327242*^9}, {
   3.802753678185257*^9, 3.802753678906453*^9}, 
   3.802753740145163*^9},ExpressionUUID->"76f72975-ad4b-40fa-878c-\
27cccb3602ed"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"proffullrp", "\[Equal]", "profexclrp"}], ",", "c"}], "]"}], ",",
    "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.802753745832095*^9, 
  3.802753747032302*^9}},ExpressionUUID->"0fca3d6a-0657-4bb8-a5ca-\
dbbd65ce02fc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"u", "+", "\[CapitalDelta]", "-", 
     FractionBox["\[CapitalDelta]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}]}], ")"}]}]]}]}], 
   "}"}], "}"}]], "Output",
 CellChangeTimes->{3.802753747664241*^9, 3.8067294019964337`*^9, 
  3.8067323622991*^9},ExpressionUUID->"b5c938d0-df9b-488c-9204-4e51917f8127"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"c3rp", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"c", "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"proffullrp", "\[Equal]", "profexclrp"}], ",", "c"}], "]"}], 
       "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", "assumptions"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7989537592792673`*^9, 3.79895377336801*^9}, {
   3.8027536821125174`*^9, 3.8027536827858725`*^9}, 
   3.8027537511544094`*^9},ExpressionUUID->"2d8a0488-91c0-4c2a-8218-\
a29ae129178b"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Characterize", " ", "\[Rho]", " ", "cutoff", " ", "which", " ", 
   "determines", " ", "threshold", " ", "cost", " ", "ordering"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7997349572943487`*^9, 
  3.7997349693433523`*^9}},ExpressionUUID->"50249b2e-0238-48c2-8fc0-\
2c101dead0ff"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rhotilderp", "=", 
  RowBox[{"\[Rho]", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"c1rp", "\[Equal]", "c2rp"}], ",", "\[Rho]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.798953800771258*^9, 3.798953815109975*^9}, {
   3.7989538699848647`*^9, 3.7989539253663473`*^9}, {3.79956146896122*^9, 
   3.7995614838723135`*^9}, 3.799732832166989*^9, {3.7997349810902452`*^9, 
   3.7997349841664906`*^9}, {3.8027537564584894`*^9, 
   3.802753756991615*^9}},ExpressionUUID->"4c60230e-ada8-4426-8935-\
4bcb1313842c"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", "1"}], "+", "\[Alpha]", "+", 
   RowBox[{"\[Alpha]", " ", "\[Mu]"}]}], 
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   RowBox[{"\[Alpha]", " ", "\[Mu]"}]}]]], "Output",
 CellChangeTimes->{
  3.79895381564287*^9, {3.7989538785138397`*^9, 3.7989538850480523`*^9}, 
   3.7989539265389595`*^9, 3.798963723125128*^9, 3.7989637778329573`*^9, 
   3.7991393345494137`*^9, 3.7993778717745953`*^9, 3.7993782395073166`*^9, 
   3.7993889788390064`*^9, 3.7993966013350945`*^9, 3.799483092923589*^9, {
   3.799483687664175*^9, 3.7994837169739513`*^9}, {3.7995614800450573`*^9, 
   3.799561484504798*^9}, 3.799561538940956*^9, {3.799734971665097*^9, 
   3.7997349843669367`*^9}, 3.7997453058974485`*^9, 3.80000169272342*^9, 
   3.8026912467567873`*^9, {3.8027537532032986`*^9, 3.80275375889181*^9}, 
   3.806729406104915*^9, 
   3.8067323626894608`*^9},ExpressionUUID->"70769b38-fd6c-4af3-b00e-\
d0ea62f64773"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"1", ">", "rhotilderp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.799561487242921*^9, 3.7995615098799686`*^9}, 
   3.7997328321826105`*^9, {3.7997352144476557`*^9, 3.7997352173663063`*^9}, {
   3.8027537746735177`*^9, 
   3.8027537749741993`*^9}},ExpressionUUID->"b9d6742c-71f2-4124-a62c-\
4466940f302d"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7995615103276963`*^9, 3.799734973739194*^9, 3.7997453061263895`*^9, 
   3.800001692923894*^9, 3.8026912482241716`*^9, {3.8027537605171165`*^9, 
   3.8027537756694393`*^9}, 3.8067294089350166`*^9, 
   3.806732362900278*^9},ExpressionUUID->"300870a2-5555-484d-a4c6-\
2f3e85428766"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"rhotilderp", "<", "0"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.799735001712638*^9, 
  3.7997350177739396`*^9}},ExpressionUUID->"1abb37b2-ba7d-42dd-9688-\
19ff6b70418f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Alpha]", "+", 
   RowBox[{"\[Alpha]", " ", "\[Mu]"}]}], ">", "1"}]], "Output",
 CellChangeTimes->{{3.7997350073981314`*^9, 3.7997350183129272`*^9}, 
   3.7997453063270187`*^9, 3.8000016931245747`*^9, 3.8026912495096703`*^9, {
   3.802753762200424*^9, 3.8027537790396843`*^9}, 3.8067294106152143`*^9, 
   3.8067323631080866`*^9},ExpressionUUID->"18a864e4-603e-4681-a6da-\
a590ce0ec774"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Possible", " ", "that", " ", "rhotilderp"}], " ", "<", " ", 
    RowBox[{"0", " ", "in", " ", "which", " ", "case", " ", "\[Rho]"}], " ", 
    "<", " ", 
    RowBox[{"rhotilderp", " ", "not", " ", "possible"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Store", " ", "restriction", " ", "that", " ", "possible", " ", "as", " ", 
    "extra", " ", "assumption"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.799735031697874*^9, 3.7997350394513884`*^9}, {
  3.799735177399212*^9, 3.7997351820399227`*^9}, {3.7997352220884514`*^9, 
  3.7997352317363925`*^9}},ExpressionUUID->"c02d3a42-de5e-447e-aeb1-\
6aae15709edc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lowrhorppossible", " ", "=", " ", 
  RowBox[{
   RowBox[{"\[Alpha]", "+", 
    RowBox[{"\[Alpha]", " ", "\[Mu]"}]}], "<", "1"}]}]], "Input",
 CellChangeTimes->{{3.799735240644067*^9, 3.799735247975443*^9}, {
  3.8027537869847126`*^9, 
  3.8027537980638375`*^9}},ExpressionUUID->"8b17ca81-ed27-47d7-a13d-\
d6057d01a5a9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Alpha]", "+", 
   RowBox[{"\[Alpha]", " ", "\[Mu]"}]}], "<", "1"}]], "Output",
 CellChangeTimes->{{3.799735242864832*^9, 3.7997352492296877`*^9}, 
   3.7997453063738966`*^9, 3.8000016931870623`*^9, 3.8026912524671736`*^9, {
   3.802753793521577*^9, 3.8027537984160686`*^9}, 3.806729414195337*^9, 
   3.806732363327279*^9},ExpressionUUID->"de46163c-db9b-4b81-994e-\
a5a333e08bf0"]
}, Open  ]],

Cell["\<\
Case 1: \[Rho] < rhotilderp => c1rp < c3rp < c2rp, c1rp and c2rp determine \
targeting\
\>", "Item",
 CellChangeTimes->{{3.798953927921574*^9, 3.7989539433823023`*^9}, {
   3.799397027109417*^9, 3.799397038581626*^9}, 
   3.7997328321982317`*^9},ExpressionUUID->"85409bfb-4c5d-483c-8897-\
cea1217a33f6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c1rp", "<", "c3rp", " ", "<", "c2rp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"\[Rho]", "<", "rhotilderp"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.798953945334814*^9, 3.79895397934054*^9}, {
   3.7995615572062473`*^9, 3.7995615586097155`*^9}, 3.7997328322873554`*^9, {
   3.799735193898819*^9, 3.799735196320364*^9}, {3.802691257801838*^9, 
   3.802691263881237*^9}},ExpressionUUID->"0d67f472-8c29-4623-911f-\
6e4254943f88"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7989539579375534`*^9, 3.7989539797568803`*^9}, 
   3.7989637231563764`*^9, 3.7989637778485775`*^9, 3.7991393345716095`*^9, 
   3.79937787180585*^9, 3.799378239538543*^9, 3.799388978858957*^9, 
   3.799396601375002*^9, 3.799483092981429*^9, {3.7994836876960897`*^9, 
   3.7994837170138826`*^9}, {3.79956155402871*^9, 3.7995615591263723`*^9}, 
   3.79973519696915*^9, 3.799745306643104*^9, 3.800001693409815*^9, {
   3.802691254652673*^9, 3.8026912683084097`*^9}, {3.8027538013778276`*^9, 
   3.8027538202868156`*^9}, 3.806729419375804*^9, 
   3.8067323635494103`*^9},ExpressionUUID->"fd197f56-0d53-4a31-8b14-\
c9b3412af810"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"In", " ", "this", " ", 
     RowBox[{"case", ":", " ", 
      RowBox[{
       RowBox[{"For", " ", "c"}], " ", "<", " ", 
       RowBox[{"c1rp", " ", "Full", " ", "targeting"}]}]}]}], ";", " ", 
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"c1rp", ",", "c2rp"}], ")"}], " ", "Medium", " ", 
      "Targeting"}]}]}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2rp", " ", "Exclusive", " ", "Targeting"}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7989540225719995`*^9, 3.79895402307343*^9}, {
  3.7989541118602877`*^9, 
  3.798954116989319*^9}},ExpressionUUID->"9be51503-d6b5-4e4d-8bc9-\
89f3a2c0b0fe"],

Cell["\<\
Case 2: \[Rho] > rhotilderp => c1rp > c3rp > c2rp, c3rp determines targeting\
\>", "Item",
 CellChangeTimes->{{3.7989541234047623`*^9, 3.798954129019453*^9}, {
   3.799397040468783*^9, 3.799397052541752*^9}, 
   3.799732832325124*^9},ExpressionUUID->"0ab36ae1-2ceb-43e1-8c91-\
a2c21b167d79"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c1rp", ">", "c3rp", ">", "c2rp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Rho]", ">", "rhotilderp"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7989541343502445`*^9, 3.7989541433594875`*^9}, {
   3.7995615870387716`*^9, 3.799561587872723*^9}, 3.7997328323407526`*^9, {
   3.799735280501542*^9, 3.7997352816457453`*^9}, 
   3.802691275833742*^9},ExpressionUUID->"2acc072e-f264-4044-b510-\
134efc00991d"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7989541348890657`*^9, 3.7989541436601343`*^9}, 
   3.7989637232566175`*^9, 3.798963777940773*^9, 3.7991393346340947`*^9, 
   3.799377871890458*^9, 3.7993782396231604`*^9, 3.799388978924777*^9, 
   3.7993966015131636`*^9, 3.7994830932197447`*^9, {3.79948368781879*^9, 
   3.7994837171415052`*^9}, 3.799561591328947*^9, 3.7997352821629534`*^9, 
   3.7997453068592353`*^9, 3.800001693626156*^9, 3.8026912760971665`*^9, 
   3.802753822602661*^9, 3.806729428016734*^9, 
   3.8067323640591707`*^9},ExpressionUUID->"eb83e7e2-78f8-4f32-b48d-\
0b1bfbd4c43c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"In", " ", "this", " ", 
    RowBox[{"case", ":", " ", 
     RowBox[{"c", " ", "<", " ", 
      RowBox[{"c3rp", " ", "Full", " ", "Targeting"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", ">", " ", 
     RowBox[{"c3rp", " ", "Exclusive", " ", "Targeting"}]}], ";", " ", 
    RowBox[{"never", " ", "medium", " ", "targeting"}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.798954229874685*^9, 3.7989542322650747`*^9}, {
  3.806729466397648*^9, 
  3.8067294669278965`*^9}},ExpressionUUID->"474f81c6-a9d3-410d-a9ed-\
d1f5fa0b7b09"],

Cell["\<\
Towards assessing the impact: First get generic comparisons given targeting \
behavior pre & post policy introduction\
\>", "Item",
 CellChangeTimes->{{3.7995617438353415`*^9, 3.7995617465419273`*^9}, 
   3.799735408396695*^9},ExpressionUUID->"25b3188c-ae6d-48e6-a6d0-\
0b591fb05d8d"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{" ", "2.", ")"}], " ", "Return", " ", "Policy"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7994835839667673`*^9, 3.799483596189886*^9}, {
  3.799484445458708*^9, 
  3.7994844493473005`*^9}},ExpressionUUID->"d4be9464-2a93-4256-aeab-\
e5937eb22d70"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"A", ":", " ", 
   RowBox[{"Full", " ", "to", " ", "Full"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799483598167594*^9, 3.7994836023244405`*^9}, {
  3.799483722505161*^9, 
  3.7994837235334153`*^9}},ExpressionUUID->"0f2a77c2-53ea-4dd1-85ae-\
2dc78b01ab45"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"qfullrp", "-", "qfull"}], "==", "0"}], ",", 
     RowBox[{
      RowBox[{"pfullrp", "-", "pfull"}], "<", "0"}], ",", 
     RowBox[{
      RowBox[{"cwfullrp", "-", "cwfull"}], ">", "0"}]}], "}"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7994836039451036`*^9, 3.7994837135481186`*^9}, {
   3.799484483566925*^9, 3.799484491454418*^9}, {3.799484541868289*^9, 
   3.799484545940422*^9}, {3.7995617535577407`*^9, 3.799561755147238*^9}, 
   3.8026912823062725`*^9, {3.802753833665313*^9, 
   3.8027538357837057`*^9}},ExpressionUUID->"284fda3d-ed29-4309-8ff1-\
d434b8468357"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.7994836494160156`*^9, 3.7994837191710587`*^9}, {
   3.799484537238679*^9, 3.799484546449111*^9}, {3.799561751350213*^9, 
   3.799561757152401*^9}, 3.7997354131466007`*^9, 3.799735708647509*^9, 
   3.7997453069438515`*^9, 3.8000016936951365`*^9, 3.8026912836264787`*^9, {
   3.8027538276206236`*^9, 3.802753836272561*^9}, 3.8067303485472193`*^9, 
   3.806732364297308*^9},ExpressionUUID->"278a731b-b9be-4445-9689-\
c821efb6abe0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"B", ":", " ", 
   RowBox[{"Full", " ", "to", " ", "Med"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799483727905716*^9, 
  3.799483730438927*^9}},ExpressionUUID->"d303490d-5c9d-44ae-864e-\
720faef2e9ee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"qmedrp", "-", "qfull"}], "<", "0"}], ",", 
     RowBox[{
      RowBox[{"pmedrp", "-", "pfull"}], ">", "0"}], ",", 
     RowBox[{
      RowBox[{"cwmedrp", "-", "cwfull"}], "==", "0"}]}], "}"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.799483736482733*^9, 3.7994837685481744`*^9}, {
   3.799484492763884*^9, 3.7994844959399853`*^9}, {3.7994845652198286`*^9, 
   3.799484568402283*^9}, 3.7995617596373997`*^9, 3.8026912857378063`*^9, {
   3.8027538406499705`*^9, 
   3.802753841267191*^9}},ExpressionUUID->"0269f3ce-a9fe-4e50-b18a-\
1f0358fefc5b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.7994837488808064`*^9, 3.7994837691356015`*^9}, {
   3.7994845615296764`*^9, 3.799484569043586*^9}, 3.7995617600920677`*^9, {
   3.799735414834277*^9, 3.799735417125825*^9}, 3.799735711153453*^9, 
   3.7997453069751234`*^9, 3.800001693726385*^9, 3.8026912859627895`*^9, {
   3.802753829901001*^9, 3.802753841616515*^9}, 
   3.80673236450797*^9},ExpressionUUID->"b3a566e2-54bc-44be-b2d8-\
b5776e3b947f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"C", ":", " ", 
   RowBox[{"Full", " ", "to", " ", "Excl"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799483774722682*^9, 
  3.799483794443741*^9}},ExpressionUUID->"e3531ee6-d57e-4925-8f45-\
3d4ae549cfe4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"qexclrp", "-", "qfull"}], "<", "0"}], ",", 
     RowBox[{
      RowBox[{"pexclrp", "-", "pfull"}], ">", "0"}], ",", 
     RowBox[{
      RowBox[{"cwexclrp", "-", "cwfull"}], "<", "0"}]}], "}"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7994837809220605`*^9, 3.7994837901412477`*^9}, {
   3.7994844980423636`*^9, 3.799484500843862*^9}, 3.799561762299223*^9, 
   3.8026912879693117`*^9, {3.8027538439682736`*^9, 
   3.802753844977138*^9}},ExpressionUUID->"4d58b6fa-17d2-422d-b9b1-\
d80948ec8314"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{3.799483791084699*^9, 3.7994845711270027`*^9, 
  3.79956176271535*^9, 3.7997354205489473`*^9, 3.799735712927307*^9, 
  3.7997453070285234`*^9, 3.8000016937576284`*^9, 3.802691288257079*^9, 
  3.8027538453364315`*^9, 3.8067303535183544`*^9, 
  3.806732364737952*^9},ExpressionUUID->"1d7f403b-def8-4aa8-9fb1-\
02b6762213db"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"D", ":", " ", 
   RowBox[{"Med", " ", "to", " ", "Full"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799483799284389*^9, 
  3.799483802100854*^9}},ExpressionUUID->"3949713b-f8d5-4433-9b0a-\
6a496ca9cede"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"qfullrp", "-", "qmed"}], ">", "0"}], ",", 
     RowBox[{
      RowBox[{"pfullrp", "-", "pmed"}], "<", "0"}], ",", 
     RowBox[{
      RowBox[{"cwfullrp", "-", "cwmed"}], ">", "0"}]}], "}"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.799483807530322*^9, 3.7994838223337083`*^9}, {
   3.799484501856154*^9, 3.7994845040313325`*^9}, 3.7995617649909296`*^9, {
   3.802753848640055*^9, 
   3.8027538495215473`*^9}},ExpressionUUID->"a52a954c-fdba-4b31-8cac-\
ef0b3d51a94f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.799483813497385*^9, 3.799483822662827*^9}, 
   3.799484574139942*^9, 3.7995617653968887`*^9, 3.7997354226866016`*^9, 
   3.7997357159354067`*^9, 3.799745307075399*^9, 3.800001693795394*^9, 
   3.802753849879244*^9, 3.8067303565288105`*^9, 
   3.8067323649573617`*^9},ExpressionUUID->"01b46301-1259-4e85-9f06-\
3f3b8144ce52"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"E", ":", " ", 
    RowBox[{"Med", " ", "to", " ", "Med"}]}], ",", " ", 
   RowBox[{
   "exploit", " ", "that", " ", "lowrhorppossible", " ", "has", " ", "to", 
    " ", "hold"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7994838268267145`*^9, 3.7994838291384974`*^9}, {
  3.8027538586487875`*^9, 
  3.8027538756265593`*^9}},ExpressionUUID->"ee346067-02e0-42dc-babb-\
f40a0eb94f2d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"qmedrp", "-", "qmed"}], "<", "0"}], ",", 
       RowBox[{
        RowBox[{"pmedrp", "-", "pmed"}], ">", "0"}], ",", 
       RowBox[{
        RowBox[{"cwmedrp", "-", "cwmed"}], ">", "0"}]}], "}"}], ",", 
     "assumptions"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"lowrhorppossible", ",", 
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7994838345231185`*^9, 3.799483854436798*^9}, {
   3.799484504931923*^9, 3.799484514344317*^9}, {3.7994845882511964`*^9, 
   3.799484589186692*^9}, {3.799561768262027*^9, 3.7995617763514023`*^9}, {
   3.799735464438695*^9, 3.7997354836084723`*^9}, 3.8026912925464516`*^9, {
   3.802753854320692*^9, 3.8027538976239595`*^9}, {3.8067303870124245`*^9, 
   3.8067303878679986`*^9}},ExpressionUUID->"6b145bc4-29f9-4faf-9ef3-\
6f4edf41f1db"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "+", "\[Mu]"}], "<", "1"}], ",", "True"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.799483851556512*^9, 3.799483854758984*^9}, {
   3.799484580617594*^9, 3.799484589600565*^9}, {3.799561768569539*^9, 
   3.7995617767525897`*^9}, {3.799735465541413*^9, 3.799735484009644*^9}, 
   3.799735717740058*^9, 3.79974530714443*^9, 3.8000016938443823`*^9, 
   3.802691292860858*^9, 3.8027538555517383`*^9, 3.802753898224119*^9, 
   3.8067303643173337`*^9, 3.806730484266219*^9, 
   3.8067323652026167`*^9},ExpressionUUID->"1ae5ae77-475d-47f4-97c0-\
ac3874871cc7"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"\[CapitalDelta]p", " ", "ambiguous"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8027543744191093`*^9, 
  3.8027543792481785`*^9}},ExpressionUUID->"acd2a6bd-463a-42ec-aa19-\
c78dc252ecef"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"F", ":", " ", 
   RowBox[{"Med", " ", "to", " ", "Excl"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7994838588589644`*^9, 
  3.799483862098297*^9}},ExpressionUUID->"5b35d1d3-2de1-4991-b7a3-\
dcbcc50c28e7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"qexclrp", "-", "qmed"}], "<", "0"}], ",", 
     RowBox[{
      RowBox[{"pexclrp", "-", "pmed"}], ">", "0"}], ",", 
     RowBox[{
      RowBox[{"cwexclrp", "-", "cwmed"}], "==", "0"}]}], "}"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.799483869602216*^9, 3.7994838840216284`*^9}, {
   3.799484516540464*^9, 3.799484518821359*^9}, {3.799484602099138*^9, 
   3.799484608106063*^9}, 3.799561792465751*^9, 3.802691294858144*^9, {
   3.802754389473316*^9, 
   3.8027543902498612`*^9}},ExpressionUUID->"8db0e3bd-0ac0-42cc-8cd2-\
1b8d82990a76"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.7994838771101236`*^9, 3.7994838844136252`*^9}, {
   3.799484599164991*^9, 3.799484608464224*^9}, {3.7995617910313373`*^9, 
   3.799561792835727*^9}, 3.799735720667164*^9, 3.799745307197855*^9, 
   3.8000016938756237`*^9, 3.8026912951242895`*^9, {3.8027543828059053`*^9, 
   3.8027543906134987`*^9}, 3.8067303906879387`*^9, 
   3.806732365428007*^9},ExpressionUUID->"676f3784-6a17-468b-9d99-\
a50972cfa79f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"G", ":", " ", 
   RowBox[{"Excl", " ", "to", " ", "Full"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7994838877945614`*^9, 3.7994838909959955`*^9}, {
  3.7994839534507236`*^9, 
  3.799483953753913*^9}},ExpressionUUID->"a3e52c3e-a179-4a5b-95c9-\
730e2ce32455"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"qfullrp", "-", "qexcl"}], ">", "0"}], ",", 
     RowBox[{
      RowBox[{"pfullrp", "-", "pexcl"}], "<", "0"}], ",", 
     RowBox[{
      RowBox[{"cwfullrp", "-", "cwexcl"}], ">", "0"}]}], "}"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7994838989616475`*^9, 3.7994839092504883`*^9}, {
   3.7994845201437902`*^9, 3.7994845226800346`*^9}, 3.7995617964454575`*^9, 
   3.802691297337187*^9, {3.8027543933283467`*^9, 
   3.8027543947208853`*^9}},ExpressionUUID->"f464fdff-7fdb-482e-951c-\
5b68e0fae34d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{3.799483909801014*^9, 3.799484614468009*^9, 
  3.7995617967461863`*^9, 3.7997357227324085`*^9, 3.799745307244753*^9, 
  3.800001693910922*^9, 3.8026912975667396`*^9, 3.802754395053238*^9, 
  3.8067303930071664`*^9, 3.8067304875067005`*^9, 
  3.8067323656586027`*^9},ExpressionUUID->"d6172909-5379-4e7c-a06b-\
a005bcc4c828"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"H", ":", " ", 
   RowBox[{"Excl", " ", "to", " ", "Med"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799483918531684*^9, 3.7994839211078215`*^9}, {
  3.7994839553227167`*^9, 
  3.799483955578032*^9}},ExpressionUUID->"3ebeaad2-d0f0-4ec7-b54e-\
7a93517ff7cf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"qmedrp", "-", "qexcl"}], ">", "0"}], ",", 
       RowBox[{"Reduce", "[", 
        RowBox[{
         RowBox[{"pmedrp", "-", "pexcl"}], ">", "0"}], "]"}], ",", 
       RowBox[{
        RowBox[{"cwmedrp", "-", "cwexcl"}], ">", "0"}]}], "}"}], ",", 
     "assumptions"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"lowrhorppossible", ",", 
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.79948392322715*^9, 3.799483941197515*^9}, {
   3.7994845239406605`*^9, 3.7994845268129745`*^9}, {3.7994846204988995`*^9, 
   3.7994846209307375`*^9}, {3.7995617993460646`*^9, 3.799561806683812*^9}, {
   3.799735704197744*^9, 3.7997357049846373`*^9}, 3.8026913008731604`*^9, {
   3.802754398673109*^9, 
   3.8027544337038865`*^9}},ExpressionUUID->"73eed31d-bb78-4233-bdfe-\
9d399a1e9b06"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", 
   RowBox[{"\[Mu]", "<", 
    RowBox[{"1", "+", 
     RowBox[{"\[Alpha]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "\[Mu]"}], ")"}]}]}]}], ",", "True"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.799483932528684*^9, {3.7994846165255055`*^9, 3.7994846212867675`*^9}, {
   3.7995617996524706`*^9, 3.7995618070693264`*^9}, {3.799735705407894*^9, 
   3.7997357248230066`*^9}, 3.7997453075611787`*^9, 3.800001694142749*^9, 
   3.8026913011168118`*^9, {3.8027544000040627`*^9, 3.802754434176025*^9}, 
   3.806730394949433*^9, 
   3.8067323660084887`*^9},ExpressionUUID->"ba138da5-b03a-44e0-84f7-\
aa8e94a4fad1"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"\[CapitalDelta]p", " ", "ambiguous"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.802754440402996*^9, 
  3.802754444464075*^9}},ExpressionUUID->"8fe333df-ad0c-442e-abe9-\
b6010c7452d6"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"I", ":", " ", 
   RowBox[{"Excl", " ", "to", " ", "Excl"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799483950226322*^9, 
  3.7994839613695335`*^9}},ExpressionUUID->"b9f5c125-e834-4754-ba9f-\
89e4c42f95cc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Reduce", "[", 
      RowBox[{
       RowBox[{"qexclrp", "-", "qexcl"}], "<", "0"}], "]"}], ",", 
     RowBox[{
      RowBox[{"pexclrp", "-", "pexcl"}], ">", "0"}], ",", 
     RowBox[{
      RowBox[{"cwexclrp", "-", "cwexcl"}], ">", "0"}]}], "}"}], ",", 
   "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.79948396552242*^9, 3.7994839796358256`*^9}, {
   3.7994845282700443`*^9, 3.799484531969743*^9}, {3.799484628467575*^9, 
   3.7994846295217237`*^9}, 3.799561812129606*^9, {3.8026913033218975`*^9, 
   3.802691311840756*^9}, {3.802754450833596*^9, 
   3.8027544588489933`*^9}},ExpressionUUID->"faa689ee-58bf-423b-a41c-\
235a83e2fa0b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Mu]", "+", 
     RowBox[{"2", " ", "\[Rho]"}]}], "<", 
    RowBox[{"1", "+", 
     RowBox[{"\[Mu]", " ", "\[Rho]"}]}]}], ",", "True", ",", "True"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.799483979981366*^9, {3.7994846247056417`*^9, 3.7994846302956696`*^9}, 
   3.7995618129852505`*^9, 3.799735727668137*^9, 3.799745307977832*^9, 
   3.8000016944124594`*^9, 3.8026913122516623`*^9, {3.802754447343904*^9, 
   3.8027544592818985`*^9}, 3.80673049006777*^9, 
   3.8067323662979207`*^9},ExpressionUUID->"02a7b89b-7aaf-44f1-8c66-\
f0d645844339"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"\[CapitalDelta]q", " ", "ambiguous"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8027544604028807`*^9, 
  3.8027544660713425`*^9}},ExpressionUUID->"ad70fe85-097a-40f6-9990-\
c0a545431176"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"\[CapitalDelta]p", ",", " ", 
   RowBox[{
    RowBox[{
    "\[CapitalDelta]q", " ", "and", " ", "\[CapitalDelta]CW", " ", 
     "generically", " ", "signed", " ", "except", " ", "for", " ", "Quantity",
      " ", "when", " ", "Excl"}], "\[Rule]", 
    RowBox[{
     RowBox[{"Excl", " ", "and", " ", "Price", " ", "when", " ", 
      RowBox[{"Med", "/", "Excl"}]}], "\[Rule]", "Med"}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7995618505857906`*^9, 3.7995618578903956`*^9}, {
  3.799735736207307*^9, 3.7997357600740895`*^9}, {3.806730515218128*^9, 
  3.8067305365572195`*^9}},ExpressionUUID->"43aa664c-2ed9-40ed-8b65-\
d0a5a8a13c36"],

Cell[" Impact of RP", "Item",
 CellChangeTimes->{{3.7989637737588615`*^9, 
  3.7989637757649717`*^9}},ExpressionUUID->"58f35464-6d41-4c2b-bc4f-\
19a243a9716b"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Obtain", " ", "ordering", " ", "of", " ", "\[Rho]"}], "-", 
   "threshodls"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997357683976746`*^9, 
  3.7997357747947474`*^9}},ExpressionUUID->"12290bc7-3712-4eeb-b372-\
023c53f4cee5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"rhotilde", ">", "rhotilderp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7995616022244415`*^9, 3.799561619260132*^9}, {
  3.799732832356372*^9, 
  3.799732832372013*^9}},ExpressionUUID->"58315453-adfe-47d0-a083-\
143e3d32a629"],

Cell[BoxData[
 RowBox[{
  RowBox[{"1", "+", 
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         RowBox[{"2", " ", "\[Mu]"}], "+", 
         SqrtBox[
          RowBox[{"5", "+", 
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", "\[Mu]"}], ")"}], " ", "\[Mu]"}]}]]}], 
        ")"}]}]}], ")"}]}]}], ">", 
  SqrtBox[
   RowBox[{"5", "+", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "\[Mu]"}], ")"}], " ", 
     "\[Mu]"}]}]]}]], "Output",
 CellChangeTimes->{{3.7995616097454977`*^9, 3.7995616203587914`*^9}, 
   3.7995618648090925`*^9, 3.7997357778337107`*^9, 3.7997453088014793`*^9, 
   3.8000016949761405`*^9, 3.802691316081188*^9, 3.8027544709683776`*^9, 
   3.8067307589438477`*^9, 
   3.806732367068121*^9},ExpressionUUID->"7e743743-cb9d-432e-be6a-\
7c142ba3fec9"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"No", " ", "generic", " ", "ordering", " ", "possible"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7997357791785603`*^9, 
  3.799735782918454*^9}},ExpressionUUID->"e6166c77-8745-431b-86fe-\
f57d76012346"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Get", " ", "critical", " ", "\[Alpha]", " ", "so", " ", "that", " ", 
   "\[Alpha]", " ", "relative", " ", "to", " ", "threshold", " ", 
   "alphatilde", " ", "determined", " ", "relative", " ", "ordering"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7997383070974255`*^9, 
  3.799738343555296*^9}},ExpressionUUID->"7c6bb948-2eee-421f-bfc4-\
b41208639945"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alphatilde", "=", 
  RowBox[{"\[Alpha]", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"rhotilde", "==", "rhotilderp"}], ",", "\[Alpha]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.798963788744445*^9, 3.798963800882249*^9}, {
   3.7989638548118*^9, 3.798963876887145*^9}, {3.799732832372013*^9, 
   3.799732832372013*^9}, {3.799738234442202*^9, 3.7997382419580636`*^9}, {
   3.7997382858676224`*^9, 3.7997382939268913`*^9}, 
   3.799738328128052*^9},ExpressionUUID->"4ef3603f-4753-4d52-bbba-\
0e5c013caf56"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   SqrtBox[
    RowBox[{"5", "-", 
     RowBox[{"8", " ", "\[Mu]"}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["\[Mu]", "2"]}]}]]}], 
  RowBox[{"2", "-", 
   RowBox[{"5", " ", "\[Mu]"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["\[Mu]", "2"]}], "+", 
   RowBox[{"\[Mu]", " ", 
    SqrtBox[
     RowBox[{"5", "-", 
      RowBox[{"8", " ", "\[Mu]"}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[Mu]", "2"]}]}]]}]}]]], "Output",
 CellChangeTimes->{{3.79896379513444*^9, 3.798963801367828*^9}, {
   3.7989638724607525`*^9, 3.798963877473271*^9}, 3.799139334718717*^9, 
   3.799377871990697*^9, 3.799378239707775*^9, 3.7993889789896035`*^9, 
   3.799396601646332*^9, 3.7994830934251966`*^9, {3.7994836879454803`*^9, 
   3.7994837172661996`*^9}, 3.7995616240580897`*^9, 3.7995618676151085`*^9, {
   3.7997382390564723`*^9, 3.799738294279108*^9}, 3.79973834632495*^9, 
   3.7997453091793413`*^9, 3.8000016951924*^9, 3.8026913203353786`*^9, 
   3.8027544734744225`*^9, 3.806730761925168*^9, 
   3.806732367368605*^9},ExpressionUUID->"55ab99fc-43b2-4026-8cc8-\
f1656dd8314b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Check", " ", "that", " ", "interior"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.79973835029056*^9, 
  3.799738355905802*^9}},ExpressionUUID->"76cef099-002e-4b67-a712-\
1734b99ff8d8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"1", ">", "alphatilde", ">", "0"}], ",", 
   RowBox[{"1", ">", "\[Mu]", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.799561626611455*^9, 3.799561641775893*^9}, {
  3.799738245621828*^9, 
  3.799738328128052*^9}},ExpressionUUID->"73d64ccb-f95b-45b1-b69c-\
319f1840b2b2"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.799561642277319*^9, 3.799561869135313*^9, {3.799738249302763*^9, 
   3.7997383038876143`*^9}, 3.799738348014613*^9, 3.7997453096627197`*^9, 
   3.800001695431009*^9, 3.8026913220325623`*^9, 3.802754477214927*^9, 
   3.806730765773592*^9, 
   3.8067323676295705`*^9},ExpressionUUID->"d0a93727-595a-43ff-b532-\
c5b4c174fd87"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Check", " ", "that", " ", "\[Alpha]", " ", "relative", " ", "to", " ", 
   "alphatilde", " ", "determines", " ", "ordering"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997383587458463`*^9, 
  3.7997383669555254`*^9}},ExpressionUUID->"34cfde63-cf76-4a58-99ac-\
a1201f34818f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"rhotilde", ">", "rhotilderp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "alphatilde"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7989638813686066`*^9, 3.79896389769808*^9}, {
   3.7995616490751953`*^9, 3.799561653641695*^9}, {3.7997328323876143`*^9, 
   3.7997328323876143`*^9}, 3.799738328128052*^9, {3.802754491680689*^9, 
   3.802754497344584*^9}},ExpressionUUID->"44483e94-29e8-45bc-8bec-\
b2751a1d86a6"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.798963894365091*^9, 3.7989638980143013`*^9}, 
   3.7991393347343388`*^9, 3.79937787202194*^9, 3.7993782397233963`*^9, 
   3.7993889790085535`*^9, 3.7993966016880474`*^9, 3.799483093506496*^9, {
   3.7994836879783707`*^9, 3.799483717297118*^9}, {3.7995616459353886`*^9, 
   3.7995616541116085`*^9}, 3.7995618708438325`*^9, 3.7997383703107333`*^9, 
   3.7997453100242367`*^9, 3.800001695678422*^9, 3.802691324362911*^9, {
   3.802754481078888*^9, 3.8027544978288145`*^9}, 3.806730767895208*^9, 
   3.8067323679683084`*^9},ExpressionUUID->"0f6ace6a-d73f-428c-875a-\
a1060ffd8c49"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"rhotilde", "<", "rhotilderp"}], ",", 
   RowBox[{"0", "<", "\[Alpha]", "<", "alphatilde"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.798963902071555*^9, 3.7989639072385645`*^9}, {
   3.7997328323876143`*^9, 3.7997328323876143`*^9}, 
   3.799738328143673*^9},ExpressionUUID->"c5e27224-32b1-47b7-b7ac-\
19be4b8bf5aa"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7989639075390778`*^9, 3.799139334772205*^9, 3.7993778720596952`*^9, 
   3.7993782397546387`*^9, 3.7993889790265055`*^9, 3.799396601735414*^9, 
   3.7994830935982504`*^9, {3.7994836880112753`*^9, 3.7994837173280344`*^9}, 
   3.7995616594739275`*^9, 3.7995618724652367`*^9, 3.7997383719519644`*^9, 
   3.7997453103782916`*^9, 3.800001695947322*^9, 3.8026913251930513`*^9, {
   3.802754489367175*^9, 3.8027545000724792`*^9}, 3.806730770275194*^9, 
   3.806732368206147*^9},ExpressionUUID->"bc4bea8b-755e-4b8f-8613-\
830d1ff4beab"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Now characterize Impact for different cases on \[Alpha] and \[Rho]", \
"Item",
 CellChangeTimes->{{3.7997383900317287`*^9, 
  3.7997383975846972`*^9}},ExpressionUUID->"d6d93089-aa83-4473-b0f9-\
97284af3384a"],

Cell[" Case 1: \[Alpha] < alphatilde which implies rhotilde < rhotilderp", \
"Item",
 CellChangeTimes->{{3.7989639183824325`*^9, 3.7989639290795507`*^9}, {
   3.799732832418866*^9, 3.799732832525627*^9}, 
   3.799738328162114*^9},ExpressionUUID->"48a8af9d-b249-4d77-b151-\
38d041bed4bc"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"1", 
    RowBox[{"a", ":", " ", 
     RowBox[{"\[Rho]", " ", "<", " ", "rhotilde", " ", "<", " ", 
      RowBox[{
       RowBox[{"rhotilderp", ".", " ", "c3"}], " ", "determines", " ", 
       "pricing", " ", "in", " ", "baseline"}]}]}]}], ",", " ", 
   RowBox[{
   "c1rp", " ", "and", " ", "c2rp", " ", "in", " ", "return", " ", 
    "policy"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.798963936376196*^9, 3.798964006174696*^9}, {
  3.79896430019007*^9, 3.798964301979253*^9}, {3.799380636895667*^9, 
  3.79938064447112*^9}, {3.7993816046733775`*^9, 3.7993816440412674`*^9}, {
  3.7997328325412536`*^9, 
  3.7997328325412536`*^9}},ExpressionUUID->"acc14d0b-ad3b-4c51-a507-\
ededbc721e4a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c3", ">", "c1rp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0", "<", "\[Alpha]", "<", "alphatilde"}], ",", 
     RowBox[{"0", "<", "\[Rho]", "<", "rhotilde"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.798964010285344*^9, 3.7989640375404773`*^9}, {
   3.799380992946585*^9, 3.7993810149892917`*^9}, {3.799381647635922*^9, 
   3.7993816478677015`*^9}, {3.7995616692727957`*^9, 3.799561670861987*^9}, {
   3.7997328325412536`*^9, 3.7997328325412536`*^9}, 3.799738328162114*^9, {
   3.8027545104407897`*^9, 
   3.8027545163278556`*^9}},ExpressionUUID->"00a82675-7090-478e-876e-\
d7fdd0a9e75f"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7989640319951887`*^9, 3.7989640380104375`*^9}, 
   3.7991393347878504`*^9, 3.7993778721065607`*^9, 3.799378239776764*^9, {
   3.799380993532015*^9, 3.7993810154901257`*^9}, 3.7993816481526365`*^9, 
   3.79938897909233*^9, 3.79939660212337*^9, 3.7994830941433115`*^9, {
   3.799483688068122*^9, 3.7994837173858843`*^9}, {3.7995616673053017`*^9, 
   3.7995616714857903`*^9}, 3.7995618756520305`*^9, 3.799738408307023*^9, 
   3.7997385394625993`*^9, 3.799745311189189*^9, 3.8000016969028435`*^9, 
   3.802691327766801*^9, {3.802754507098862*^9, 3.8027545168707876`*^9}, 
   3.8067307770840025`*^9, 
   3.8067323688384323`*^9},ExpressionUUID->"c40eadf9-6996-46fe-8865-\
542386f072b0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c3", ">", "c2rp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0", "<", "\[Alpha]", "<", "alphatilde"}], ",", 
     RowBox[{"0", "<", "\[Rho]", "<", "rhotilde", "<", "rhotilderp"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.799381227178068*^9, 3.79938124314931*^9}, {
   3.7993816521786475`*^9, 3.7993816615551353`*^9}, {3.7995616797076674`*^9, 
   3.799561694016466*^9}, {3.7997328325568743`*^9, 3.7997328325568743`*^9}, 
   3.799738328177737*^9, {3.802691333506793*^9, 3.8026913511287394`*^9}, {
   3.802754532065587*^9, 3.802754554368807*^9}, {3.806732469128909*^9, 
   3.8067324717675476`*^9}, {3.8067325111375666`*^9, 
   3.8067325319678106`*^9}, {3.8067325654791746`*^9, 
   3.806732566819401*^9}},ExpressionUUID->"384d2caa-d1b0-4074-a98c-\
3c097787984f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalDelta]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[Mu]", "+", 
     RowBox[{"\[Alpha]", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Mu]", "+", 
        FractionBox["1", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}]], "+", 
        FractionBox["1", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]", "-", 
          RowBox[{"\[Mu]", " ", "\[Rho]"}]}]]}], ")"}]}]}], ")"}]}], ">", 
  "0"}]], "Output",
 CellChangeTimes->{{3.799381229900615*^9, 3.799381243371504*^9}, {
   3.7993816534976406`*^9, 3.799381662056363*^9}, 3.799388979250908*^9, 
   3.7993966028155084`*^9, 3.7994830948847303`*^9, {3.7994836881030283`*^9, 
   3.799483717420757*^9}, {3.7995616809747725`*^9, 3.799561694844224*^9}, 
   3.799561877297728*^9, 3.799738411337452*^9, 3.799738541620599*^9, 
   3.7997453121924353`*^9, 3.8000016979623604`*^9, {3.802691330142971*^9, 
   3.802691366762113*^9}, 3.802754525398383*^9, 3.8027545673801947`*^9, 
   3.80673077969567*^9, 3.806732369838504*^9, {3.8067324978271294`*^9, 
   3.8067325269475513`*^9}, {3.806732558378086*^9, 
   3.806732567618124*^9}},ExpressionUUID->"d5e8e8aa-8ec1-41fc-ab94-\
11dcd54c2b97"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Two", " ", "possible", " ", "scenarios"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7989641029463034`*^9, 
  3.798964112534685*^9}},ExpressionUUID->"2137ff33-c735-4b60-9170-\
2aea39190d44"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"1.", 
    RowBox[{"a", ".", 
     RowBox[{"i", ":", "  ", 
      RowBox[{"c3", " ", ">", " ", "c2rp", " ", ">", " ", 
       RowBox[{"c1rp", ".", " ", "c"}], " ", "<", " ", "c1rp"}], ":", " ", 
      RowBox[{"Full", " ", "in", " ", "Both"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1rp", ",", "c2rp"}], ")"}]}], ":", " ", 
    RowBox[{"Full", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Medium", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1rp", ",", "c3"}], ")"}]}], ":", " ", 
    RowBox[{"Full", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Exclusive", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c3", ":", " ", 
     RowBox[{"Exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.79896411447841*^9, 3.7989642211668906`*^9}, {
  3.7993816705623507`*^9, 3.7993816735319214`*^9}, {3.7997385477659636`*^9, 
  3.7997385542437944`*^9}},ExpressionUUID->"7ce9de8a-47e7-411a-9677-\
37456e7c092d"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"1.", 
    RowBox[{"a", ".", 
     RowBox[{"ii", ":", " ", 
      RowBox[{"c2rp", " ", ">", " ", "c3", " ", ">", " ", 
       RowBox[{"c1rp", ".", " ", "c"}], " ", "<", " ", "c1rp"}], ":", " ", 
      RowBox[{"Full", " ", "in", " ", "Both"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1rp", ",", "c3"}], ")"}]}], ":", " ", 
    RowBox[{"Full", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Medium", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c3", ",", "c2rp"}], ")"}]}], ":", " ", 
    RowBox[{"Exclusive", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Medium", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2rp", ":", " ", 
     RowBox[{"Exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.798964213377534*^9, 
  3.79896425239201*^9}},ExpressionUUID->"9e370b45-79bd-4a0b-9bce-\
80a7cd53a9a1"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "Check", " ", "whether", " ", "quantity", " ", "comparison", " ", "given", 
    " ", "for", " ", "Excl"}], " ", "\[Rule]", " ", "Excl"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7997386055605335`*^9, 3.7997386199875917`*^9}, {
  3.799738978588485*^9, 
  3.7997389796060233`*^9}},ExpressionUUID->"183cf63d-15d1-4477-9a3d-\
3672acd847d0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"qexcl", ">", "qexclrp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"alphatilde", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"0", "<", "\[Rho]", "<", "rhotilde"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.79948312564632*^9, 3.7994831482143087`*^9}, 
   3.7995617024185762`*^9, 3.7997328325568743`*^9, 
   3.799738328177737*^9},ExpressionUUID->"35ff71a9-ad94-4a96-be1d-\
fc5f9dc166c5"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.799483148815685*^9, {3.799483688200737*^9, 3.799483717515315*^9}, {
   3.799561700242592*^9, 3.799561702856678*^9}, 3.799561881086753*^9, 
   3.7997386222087708`*^9, 3.799745312826456*^9, 3.800001698236974*^9, 
   3.80269136897983*^9, 3.8027545735396943`*^9, 3.8067307829444847`*^9, 
   3.806732370238385*^9},ExpressionUUID->"c4119b02-5750-4b99-8390-\
3330bb1acbcc"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "Check", " ", "whether", " ", "price", " ", "comparison", " ", "given", 
    " ", "for", " ", "Excl"}], " ", "\[Rule]", " ", "Med"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7993819986100087`*^9, 3.7993820000771646`*^9}, 
   3.799738657726293*^9, {3.7997387665471363`*^9, 3.79973876691704*^9}, {
   3.799738798625016*^9, 
   3.799738799194916*^9}},ExpressionUUID->"8b0c5c1d-a4e9-456b-969c-\
35c901371303"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Reduce", "[", 
    RowBox[{
     RowBox[{"pexcl", "<", "pmedrp"}], "/.", 
     RowBox[{"\[Alpha]", "\[Rule]", "alphatilde"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0", "<", "\[Rho]", "<", "rhotilde"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7993820055595036`*^9, 3.7993820078968267`*^9}, {
   3.7995618906282597`*^9, 3.7995618963907337`*^9}, 3.7997383281933565`*^9, 
   3.7997386671302614`*^9, {3.8026913728659625`*^9, 3.8026913801129684`*^9}, {
   3.8027546369775643`*^9, 3.8027546401287317`*^9}, {3.8027548167537527`*^9, 
   3.802754822536174*^9}},ExpressionUUID->"4cce0a16-9921-42c0-b279-\
746ef4c1819d"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{
  3.7993820085989428`*^9, 3.7993889793446627`*^9, 3.799396603029106*^9, 
   3.7994830952916193`*^9, {3.7994836883174286`*^9, 3.7994837176220336`*^9}, {
   3.7995618867635684`*^9, 3.799561897029912*^9}, 3.7997386685271316`*^9, 
   3.799738802969223*^9, 3.799745313143577*^9, 3.800001698468808*^9, 
   3.802691380443264*^9, 3.8027545776718664`*^9, 3.80275464072447*^9, 
   3.8027548229691296`*^9, 3.806730785655486*^9, 3.8067308256477623`*^9, 
   3.806732370499789*^9},ExpressionUUID->"c736d3ed-4015-4eaf-b6b7-\
717e894a7bf9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Reduce", "[", 
    RowBox[{
     RowBox[{"pexcl", "<", "pmedrp"}], "/.", 
     RowBox[{"\[Alpha]", "\[Rule]", "0"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0", "<", "\[Rho]", "<", "rhotilde"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.802754831983364*^9, 
  3.802754836351636*^9}},ExpressionUUID->"fa24f395-03f1-4d1b-b744-\
ccc5205a145c"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.802754832780657*^9, 3.8027548374623747`*^9}, 
   3.806730787765413*^9, 3.80673082766823*^9, 
   3.806732370708995*^9},ExpressionUUID->"5bb4ec20-ab16-499b-9127-\
bdb937326790"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"\[CapitalDelta]p", " ", "ambiguous"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.802754842195673*^9, 
  3.802754865023467*^9}},ExpressionUUID->"61d970d6-e5d0-42e5-88ea-\
6c89ab9f7849"],

Cell[BoxData[
 RowBox[{"(*", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7989642614712563`*^9, 
  3.798964269927886*^9}},ExpressionUUID->"83303b85-9335-4308-ac9a-\
dffff72f54f5"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"1", 
    RowBox[{"b", ":", " ", 
     RowBox[{"rhotilderp", " ", ">", " ", "\[Rho]", " ", ">", " ", 
      RowBox[{
       RowBox[{"rhotilde", ".", " ", "c1"}], " ", "and", " ", "c2", " ", 
       "determine", " ", "pricing", " ", "in", " ", "baseline"}]}]}]}], ",", 
   " ", 
   RowBox[{
   "c1rp", " ", "and", " ", "c2rp", " ", "in", " ", "return", " ", 
    "policy"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7989642723861036`*^9, 3.7989643124835386`*^9}, {
  3.7997328325724955`*^9, 
  3.7997328325724955`*^9}},ExpressionUUID->"e6eda3e8-5554-441b-8642-\
80020412faf1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c2", ">", "c1", ">", "c1rp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0", "<", "\[Alpha]", "<", "alphatilde"}], ",", 
     RowBox[{"rhotilde", "<", "\[Rho]", "<", "rhotilderp"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.798966887617524*^9, 3.798966923390687*^9}, 
   3.7995619146423187`*^9, {3.7997328325881186`*^9, 3.7997328325881186`*^9}, 
   3.7997383281933565`*^9, 
   3.8026913854829288`*^9},ExpressionUUID->"4f98869f-f8a8-4d50-8dd2-\
5d1fc0612df9"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7989669089924836`*^9, 3.79896691824594*^9}, 
   3.7989669497988997`*^9, 3.7991393350732017`*^9, 3.799377872607766*^9, 
   3.7993782398926244`*^9, 3.7993889794354143`*^9, 3.799396603202262*^9, 
   3.7994830957528996`*^9, {3.799483688425171*^9, 3.799483717733736*^9}, {
   3.799561913590753*^9, 3.799561915290985*^9}, 3.799738686036072*^9, 
   3.7997453136562185`*^9, 3.8000016987227297`*^9, {3.802691383516057*^9, 
   3.802691386081129*^9}, 3.802754867746371*^9, 3.80673083089714*^9, 
   3.8067323718992567`*^9},ExpressionUUID->"0cac3f77-10fc-4205-a864-\
0805d1de67ff"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c2rp", ">", "c1"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0", "<", "\[Alpha]", "<", "alphatilde"}], ",", 
     RowBox[{"rhotilde", "<", "\[Rho]", "<", "rhotilderp"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.798966931435647*^9, 3.7989669366506042`*^9}, 
   3.79956191765092*^9, {3.7997328325881186`*^9, 3.7997328326037393`*^9}, 
   3.7997383282089787`*^9, {3.8026913885050874`*^9, 
   3.802691410032292*^9}},ExpressionUUID->"1ba2bed2-9086-4285-bd14-\
2036c4824af7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"1", "+", 
   RowBox[{"\[Mu]", " ", "\[Rho]"}]}], ">", 
  RowBox[{"\[Alpha]", "+", "\[Mu]", "+", "\[Rho]"}]}]], "Output",
 CellChangeTimes->{{3.798966932384757*^9, 3.79896693701417*^9}, 
   3.799139335173374*^9, 3.7993778727770233`*^9, 3.799378239908246*^9, 
   3.799388979484284*^9, 3.799396603591241*^9, 3.7994830961066875`*^9, {
   3.79948368846017*^9, 3.7994837177686377`*^9}, 3.7995619182524996`*^9, 
   3.7997386881868467`*^9, 3.7997453142607136`*^9, 3.80000169908613*^9, 
   3.802691410306387*^9, 3.8027548720554*^9, 3.8067308325378294`*^9, 
   3.8067323727294607`*^9},ExpressionUUID->"f0da6dd2-7cb9-43f5-849e-\
e9129a8f78ba"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c2rp", ">", "c2"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0", "<", "\[Alpha]", "<", "alphatilde"}], ",", 
     RowBox[{"rhotilde", "<", "\[Rho]", "<", "rhotilderp"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7989669575520077`*^9, 3.798966957652445*^9}, 
   3.7995619205898724`*^9, {3.7997328326037393`*^9, 3.7997328326037393`*^9}, 
   3.79973832821249*^9, 
   3.802691415257859*^9},ExpressionUUID->"f4336064-565a-4e07-b4bc-\
753ea2c2edda"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Alpha]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], "2"], " ", "\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], "2"]}], "-", "\[Rho]"}], 
    ")"}]}], ">", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], " ", "\[Rho]"}]}]], "Output",
 CellChangeTimes->{
  3.798966958137752*^9, 3.7991393352892914`*^9, 3.799377872939746*^9, 
   3.799378239939489*^9, 3.7993889796189237`*^9, 3.799396603962253*^9, 
   3.7994830964886665`*^9, {3.7994836884999495`*^9, 3.799483717805507*^9}, 
   3.7995619219087324`*^9, 3.7997386909784365`*^9, 3.799745315221507*^9, 
   3.8000016999025335`*^9, {3.802691413724169*^9, 3.802691416259762*^9}, 
   3.8027548747234325`*^9, 
   3.8067323743795166`*^9},ExpressionUUID->"b7a1ee64-0eaf-457c-8aac-\
9f30578cd6ea"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Three", " ", "possible", " ", "scenarios"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.798967047378128*^9, 
  3.798967047995493*^9}},ExpressionUUID->"5dfa3757-82b0-43cb-83e4-\
66133e456ec1"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"1.", 
    RowBox[{"b", ".", 
     RowBox[{"i", ":", "    ", 
      RowBox[{"c2rp", " ", ">", " ", "c2", " ", ">", " ", "c1", " ", ">", " ", 
       RowBox[{"c1rp", ".", " ", "c"}], " ", "<", " ", "c1rp"}], ":", " ", 
      RowBox[{"Full", " ", "in", " ", "Both"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1rp", ",", "c1"}], ")"}]}], ":", " ", 
    RowBox[{"Full", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Medium", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1", ",", "c2"}], ")"}]}], ":", " ", 
    RowBox[{"Medium", " ", "Pre", " ", "and", " ", "Post"}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c2", ",", "c2rp"}], ")"}]}], ":", " ", 
    RowBox[{"Exclusive", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Medium", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2rp", ":", " ", 
     RowBox[{"exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.798967057839574*^9, 
  3.798967133874832*^9}},ExpressionUUID->"9b329f2e-c081-4729-9d98-\
d13c1b7e42c4"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"1.", 
    RowBox[{"b", ".", 
     RowBox[{"ii", ":", "   ", 
      RowBox[{"c2", " ", ">", " ", "c2rp", " ", ">", " ", "c1", " ", ">", " ", 
       RowBox[{"c1rp", ".", " ", "c"}], " ", "<", " ", 
       RowBox[{"c1rp", ":", " ", 
        RowBox[{"Full", " ", "in", " ", "Both"}]}]}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1rp", ",", "c1"}], ")"}]}], ":", " ", 
    RowBox[{"Full", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Medium", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1", ",", "c2rp"}], ")"}]}], ":", " ", 
    RowBox[{"Medium", " ", "Pre", " ", "and", " ", "Post"}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c2rp", ",", "c2"}], ")"}]}], ":", " ", 
    RowBox[{"Medium", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Exclusive", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2", ":", " ", 
     RowBox[{"exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.798967116023261*^9, 
  3.7989671777772036`*^9}},ExpressionUUID->"9b2db124-c303-4dc5-8d39-\
6ffceb681f4f"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"1.", 
    RowBox[{"b", ".", 
     RowBox[{"iii", ":", "  ", 
      RowBox[{"c2", " ", ">", " ", "c1", " ", ">", " ", "c2rp", " ", ">", " ", 
       RowBox[{"c1rp", ".", " ", "c"}], " ", "<", " ", "c1rp"}], ":", " ", 
      RowBox[{"Full", " ", "in", " ", "Both"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1rp", ",", "c2rp"}], ")"}]}], ":", " ", 
    RowBox[{"Full", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Medium", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c2rp", ",", "c1"}], ")"}]}], ":", " ", 
    RowBox[{"Full", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Exclusive", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1", ",", "c2"}], ")"}]}], ":", " ", 
    RowBox[{"Medium", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Exclusive", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2", ":", " ", 
     RowBox[{"exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.798967117596305*^9, 3.798967131020574*^9}, {
  3.7989671826272297`*^9, 
  3.7989672254578753`*^9}},ExpressionUUID->"aa8233bc-57e6-4bb0-afc3-\
951087219b65"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Check", " ", "\[CapitalDelta]p", " ", "for", " ", "Med", " ", "to", " ", 
   "Med"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7993824458412695`*^9, 3.79938244938409*^9}, {
  3.7997388329210215`*^9, 3.7997388334909363`*^9}, {3.799738894557611*^9, 
  3.7997388961560135`*^9}},ExpressionUUID->"87d69a7f-e2a6-480a-b134-\
ca22933ef172"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"pmed", "<", "pmedrp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0", "<", "\[Alpha]", "<", "alphatilde"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"rhotilde", "<", "\[Rho]", "<", "rhotilderp"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7993823764601855`*^9, 3.7993823934486265`*^9}, {
   3.7993825253501444`*^9, 3.79938252556641*^9}, {3.799561946811198*^9, 
   3.79956195629916*^9}, 3.79973832821249*^9, {3.7997388180283933`*^9, 
   3.7997388219386687`*^9}, {3.802691420282158*^9, 
   3.802691426231629*^9}},ExpressionUUID->"0371ae6b-93d7-46c5-bf04-\
cf2a247b5324"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Alpha]", "+", "\[Mu]"}], "<", "1"}]], "Output",
 CellChangeTimes->{{3.799382385506674*^9, 3.799382395600995*^9}, 
   3.7993825258986654`*^9, 3.799388979688737*^9, 3.799396604091987*^9, 
   3.7994830966702123`*^9, {3.79948368865952*^9, 3.7994837179660797`*^9}, {
   3.7995619396234465`*^9, 3.7995619496741714`*^9}, {3.799738822662919*^9, 
   3.7997388490323944`*^9}, 3.7997453155090103`*^9, 3.80000170018686*^9, 
   3.802691426494134*^9, 3.8027549033280525`*^9, 
   3.8067323749386992`*^9},ExpressionUUID->"6ac2e017-2455-4e11-959e-\
5b42a7299fd3"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Check", " ", "\[CapitalDelta]p", " ", "for", " ", "Excl", " ", "to", " ", 
   "Med"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799382503538359*^9, 3.799382504841481*^9}, {
  3.7997388360974913`*^9, 3.7997388380654936`*^9}, {3.7997388914113936`*^9, 
  3.7997388922510977`*^9}},ExpressionUUID->"d127919e-2224-4fc6-850d-\
0375ceff2d3b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"pexcl", "<", "pmedrp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0", "<", "\[Alpha]", "<", "alphatilde"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"rhotilde", "<", "\[Rho]", "<", "rhotilderp"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.799382510623891*^9, 3.799382516270028*^9}, {
   3.799561952488695*^9, 3.7995619603334026`*^9}, 3.79973832821249*^9, {
   3.7997388416914673`*^9, 3.7997388461246324`*^9}, {3.7997388849944067`*^9, 
   3.7997388883560576`*^9}, 
   3.8026914285211477`*^9},ExpressionUUID->"d389b1ec-8714-4ebb-93b9-\
4d2964b10913"],

Cell[BoxData[
 RowBox[{"\[Mu]", "<", 
  RowBox[{"1", "+", 
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", "\[Mu]"}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.799382512529895*^9, 3.7993825165862055`*^9}, 
   3.7993889797146673`*^9, 3.799396604164419*^9, 3.7994830967394185`*^9, {
   3.7994836887084093`*^9, 3.799483718015946*^9}, {3.7995619443890676`*^9, 
   3.799561960981921*^9}, 3.7997388466414948`*^9, {3.799738885613679*^9, 
   3.799738888756834*^9}, 3.79974531578765*^9, 3.800001700425887*^9, 
   3.8026914287712655`*^9, 3.802754987158836*^9, 
   3.8067323754182277`*^9},ExpressionUUID->"fe1b4f10-cb1f-40ac-8b1e-\
02fabe07f0d8"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Check", " ", "\[CapitalDelta]q", " ", "for", " ", "Excl"}], " ", 
   "\[Rule]", " ", "Excl"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997388528217134`*^9, 
  3.799738859359583*^9}},ExpressionUUID->"31b72f86-0b4f-45bf-80c5-\
cede12e7c86c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"qexcl", ">", "qexclrp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"alphatilde", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"rhotilderp", ">", "\[Rho]", ">", "rhotilde"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7994852611187553`*^9, 3.799485265976714*^9}, 
   3.7995619651251965`*^9, {3.7997328326037393`*^9, 3.79973283261936*^9}, 
   3.79973832821249*^9, {3.7997388727112045`*^9, 3.7997388776261387`*^9}, 
   3.8026914303618765`*^9},ExpressionUUID->"ee019bc1-6160-41eb-b958-\
43d0d43c0edc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"1", "+", 
   RowBox[{"\[Mu]", " ", "\[Rho]"}]}], ">", 
  RowBox[{"\[Mu]", "+", 
   RowBox[{"2", " ", "\[Rho]"}]}]}]], "Output",
 CellChangeTimes->{
  3.79948526670479*^9, 3.7995619656953573`*^9, {3.799738862215249*^9, 
   3.7997388781740937`*^9}, 3.7997453160725107`*^9, 3.8000017006734257`*^9, 
   3.8026914306584044`*^9, {3.8027549901070595`*^9, 3.8027550010902386`*^9}, 
   3.806732375988057*^9},ExpressionUUID->"63b00453-ea42-454f-803f-\
922906ac0bb5"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "*)"}]], "Input",ExpressionUUID->"78550ac3-5b41-456a-92bd-232557428933"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"1", 
    RowBox[{"c", ":", " ", 
     RowBox[{"\[Rho]", " ", ">", " ", "rhotilderp", " ", ">", " ", 
      RowBox[{
       RowBox[{"rhotilde", ".", " ", "c1"}], " ", "and", " ", "c2", " ", 
       "determine", " ", "pricing", " ", "in", " ", "baseline"}]}]}]}], ",", 
   " ", 
   RowBox[{"c3rp", " ", "in", " ", "return", " ", "policy"}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.798967244495683*^9, 3.7989672598386245`*^9}, {
  3.799732832625868*^9, 
  3.799732832625868*^9}},ExpressionUUID->"f6de49d8-b43e-415c-8c61-\
f1d3240421e2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c3rp", "<", "c2"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0", "<", "\[Alpha]", "<", "alphatilde"}], ",", 
     RowBox[{"rhotilderp", "<", "\[Rho]", "<", "1"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7989672721040974`*^9, 3.798967299316365*^9}, {
   3.7995619921674223`*^9, 3.7995619922140274`*^9}, 3.799732832625868*^9, 
   3.7997383282281218`*^9, 
   3.802691434834607*^9},ExpressionUUID->"b7b2f29d-8c84-4d05-898b-\
2a46415214a2"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.798967292835019*^9, 3.7989672996322794`*^9}, 
   3.7991393353739557`*^9, 3.799377873077751*^9, 3.7993782400397243`*^9, 
   3.7993889798193874`*^9, 3.799396604426414*^9, 3.7994830969503975`*^9, {
   3.799483688862996*^9, 3.7994837181775427`*^9}, {3.7995619891903443`*^9, 
   3.7995619946050873`*^9}, 3.799738932755576*^9, 3.7997453163264675`*^9, 
   3.8000017009273667`*^9, {3.8026914331571608`*^9, 3.8026914351340494`*^9}, {
   3.8027549974721756`*^9, 3.802755003237739*^9}, 
   3.8067323766584916`*^9},ExpressionUUID->"1632d9f2-5c43-4424-8c3f-\
2ef315bf7409"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c3rp", "<", "c1"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0", "<", "\[Alpha]", "<", "alphatilde"}], ",", 
     RowBox[{"rhotilderp", "<", "\[Rho]", "<", "1"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.798967304834494*^9, 3.7989673049881477`*^9}, 
   3.799562000334298*^9, 3.7997328326414948`*^9, 3.7997383282281218`*^9, 
   3.8026914376330843`*^9},ExpressionUUID->"6de332b1-2f26-46ce-a262-\
4213ca86f382"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "\[Mu]", "+", 
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}], "+", "\[Rho]", "-", 
      RowBox[{"2", " ", "\[Mu]", " ", "\[Rho]"}]}], ")"}]}], "+", 
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "\[Mu]", "-", 
      RowBox[{"\[Mu]", " ", "\[Rho]"}]}], ")"}]}]}], "<", "0"}]], "Output",
 CellChangeTimes->{
  3.7989673054515743`*^9, 3.799139335458645*^9, 3.7993778732404766`*^9, 
   3.799378240077479*^9, 3.79938897989319*^9, 3.7993966048053293`*^9, 
   3.7994830973388557`*^9, {3.7994836889168205`*^9, 3.799483718215412*^9}, {
   3.7995619986363325`*^9, 3.7995620011210876`*^9}, 3.7997389352441726`*^9, 
   3.799745316796606*^9, 3.80000170135995*^9, 3.8026914383618684`*^9, 
   3.8027550064300036`*^9, 
   3.8067323781722727`*^9},ExpressionUUID->"17cd57bd-0122-4195-be7a-\
db5baff8491b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Two", " ", "possible", " ", "scenarios"}], " ", "*)"}]], "Input",Ex\
pressionUUID->"c7f66f77-094f-496d-81a8-9b3a505f6d2b"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"1.", 
    RowBox[{"c", ".", 
     RowBox[{"i", ":", "   ", 
      RowBox[{"c2", " ", ">", " ", "c3rp", " ", ">", " ", 
       RowBox[{"c1", ".", " ", "c"}], " ", "<", " ", "c1"}], ":", " ", 
      RowBox[{"Full", " ", "in", " ", "Both"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1", ",", "c3rp"}], ")"}]}], ":", " ", 
    RowBox[{"Medium", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Full", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c3rp", ",", "c2"}], ")"}]}], ":", " ", 
    RowBox[{"Medium", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Exclusive", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2", ":", " ", 
     RowBox[{"Exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.798967322700294*^9, 
  3.7989673770879087`*^9}},ExpressionUUID->"e075ce31-7b34-46af-96ba-\
a0d4f2d65cdc"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"1.", 
    RowBox[{"c", ".", 
     RowBox[{"ii", ":", "  ", 
      RowBox[{"c2", " ", ">", " ", "c1", " ", ">", " ", 
       RowBox[{"c3rp", ".", " ", "c"}], " ", "<", " ", "c3rp"}], ":", " ", 
      RowBox[{"Full", " ", "in", " ", "Both"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c3rp", ",", "c1"}], ")"}]}], ":", " ", 
    RowBox[{"Full", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Exclusive", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1", ",", "c2"}], ")"}]}], ":", " ", 
    RowBox[{"Medium", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Exclusive", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2", ":", " ", 
     RowBox[{"Exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7989673748124914`*^9, 
  3.798967402787956*^9}},ExpressionUUID->"0379f88f-9c26-4231-b110-\
627df5833b7e"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Check", " ", "\[CapitalDelta]q", " ", "for", " ", "Excl"}], " ", 
   "\[Rule]", " ", "Excl"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799738949077849*^9, 
  3.799738957025428*^9}},ExpressionUUID->"9276c5c3-57de-40bc-a948-\
1221990d4417"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"qexcl", ">", "qexclrp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"alphatilde", ">", "\[Alpha]", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Rho]", ">", "rhotilderp"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7994852916217747`*^9, 3.799485298880344*^9}, 
   3.7995620160638275`*^9, 3.7997328326414948`*^9, 3.7997383282281218`*^9, 
   3.802691442418707*^9},ExpressionUUID->"112abea3-89b2-4f44-90ec-\
d231cac771e7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"1", "+", 
   RowBox[{"\[Mu]", " ", "\[Rho]"}]}], ">", 
  RowBox[{"\[Mu]", "+", 
   RowBox[{"2", " ", "\[Rho]"}]}]}]], "Output",
 CellChangeTimes->{{3.7994852955053773`*^9, 3.7994853034870195`*^9}, 
   3.7995620165638657`*^9, 3.7997389872408867`*^9, 3.799745317075255*^9, 
   3.8000017016295366`*^9, 3.802691442742586*^9, 3.8027550089153013`*^9, 
   3.806732378768255*^9},ExpressionUUID->"741458cd-996a-45da-a2da-\
ab6b800cee85"]
}, Open  ]],

Cell[" Case 2: \[Alpha] > alphatilde which implies rhotilde > rhotilderp", \
"Item",
 CellChangeTimes->{{3.7989674192199163`*^9, 3.798967428932727*^9}, {
   3.7997328326727376`*^9, 3.799732832788607*^9}, 
   3.7997383282437387`*^9},ExpressionUUID->"7d1df804-e7a3-4614-b0d2-\
bab225c4e017"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"2", 
    RowBox[{"a", ":", " ", 
     RowBox[{"\[Rho]", " ", "<", " ", 
      RowBox[{
       RowBox[{"rhotilderp", ".", " ", "c3"}], " ", "determines", " ", 
       "pricing", " ", "in", " ", "baseline"}]}]}]}], ",", " ", 
   RowBox[{
   "c1rp", " ", "and", " ", "c2rp", " ", "in", " ", "return", " ", 
    "policy"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7989674425796943`*^9, 3.7989674429185414`*^9}, {
   3.7989700143863463`*^9, 3.7989700151421127`*^9}, 
   3.799732832804227*^9},ExpressionUUID->"66c4db27-e6d3-4448-a150-\
f264649ce561"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c3", ">", "c1rp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "alphatilde"}], ",", 
     RowBox[{"0", "<", "\[Rho]", "<", "rhotilderp", "<", "rhotilde"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7989674611856923`*^9, 3.7989674667699594`*^9}, {
   3.798967598253173*^9, 3.7989676135644226`*^9}, {3.798969989804016*^9, 
   3.7989699911391964`*^9}, 3.7995620221158156`*^9, {3.799732832804227*^9, 
   3.799732832804227*^9}, 3.7997383282906065`*^9, 
   3.8026914449296227`*^9},ExpressionUUID->"04f63cb6-86a0-482f-92ad-\
60d4565b57b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Alpha]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "3"}], "+", 
     RowBox[{"\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{"4", "+", 
        RowBox[{"\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}], "-", 
        RowBox[{"3", " ", "\[Rho]"}]}], ")"}]}], "+", "\[Rho]"}], ")"}]}], 
  ">", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "\[Mu]"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.7989674673716707`*^9, 3.7989676170359344`*^9, 3.798969991809654*^9, 
   3.7991393357217207`*^9, 3.7993778737011003`*^9, 3.799378240139968*^9, 
   3.7993889801116056`*^9, 3.799396605320197*^9, 3.799483097945198*^9, {
   3.799483689030551*^9, 3.7994837183311424`*^9}, 3.799562023102689*^9, 
   3.799739004246212*^9, 3.799745317576623*^9, 3.8000017020962553`*^9, 
   3.8026914456596966`*^9, 3.80275501183877*^9, 
   3.80673238000854*^9},ExpressionUUID->"35d429e9-3877-4b6f-97c9-\
7724a1520971"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c3", "<", "c2rp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "alphatilde"}], ",", 
     RowBox[{"0", "<", "\[Rho]", "<", "rhotilderp", "<", "rhotilde"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7989675142642965`*^9, 3.7989675154903336`*^9}, {
   3.79896999388402*^9, 3.7989699949713097`*^9}, 3.7995620258236427`*^9, {
   3.799732832819849*^9, 3.799732832826357*^9}, 3.7997383282906065`*^9, 
   3.802691447161642*^9},ExpressionUUID->"8745c497-ec69-493b-8dea-\
5b9490838ef8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalDelta]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[Mu]", "+", 
     RowBox[{"\[Alpha]", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Mu]", "+", 
        FractionBox["1", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}]], "+", 
        FractionBox["1", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]", "-", 
          RowBox[{"\[Mu]", " ", "\[Rho]"}]}]]}], ")"}]}]}], ")"}]}], "<", 
  "0"}]], "Output",
 CellChangeTimes->{
  3.7989675158535933`*^9, 3.79896999561992*^9, 3.799139336022589*^9, 
   3.7993778741858606`*^9, 3.7993782401712103`*^9, 3.799388980351963*^9, 
   3.7993966059080253`*^9, 3.799483098598945*^9, {3.7994836890714083`*^9, 
   3.799483718367014*^9}, 3.799562027229537*^9, {3.799739007050109*^9, 
   3.799739033354437*^9}, 3.7997453190451527`*^9, 3.800001703033903*^9, 
   3.802691448795389*^9, 3.8027550146630373`*^9, 
   3.8067323818785267`*^9},ExpressionUUID->"4327832c-5667-4939-b51f-\
835335c0f0e7"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"c3", " ", "can", " ", "lie", " ", "anywhere", " ", 
   RowBox[{"w", ".", "r", ".", "t"}], " ", "both", " ", "c1rp", " ", "and", 
   " ", "c2rp", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"where", " ", "we", " ", "have", " ", "c1rp"}], " ", "<", " ", 
     "c2rp"}], ")"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997390465451827`*^9, 
  3.7997390642426186`*^9}},ExpressionUUID->"08b08e1e-57b4-4ef0-b354-\
3fb60d2465bb"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Three", " ", "possible", " ", "scenarios"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.798967047378128*^9, 
  3.798967047995493*^9}},ExpressionUUID->"72ad1318-d91a-497d-a327-\
eba163e212e3"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"2.", 
    RowBox[{"a", ".", 
     RowBox[{"i", ":", "    ", 
      RowBox[{"c3", " ", ">", " ", "c2rp", " ", ">", " ", 
       RowBox[{"c1rp", ".", " ", "c"}], " ", "<", " ", "c1rp"}], ":", " ", 
      RowBox[{"Full", " ", "in", " ", "Both"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1rp", ",", "c2rp"}], ")"}]}], ":", " ", 
    RowBox[{"Full", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Medium", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c2rp", ",", "c3"}], ")"}]}], ":", " ", 
    RowBox[{"Full", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Exclusive", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c3", ":", " ", 
     RowBox[{"Exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.798967057839574*^9, 3.798967133874832*^9}, {
  3.7989700109932094`*^9, 
  3.798970108798323*^9}},ExpressionUUID->"3f29aad0-aadd-44c5-b6e0-\
77a9715976e7"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"2.", 
    RowBox[{"a", ".", 
     RowBox[{"ii", ":", "   ", 
      RowBox[{"c2rp", " ", ">", " ", "c3", " ", ">", " ", 
       RowBox[{"c1rp", ".", " ", "c"}], " ", "<", " ", 
       RowBox[{"c1rp", ":", " ", 
        RowBox[{"Full", " ", "in", " ", "Both"}]}]}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1rp", ",", "c3"}], ")"}]}], ":", " ", 
    RowBox[{"Full", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Medium", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c3", ",", "c2rp"}], ")"}]}], ":", " ", 
    RowBox[{"Exclusive", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Medium", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2rp", ":", " ", 
     RowBox[{"exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.798967116023261*^9, 3.7989671777772036`*^9}, {
  3.7989700198723373`*^9, 3.79897002062174*^9}, {3.7989701737620645`*^9, 
  3.798970202238159*^9}},ExpressionUUID->"c0533c33-6bac-445f-9350-\
c7b3fcc293a7"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"2.", 
    RowBox[{"a", ".", 
     RowBox[{"iii", ":", "  ", 
      RowBox[{"c2rp", " ", ">", " ", "c1rp", " ", ">", " ", 
       RowBox[{"c3", ".", " ", "c"}], " ", "<", " ", "c3"}], ":", " ", 
      RowBox[{"Full", " ", "in", " ", "Both"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c3", ",", "c1rp"}], ")"}]}], ":", " ", 
    RowBox[{"Exclusive", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Full", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1rp", ",", "c2rp"}], ")"}]}], ":", " ", 
    RowBox[{"Exclusive", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Medium", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2rp", ":", " ", 
     RowBox[{"exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.798967117596305*^9, 3.798967131020574*^9}, {
  3.7989671826272297`*^9, 3.7989672254578753`*^9}, {3.7989700236836214`*^9, 
  3.798970025218974*^9}, {3.7989702120353208`*^9, 
  3.798970246541701*^9}},ExpressionUUID->"492fb126-4415-4c2e-b457-\
c611bcc6589c"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Check", " ", "\[CapitalDelta]p", " ", "for", " ", "Excl"}], " ", 
   "\[Rule]", " ", "Med"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997390843865232`*^9, 
  3.79973909413262*^9}},ExpressionUUID->"7f81ee38-29f9-4f77-89fe-\
a5decf234392"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"pexcl", ">", "pmedrp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "alphatilde"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.799383153956852*^9, 3.799383168187027*^9}, {
   3.7995620367816143`*^9, 3.799562039974208*^9}, 3.7997383283062267`*^9, 
   3.8026914517858114`*^9},ExpressionUUID->"ee2250de-b4ae-4c2b-a27d-\
597d637a2360"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.799383168566188*^9, 3.7993889804397297`*^9, 3.7993966063133507`*^9, 
   3.799483099112567*^9, {3.7994836892050796`*^9, 3.799483718504675*^9}, {
   3.7995620345380473`*^9, 3.799562040353312*^9}, 3.799745319453289*^9, 
   3.800001703304294*^9, 3.802691452102357*^9, 3.8027550179905615`*^9, 
   3.806732382239709*^9},ExpressionUUID->"d04cd59c-e259-4bf0-9b7b-\
9479c5f4f7f3"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Check", " ", "\[CapitalDelta]q", " ", "for", " ", "Excl"}], " ", 
   "\[Rule]", " ", "Excl"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799739101234989*^9, 
  3.799739112237707*^9}},ExpressionUUID->"ae877cea-7996-44b3-9138-\
857eac9359b2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"qexcl", ">", "qexclrp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0", "<", "\[Rho]", "<", "rhotilderp"}], ",", 
     RowBox[{"1", ">", "\[Alpha]", ">", "alphatilde"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7994855563764133`*^9, 3.799485576720053*^9}, 
   3.799562059561469*^9, 3.799732832826357*^9, 3.7997383283127346`*^9, 
   3.8026914557063103`*^9},ExpressionUUID->"b5dd1f8a-bc0b-4d6f-a868-\
f5b9c2dcc2bc"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.799485573330078*^9, 3.7994855772007775`*^9}, 
   3.799562060110194*^9, 3.7997453196907964`*^9, 3.8000017035204773`*^9, 
   3.802691455994523*^9, 3.8027550192242274`*^9, 
   3.806732382689522*^9},ExpressionUUID->"2527158b-e12c-405d-9e3b-\
dc5d1b36a18f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7989702543991203`*^9, 
  3.798970260397987*^9}},ExpressionUUID->"1ac04e55-d637-491a-a5ae-\
6fd039027f46"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"2", 
    RowBox[{"b", ":", " ", 
     RowBox[{"rhotilde", " ", ">", " ", "\[Rho]", " ", ">", " ", 
      RowBox[{
       RowBox[{"rhotilderp", ".", " ", "c3"}], " ", "determines", " ", 
       "pricing", " ", "in", " ", "baseline"}]}]}]}], ",", " ", 
   RowBox[{"c3rp", " ", "in", " ", "return", " ", "policy"}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.798970264426154*^9, 3.798970277777996*^9}, {
  3.7997328328420005`*^9, 
  3.7997328328420005`*^9}},ExpressionUUID->"1323af8b-f289-485f-8a93-\
bcc3e3816172"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Reduce", "[", 
    RowBox[{"c3rp", ">", "c3"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "1", ">", "rhotilde", ">", "\[Rho]", ">", "rhotilderp", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Alpha]", ">", "alphatilde"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7989702928876295`*^9, 3.798970322222711*^9}, 
   3.7995620652782497`*^9, {3.799732832857605*^9, 3.799732832857605*^9}, 
   3.7997383283127346`*^9, 3.8026914585300026`*^9, {3.8067309471776257`*^9, 
   3.8067309511977353`*^9}},ExpressionUUID->"6734b9b4-87dd-4628-983c-\
83c9c5ae624d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"2", "+", 
     RowBox[{"\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}], "-", "\[Rho]"}], ")"}], 
   " ", 
   RowBox[{"(", 
    RowBox[{"\[Alpha]", "+", 
     SuperscriptBox["\[Mu]", "2"], "-", 
     RowBox[{"\[Alpha]", " ", 
      SuperscriptBox["\[Mu]", "2"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", "\[Mu]", " ", 
      "\[Rho]"}]}], ")"}]}], ">", 
  RowBox[{"1", "+", "\[Rho]"}]}]], "Output",
 CellChangeTimes->{{3.798970306223296*^9, 3.798970322538685*^9}, 
   3.7991393363611507`*^9, 3.7993778745201035`*^9, 3.799378240277946*^9, 
   3.799388980606283*^9, 3.7993966067570915`*^9, 3.7994830995406275`*^9, {
   3.799483689323762*^9, 3.799483718612732*^9}, {3.7995620644287224`*^9, 
   3.799562067217835*^9}, 3.799739143513164*^9, 3.7997453212675505`*^9, 
   3.800001704868843*^9, 3.8026914602359457`*^9, 3.802755023408272*^9, 
   3.806730960097409*^9, 
   3.80673239191848*^9},ExpressionUUID->"dfe77a77-20b2-44a3-b798-\
8a9b79a3a93b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Can", " ", "lie", " ", "either", " ", "way"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7993778770041656`*^9, 
  3.799377879818469*^9}},ExpressionUUID->"04d6e626-a8a0-444a-b91a-\
6d51016b3597"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"2.", 
    RowBox[{"b", ".", 
     RowBox[{"i", ":", "    ", 
      RowBox[{"c3", " ", ">", " ", 
       RowBox[{"c3rp", ".", " ", "c"}], " ", "<", " ", "c3rp"}], ":", " ", 
      RowBox[{"Full", " ", "in", " ", "Both"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c3rp", ",", "c3"}], ")"}]}], ":", " ", 
    RowBox[{"Full", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Exclusive", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c3", ":", " ", 
     RowBox[{"Exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7993779479299593`*^9, 
  3.7993779769229813`*^9}},ExpressionUUID->"d85f2ac3-319c-4c2c-bda5-\
130b1b73c841"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"2.", 
    RowBox[{"b", ".", 
     RowBox[{"ii", ":", "   ", 
      RowBox[{"c3", " ", "<", " ", 
       RowBox[{"c3rp", ".", " ", "c"}], " ", "<", " ", "c3"}], ":", " ", 
      RowBox[{"Full", " ", "in", " ", "Both"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c3", ",", "c3rp"}], ")"}]}], ":", " ", 
    RowBox[{"Exclusive", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Full", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c3rp", ":", " ", 
     RowBox[{"Exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.799377982133743*^9, 
  3.7993780041098146`*^9}},ExpressionUUID->"bda86138-afde-4715-81ad-\
802868f1306f"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Check", " ", "\[CapitalDelta]q", " ", "for", " ", "Excl"}], " ", 
   "\[Rule]", " ", "Excl"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997391701574345`*^9, 
  3.799739176158917*^9}},ExpressionUUID->"19cf8043-5025-40e5-9709-\
24d331eddd1c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"qexcl", ">", "qexclrp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"rhotilderp", "<", "\[Rho]", "<", "rhotilde"}], ",", 
     RowBox[{"1", ">", "\[Alpha]", ">", "alphatilde"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7994856149098206`*^9, 3.799485622255169*^9}, 
   3.7995620964393616`*^9, {3.7997328328888483`*^9, 3.7997328328888483`*^9}, 
   3.7997383283283615`*^9, 
   3.8026914629935937`*^9},ExpressionUUID->"729549d1-25b8-4a2f-aca3-\
e97003a3f40c"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7994856231477766`*^9, {3.7995620946189847`*^9, 3.7995620969714484`*^9}, 
   3.7997391792993083`*^9, 3.799745321558326*^9, 3.800001705115535*^9, 
   3.802691463220418*^9, 3.802755025402901*^9, 
   3.8067323922686005`*^9},ExpressionUUID->"c409b845-8b22-42bb-8f57-\
8bdb1ff7c076"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "*)"}]], "Input",ExpressionUUID->"19224acd-b770-4b35-9141-c83e0a37a2d4"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"2", 
    RowBox[{"c", ":", " ", 
     RowBox[{"\[Rho]", " ", ">", " ", "rhotilde", " ", ">", " ", 
      RowBox[{
       RowBox[{"rhotilderp", ".", " ", "c1"}], " ", "and", " ", "c2", " ", 
       "determine", " ", "pricing", " ", "in", " ", "baseline"}]}]}]}], ",", 
   " ", 
   RowBox[{
   "c3rp", " ", "determines", " ", "pricing", " ", "in", " ", "return", " ", 
    "policy"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799378050003272*^9, 3.799378133977209*^9}, {
  3.7997328328888483`*^9, 
  3.7997328328888483`*^9}},ExpressionUUID->"dd01d159-1e07-47ea-a349-\
04da4a3b1fd0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c3rp", "<", "c2"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "alphatilde"}], ",", 
     RowBox[{
     "1", ">", "\[Rho]", ">", "rhotilde", ">", "rhotilderp", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.799378155717338*^9, 3.799378189371755*^9}, {
   3.799562102208519*^9, 3.799562111307325*^9}, {3.7997328329044695`*^9, 
   3.7997328329044695`*^9}, 3.7997383283283615`*^9, 
   3.8026914676730623`*^9},ExpressionUUID->"cb4023a0-e752-4181-9446-\
fe3cfe633231"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Alpha]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}], "+", 
     RowBox[{"\[Rho]", " ", 
      RowBox[{"(", 
       RowBox[{"\[Mu]", "+", "\[Rho]", "-", 
        RowBox[{"\[Mu]", " ", "\[Rho]"}]}], ")"}]}]}], ")"}]}], "<", 
  "\[Rho]"}]], "Output",
 CellChangeTimes->{{3.79937816783997*^9, 3.799378189587996*^9}, 
   3.7993782405252986`*^9, 3.799388980924433*^9, 3.7993966075766196`*^9, 
   3.7994831009878087`*^9, {3.7994836896937428`*^9, 3.7994837189795723`*^9}, 
   3.7995621122098756`*^9, 3.799739183848442*^9, 3.7997453226012783`*^9, 
   3.8000017059334807`*^9, 3.802691468664422*^9, 3.8027550279606705`*^9, 
   3.8067309813781314`*^9, 
   3.806732393878753*^9},ExpressionUUID->"ee811822-0144-44a7-981e-\
09c73b9a8b1e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"c3rp", "<", "c1"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "alphatilde"}], ",", 
     RowBox[{
     "1", ">", "\[Rho]", ">", "rhotilde", ">", "rhotilderp", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7993781950851536`*^9, 3.7993781952010355`*^9}, 
   3.799562114938198*^9, {3.7997328329044695`*^9, 3.799732832920105*^9}, 
   3.7997383283439875`*^9, 
   3.802691470385595*^9},ExpressionUUID->"057352ac-3fcf-4a6c-a276-\
c3cb722fbd1f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "\[Mu]", "+", 
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}], "+", "\[Rho]", "-", 
      RowBox[{"2", " ", "\[Mu]", " ", "\[Rho]"}]}], ")"}]}], "+", 
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "\[Mu]", "-", 
      RowBox[{"\[Mu]", " ", "\[Rho]"}]}], ")"}]}]}], "<", "0"}]], "Output",
 CellChangeTimes->{
  3.7993781956164365`*^9, 3.799378240556527*^9, 3.7993889810700436`*^9, 
   3.799396607917742*^9, 3.7994831013845854`*^9, {3.7994836897296505`*^9, 
   3.7994837190195365`*^9}, 3.799562115908747*^9, 3.799739185323779*^9, 
   3.7997453238671646`*^9, 3.8000017065664043`*^9, 3.8026914714384146`*^9, 
   3.802755029146385*^9, 3.8067309846057224`*^9, 
   3.806732395299412*^9},ExpressionUUID->"fda0241b-dbf2-4118-ae00-\
73004981f657"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"c3rp", " ", "can", " ", "lie", " ", "above", " ", "anywhere", " ", 
   RowBox[{"w", ".", "r", ".", "t", ".", " ", "both"}], " ", "c1", " ", "and",
    " ", "c2"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7995621291513786`*^9, 3.7995621355205345`*^9}, {
  3.7997391878476486`*^9, 3.799739199248573*^9}, {3.8067309940483303`*^9, 
  3.806730994338549*^9}},ExpressionUUID->"4b683972-b59c-4f70-98f7-\
640f147bd4e7"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Three", " ", "possible", " ", "Scenarios"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799378201737979*^9, 3.799378205149371*^9}, {
  3.799562126944084*^9, 
  3.7995621274462*^9}},ExpressionUUID->"5a27ab1c-d34c-423a-b034-86f87b695d7d"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"2.", 
    RowBox[{"c", ".", 
     RowBox[{"i", ":", "   ", 
      RowBox[{"c2", " ", ">", " ", "c3rp", " ", ">", " ", 
       RowBox[{"c1", ".", " ", "c"}], " ", "<", " ", "c1"}], ":", " ", 
      RowBox[{"Full", " ", "in", " ", "Both"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1", ",", "c3rp"}], ")"}]}], ":", " ", 
    RowBox[{"Medium", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Full", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c3rp", ",", "c2"}], ")"}]}], ":", " ", 
    RowBox[{"Medium", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Exclusive", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2", ":", " ", 
     RowBox[{"Exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.799378207372543*^9, 
  3.7993782324675465`*^9}},ExpressionUUID->"b5de5c71-2201-4f1e-bf6b-\
36a9d0dc351c"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"2.", 
    RowBox[{"c", ".", 
     RowBox[{"ii", ":", "  ", 
      RowBox[{"c2", " ", ">", " ", "c1", " ", ">", " ", 
       RowBox[{"c3rp", ".", " ", "c"}], " ", "<", " ", "c3rp"}], ":", " ", 
      RowBox[{"Full", " ", "in", " ", "Both"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c3rp", ",", "c1"}], ")"}]}], ":", " ", 
    RowBox[{"Full", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Exclusive", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1", ",", "c2"}], ")"}]}], ":", " ", 
    RowBox[{"Medium", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Exclusive", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c2", ":", " ", 
     RowBox[{"Exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.79937823624942*^9, 
  3.7993782364028277`*^9}},ExpressionUUID->"06e69a27-4e31-467c-b4b3-\
2ddb5b84a17d"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"2.", 
    RowBox[{"c", ".", 
     RowBox[{"iii", ":", " ", 
      RowBox[{"c3rp", " ", ">", " ", "c2", " ", ">", " ", 
       RowBox[{"c1", ".", " ", "c"}], " ", "<", " ", "c1"}], ":", " ", 
      RowBox[{"Full", " ", "in", " ", "Both"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c1", ",", "c2"}], ")"}]}], ":", " ", 
    RowBox[{"Medium", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Full", " ", "Post"}], ",", " ", 
   RowBox[{
    RowBox[{"c", " ", "\[Element]", " ", 
     RowBox[{"(", 
      RowBox[{"c2", ",", "c3rp"}], ")"}]}], ":", " ", 
    RowBox[{"Exclusive", " ", "Pre"}]}], ",", " ", 
   RowBox[{"Full", " ", "Post"}], ",", " ", 
   RowBox[{"c", " ", ">", " ", 
    RowBox[{"c3rp", ":", " ", 
     RowBox[{"Exclusive", " ", "Pre", " ", "and", " ", "Post"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.799562450656171*^9, 
  3.7995624969818687`*^9}},ExpressionUUID->"0c8c00cc-3067-4ee8-abe8-\
6646b3a62c85"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Check", " ", "\[CapitalDelta]q", " ", "for", " ", "Excl"}], " ", 
   "\[Rule]", " ", "Excl"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7997392039301987`*^9, 
  3.7997392101938667`*^9}},ExpressionUUID->"c96690ce-a5b7-4944-bffd-\
726405c756c9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"qexcl", ">", "qexclrp"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", ">", "\[Alpha]", ">", "alphatilde"}], ",", 
     RowBox[{
     "1", ">", "\[Rho]", ">", "rhotilde", ">", "rhotilderp", ">", "0"}], ",", 
     RowBox[{"1", ">", "\[Mu]", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7994856546535063`*^9, 3.7994856589270635`*^9}, {
   3.799562510268879*^9, 3.799562515346525*^9}, 3.7997328329266396`*^9, 
   3.7997383283439875`*^9, 3.802691474737164*^9, 
   3.8067310164566436`*^9},ExpressionUUID->"e635c153-7fa7-4817-8fc2-\
0ba6c9eb22f7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"1", "+", 
   RowBox[{"\[Mu]", " ", "\[Rho]"}]}], ">", 
  RowBox[{"\[Mu]", "+", 
   RowBox[{"2", " ", "\[Rho]"}]}]}]], "Output",
 CellChangeTimes->{
  3.799485659431679*^9, {3.799562507630528*^9, 3.79956251758886*^9}, 
   3.7997453242682667`*^9, 3.8000017068204503`*^9, 3.802691475084916*^9, 
   3.8027550324426203`*^9, {3.806730991267868*^9, 3.80673101745757*^9}, 
   3.8067323960375414`*^9},ExpressionUUID->"df1743d4-eb0f-433b-9c39-\
5ca756edd27b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "Overall", " ", "all", " ", "9", " ", "cases", " ", "are", " ", 
    "possible"}], ",", " ", 
   RowBox[{
   "including", " ", "all", " ", "possible", " ", "ambiguities", " ", 
    "regarding", " ", "\[CapitalDelta]p", " ", "and", " ", "\[CapitalDelta]q",
     " ", "where", " ", "relevant"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.799562520695857*^9, 3.799562528147314*^9}, {
  3.799739216528967*^9, 
  3.799739230886978*^9}},ExpressionUUID->"8db99c3a-ac7c-4dc6-9ef3-\
5eb35c4de1ff"]
},
WindowSize->{1167, 901},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"12.1 for Microsoft Windows (64-bit) (March 18, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"997bda06-d23a-4e1b-b3a5-5c9daef54b32"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 131, 1, 28, "Input",ExpressionUUID->"6a2415a9-3767-461c-a3d1-bd301397e620"],
Cell[CellGroupData[{
Cell[714, 25, 153, 2, 31, "Item",ExpressionUUID->"7405c490-1d13-4eec-8bd3-bb455794167d"],
Cell[870, 29, 287, 7, 31, "Item",ExpressionUUID->"6e4a96ce-9e23-4be3-90b0-fed99498172b"],
Cell[1160, 38, 347, 7, 31, "Item",ExpressionUUID->"64bb3752-d78e-4974-9f1f-b86e0d265d27"],
Cell[1510, 47, 299, 7, 31, "Item",ExpressionUUID->"ae15c27d-e77a-4f79-b775-9de309623cc1"]
}, Open  ]],
Cell[1824, 57, 346, 8, 28, "Input",ExpressionUUID->"9c901ce1-f37a-4219-a649-ac07f993361f"],
Cell[2173, 67, 280, 6, 28, "Input",ExpressionUUID->"41a54a3e-2d35-43ce-a99a-f095e2d046ee"],
Cell[CellGroupData[{
Cell[2478, 77, 339, 9, 28, "Input",ExpressionUUID->"b4383f3e-e3e8-402d-8e3d-d3e2b26a3873"],
Cell[2820, 88, 448, 9, 32, "Output",ExpressionUUID->"a321ed5a-f51f-42bd-8b66-8f51a2e3abb7"]
}, Open  ]],
Cell[3283, 100, 358, 8, 28, "Input",ExpressionUUID->"fab666ed-9271-4b6a-a2e9-893813eac33e"],
Cell[CellGroupData[{
Cell[3666, 112, 646, 18, 28, "Input",ExpressionUUID->"426f67df-e469-4f16-bd22-584a667bde74"],
Cell[4315, 132, 544, 12, 32, "Output",ExpressionUUID->"f9f05d52-3238-4adb-a445-7088b86d2369"]
}, Open  ]],
Cell[4874, 147, 367, 8, 28, "Input",ExpressionUUID->"a05df26d-c811-4d35-bee7-018c1747baf2"],
Cell[CellGroupData[{
Cell[5266, 159, 605, 18, 28, "Input",ExpressionUUID->"b68bde7d-d48b-4674-9644-0f7dda6dd8e9"],
Cell[5874, 179, 511, 12, 32, "Output",ExpressionUUID->"07934fa1-cc13-467c-95c8-5b8c6e5634da"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6422, 196, 459, 11, 28, "Input",ExpressionUUID->"0f264897-e59f-4d6b-9a40-20c2ca81833c"],
Cell[6884, 209, 461, 11, 32, "Output",ExpressionUUID->"51685f5d-64a7-4edc-9b76-09024cffe76e"]
}, Open  ]],
Cell[7360, 223, 283, 4, 31, "Item",ExpressionUUID->"9b3b4abd-4416-407b-a8b2-889f456c5feb"],
Cell[7646, 229, 466, 11, 28, "Input",ExpressionUUID->"470ce5cd-e32f-4b27-9e5f-631654b6f3e7"],
Cell[8115, 242, 532, 13, 28, "Input",ExpressionUUID->"f1896b65-ee11-42ca-a3df-7c98638ecdbb"],
Cell[8650, 257, 539, 13, 28, "Input",ExpressionUUID->"4e4b87ba-24cc-48ce-aeb3-82c8e035712f"],
Cell[9192, 272, 737, 17, 28, "Input",ExpressionUUID->"d8dac42d-c8a0-4bd5-aacc-182a73866214"],
Cell[9932, 291, 483, 12, 28, "Input",ExpressionUUID->"7df3ec85-f965-4ae2-b4c5-6c572557e40f"],
Cell[10418, 305, 740, 20, 28, "Input",ExpressionUUID->"099e4df1-bbb7-40b7-8e21-250f3feb56a4"],
Cell[11161, 327, 543, 14, 28, "Input",ExpressionUUID->"12a70fb2-43df-4994-b7cd-989200de13b6"],
Cell[11707, 343, 665, 18, 28, "Input",ExpressionUUID->"6a913437-5610-43bd-88b2-1bd790112172"],
Cell[12375, 363, 294, 7, 28, "Input",ExpressionUUID->"a8eccb08-938e-4a71-9562-73d9eac6fb55"],
Cell[CellGroupData[{
Cell[12694, 374, 420, 9, 28, "Input",ExpressionUUID->"b9c2caed-7d39-4a0e-9641-1a3c7d4dabaf"],
Cell[13117, 385, 817, 23, 32, "Output",ExpressionUUID->"38aad657-f5e2-4c3c-af55-7de229ff5065"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13971, 413, 408, 9, 28, "Input",ExpressionUUID->"f8601c24-d016-4cfd-9991-f82053056e0f"],
Cell[14382, 424, 1209, 26, 32, "Output",ExpressionUUID->"3fb67d0c-c068-46cf-8428-8b87fae672e6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15628, 455, 422, 9, 28, "Input",ExpressionUUID->"fbd227a8-d2e4-4541-8fcb-b49d13fc3737"],
Cell[16053, 466, 1613, 38, 32, "Output",ExpressionUUID->"b54db5a1-ef89-4b76-a12a-79b3be94e6a8"]
}, Open  ]],
Cell[17681, 507, 173, 3, 31, "Item",ExpressionUUID->"c6af4016-272c-4e1e-b7e6-861eba37da2e"],
Cell[17857, 512, 445, 10, 28, "Input",ExpressionUUID->"63eb4e3c-56d8-4b9a-b61d-f7d77a85e086"],
Cell[18305, 524, 601, 13, 28, "Input",ExpressionUUID->"25056652-8a45-4a8e-a7ac-28349be60574"],
Cell[CellGroupData[{
Cell[18931, 541, 334, 9, 28, "Input",ExpressionUUID->"8b0d2854-4a32-46ea-8581-c8184744bff1"],
Cell[19268, 552, 704, 21, 52, "Output",ExpressionUUID->"1cdc293e-af76-4cf8-a6f3-01d6c58f756c"]
}, Open  ]],
Cell[19987, 576, 610, 16, 28, "Input",ExpressionUUID->"181ff33e-82ef-4c76-90d8-bed61944b824"],
Cell[CellGroupData[{
Cell[20622, 596, 332, 9, 28, "Input",ExpressionUUID->"20c2220c-912f-46db-8848-a043cbd9c1bd"],
Cell[20957, 607, 686, 19, 52, "Output",ExpressionUUID->"d45eb9e9-a628-4817-b9fc-f208c856af2a"]
}, Open  ]],
Cell[21658, 629, 604, 16, 28, "Input",ExpressionUUID->"37fec7e3-2963-4c36-a8a1-394861116a92"],
Cell[CellGroupData[{
Cell[22287, 649, 335, 9, 28, "Input",ExpressionUUID->"ad5b2eb1-1f39-47db-b953-e207c8b53ad5"],
Cell[22625, 660, 641, 18, 51, "Output",ExpressionUUID->"7014942e-2ee8-4893-aedc-b1696d5515e8"]
}, Open  ]],
Cell[23281, 681, 527, 15, 28, "Input",ExpressionUUID->"f9061049-d7cb-4b19-adf9-abe5c17d0839"],
Cell[23811, 698, 533, 11, 28, "Input",ExpressionUUID->"d5fc4db5-cb5c-4c28-a4db-86a06e38108a"],
Cell[CellGroupData[{
Cell[24369, 713, 592, 13, 28, "Input",ExpressionUUID->"21089384-efc9-4d88-bc28-98164d0734df"],
Cell[24964, 728, 1251, 29, 57, "Output",ExpressionUUID->"6ca4bdc3-4b6b-48e4-8ec7-fe7f19d69066"]
}, Open  ]],
Cell[26230, 760, 269, 6, 28, "Input",ExpressionUUID->"fc51aec0-efc6-4d10-886f-13050d03c0eb"],
Cell[CellGroupData[{
Cell[26524, 770, 372, 8, 28, "Input",ExpressionUUID->"2dcb4386-38f7-4c29-a82d-9ffcfa6b7090"],
Cell[26899, 780, 335, 6, 32, "Output",ExpressionUUID->"748f439f-b663-4313-a8e2-e1309b60b03e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27271, 791, 222, 5, 31, "Item",ExpressionUUID->"911d2092-8d65-4d2b-9c54-4e91a8f194ce"],
Cell[27496, 798, 270, 6, 31, "Item",ExpressionUUID->"382e3174-b931-4bf7-8e56-ed8e489651f3"]
}, Open  ]],
Cell[27781, 807, 512, 13, 32, "Input",ExpressionUUID->"de1bbb3d-5af2-4028-9e16-845df852123b"],
Cell[CellGroupData[{
Cell[28318, 824, 692, 13, 32, "Input",ExpressionUUID->"ea5b7a21-6467-407a-9bf6-a05c4a8fdf4b"],
Cell[29013, 839, 870, 13, 32, "Output",ExpressionUUID->"7052c0eb-e13b-419a-bb36-9443fae046bb"]
}, Open  ]],
Cell[29898, 855, 1087, 24, 28, "Input",ExpressionUUID->"1551b1d3-d25a-4281-9b6f-7f8bc3109c6a"],
Cell[30988, 881, 499, 10, 28, "Input",ExpressionUUID->"f51cc864-da4e-434c-af0c-8073f675af4c"],
Cell[31490, 893, 255, 4, 31, "Item",ExpressionUUID->"56e8200d-b2cb-4685-86f9-64aaee20fa00"],
Cell[31748, 899, 509, 13, 30, "Input",ExpressionUUID->"936afdc4-d514-4d76-9aee-764840cbac98"],
Cell[CellGroupData[{
Cell[32282, 916, 498, 10, 30, "Input",ExpressionUUID->"7dc3201c-8971-4372-8426-053d9611c96e"],
Cell[32783, 928, 183, 3, 32, "Output",ExpressionUUID->"31f954c1-c9bf-409e-9b08-e6f83e68bb94"]
}, Open  ]],
Cell[32981, 934, 596, 15, 28, "Input",ExpressionUUID->"b1a20859-7efa-4fc2-ab67-e2acabcd5458"],
Cell[33580, 951, 658, 17, 28, "Input",ExpressionUUID->"1b32a5a8-5e41-49fb-a1c2-00a2827895b1"],
Cell[34241, 970, 205, 4, 67, "Input",ExpressionUUID->"7fa5522d-21a4-43b7-9f10-d0b8dd82a3f3"],
Cell[34449, 976, 175, 3, 31, "Item",ExpressionUUID->"5badd8a7-863a-4521-83f6-87e706831304"],
Cell[34627, 981, 360, 9, 28, "Input",ExpressionUUID->"76879b96-6c8b-489d-a12a-30ce983b3b45"],
Cell[34990, 992, 304, 7, 28, "Input",ExpressionUUID->"0bd5e45e-649a-4f72-8646-706613e4f195"],
Cell[35297, 1001, 747, 17, 28, "Input",ExpressionUUID->"cb4d73a8-0921-4cc5-94aa-918903982824"],
Cell[36047, 1020, 838, 23, 28, "Input",ExpressionUUID->"912145e2-7031-4b67-9b3a-3e2db7ede3fc"],
Cell[36888, 1045, 756, 20, 28, "Input",ExpressionUUID->"c820932f-5d89-4342-9e17-53371b9eeae1"],
Cell[37647, 1067, 347, 8, 28, "Input",ExpressionUUID->"ffff0042-80b9-4ddb-986b-3a01ae82d65b"],
Cell[CellGroupData[{
Cell[38019, 1079, 429, 9, 28, "Input",ExpressionUUID->"b5f36179-d2de-42a5-96ae-d13632886719"],
Cell[38451, 1090, 1115, 27, 32, "Output",ExpressionUUID->"3e0400a8-3c29-4485-8cb7-720f401f0485"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39603, 1122, 377, 9, 28, "Input",ExpressionUUID->"04e499b6-1cb5-4285-a810-728680d68183"],
Cell[39983, 1133, 1005, 30, 36, "Output",ExpressionUUID->"81544420-9924-43c5-a4cf-8c44cd01a8e0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41025, 1168, 381, 9, 28, "Input",ExpressionUUID->"be9b2d71-c986-484e-8633-1e99cbc74118"],
Cell[41409, 1179, 1332, 38, 36, "Output",ExpressionUUID->"403336f9-9aad-4984-89a8-fb59e9f3c31c"]
}, Open  ]],
Cell[42756, 1220, 442, 10, 28, "Input",ExpressionUUID->"e70a6a5f-2189-443b-89a2-a21afad060bf"],
Cell[CellGroupData[{
Cell[43223, 1234, 391, 10, 28, "Input",ExpressionUUID->"2cbfacea-e0fe-4b1e-899c-56842bab3d6e"],
Cell[43617, 1246, 707, 21, 53, "Output",ExpressionUUID->"c2e458ab-140a-43db-b106-82102800062f"]
}, Open  ]],
Cell[44339, 1270, 479, 13, 28, "Input",ExpressionUUID->"95a02e93-68b9-4b25-b026-98ada59743ea"],
Cell[CellGroupData[{
Cell[44843, 1287, 386, 10, 28, "Input",ExpressionUUID->"8e38b163-245b-4b7d-9b7f-cda313ea6e2a"],
Cell[45232, 1299, 667, 18, 52, "Output",ExpressionUUID->"010f686d-31d4-4b8b-8cdf-d970a9e89fdd"]
}, Open  ]],
Cell[45914, 1320, 480, 13, 28, "Input",ExpressionUUID->"d2258e74-d9b6-462c-838b-e3716a5ea626"],
Cell[CellGroupData[{
Cell[46419, 1337, 388, 10, 28, "Input",ExpressionUUID->"8c2c439e-ac41-4f07-b612-0d1db9560130"],
Cell[46810, 1349, 704, 20, 53, "Output",ExpressionUUID->"812a98e7-64c7-43b7-96a2-82d0fe42bfb0"]
}, Open  ]],
Cell[47529, 1372, 474, 13, 28, "Input",ExpressionUUID->"1a9da96d-0356-4663-a938-5db5db6cb14d"],
Cell[48006, 1387, 301, 7, 28, "Input",ExpressionUUID->"1a94108a-e7b5-4c27-9cf7-0795e0ff6465"],
Cell[CellGroupData[{
Cell[48332, 1398, 545, 13, 28, "Input",ExpressionUUID->"69d711fc-9c40-45dd-b1f3-ed5eda87c430"],
Cell[48880, 1413, 1345, 35, 58, "Output",ExpressionUUID->"60eaed8d-e043-46a9-b756-c1dd90b8d2db"]
}, Open  ]],
Cell[50240, 1451, 273, 7, 28, "Input",ExpressionUUID->"bdcb36b2-3c0e-4f2d-9713-0dad3a78dd61"],
Cell[CellGroupData[{
Cell[50538, 1462, 322, 7, 28, "Input",ExpressionUUID->"1dcc1f65-f400-44c1-98d4-b0bc5d1a4afe"],
Cell[50863, 1471, 300, 5, 32, "Output",ExpressionUUID->"7600c097-01e9-4484-911c-db471b1de402"]
}, Open  ]],
Cell[51178, 1479, 519, 14, 32, "Input",ExpressionUUID->"0600f997-9171-48ab-bd0e-7f3aa8fa5b3a"],
Cell[51700, 1495, 518, 14, 30, "Input",ExpressionUUID->"c476df4c-c0f1-4d1a-bc8e-c41de6fffeaa"],
Cell[52221, 1511, 323, 6, 31, "Item",ExpressionUUID->"9e1c9251-18f7-4f74-b4c0-93f93c305d3b"],
Cell[CellGroupData[{
Cell[52569, 1521, 527, 10, 32, "Input",ExpressionUUID->"6e261341-809f-4522-a8ca-eb835e43ecd8"],
Cell[53099, 1533, 755, 12, 32, "Output",ExpressionUUID->"379f34f4-1478-42bc-b4ec-20697ae642d5"]
}, Open  ]],
Cell[53869, 1548, 1351, 28, 28, "Input",ExpressionUUID->"d42f8d21-7344-4ad3-81a9-5b440513b905"],
Cell[55223, 1578, 218, 5, 31, "Item",ExpressionUUID->"077bfdff-6351-40cb-9143-1d29b43f740a"],
Cell[CellGroupData[{
Cell[55466, 1587, 476, 9, 30, "Input",ExpressionUUID->"f6774197-c53d-480f-9c4b-e7ae29fc2dc3"],
Cell[55945, 1598, 677, 11, 32, "Output",ExpressionUUID->"ccf9fbb8-1b6c-4a42-8818-584cfbbdfce0"]
}, Open  ]],
Cell[56637, 1612, 551, 14, 28, "Input",ExpressionUUID->"2c04ad27-d846-4f07-85bf-2b82d1fa36e4"],
Cell[57191, 1628, 355, 8, 28, "Input",ExpressionUUID->"e8627278-3b73-4a8a-b694-695f48a58a10"],
Cell[57549, 1638, 159, 3, 31, "Item",ExpressionUUID->"5594ba39-5f53-4ff3-a93d-bdc6d8102bc4"],
Cell[57711, 1643, 304, 7, 28, "Input",ExpressionUUID->"9bcae843-8104-4b33-9da5-c3244fecb26c"],
Cell[CellGroupData[{
Cell[58040, 1654, 477, 10, 28, "Input",ExpressionUUID->"8d5e2ef0-d4c3-439b-b8f7-dbd792e9faea"],
Cell[58520, 1666, 752, 14, 32, "Output",ExpressionUUID->"c7bfa451-993c-4d30-80d5-6d5db9efe3f1"]
}, Open  ]],
Cell[59287, 1683, 400, 8, 28, "Input",ExpressionUUID->"e6f16eb6-92cd-4cb4-be86-3698c995cd10"],
Cell[59690, 1693, 407, 10, 28, "Input",ExpressionUUID->"3a8a2582-99e8-46e5-8ac1-bdef4e2076c0"],
Cell[CellGroupData[{
Cell[60122, 1707, 438, 12, 28, "Input",ExpressionUUID->"0cdcc241-8b26-47de-aee2-0254a8a3f85d"],
Cell[60563, 1721, 450, 11, 49, "Output",ExpressionUUID->"0aaf3387-3131-4d77-a275-16b53f59e1b0"]
}, Open  ]],
Cell[61028, 1735, 269, 6, 28, "Input",ExpressionUUID->"29b983b4-b905-45b3-9281-8574417b2469"],
Cell[CellGroupData[{
Cell[61322, 1745, 233, 5, 28, "Input",ExpressionUUID->"92a315d8-f84b-416d-92d9-4531b5410f75"],
Cell[61558, 1752, 303, 5, 32, "Output",ExpressionUUID->"1132fc93-e481-4b93-9c25-619262cf65b6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61898, 1762, 606, 14, 28, "Input",ExpressionUUID->"b3a89059-6cee-44d1-8524-8e3c486a2055"],
Cell[62507, 1778, 405, 8, 32, "Output",ExpressionUUID->"a8ad9cf1-facb-4414-8cfc-90638ec546bc"]
}, Open  ]],
Cell[62927, 1789, 322, 7, 31, "Item",ExpressionUUID->"cbc52bfd-7df4-4860-914f-6894d8394fac"],
Cell[63252, 1798, 253, 7, 28, "Input",ExpressionUUID->"7d6893c2-17a7-4a6e-b12e-49c18f204787"],
Cell[63508, 1807, 309, 7, 28, "Input",ExpressionUUID->"f35fe078-ce56-434d-9df0-b5886e0e3d61"],
Cell[CellGroupData[{
Cell[63842, 1818, 584, 15, 28, "Input",ExpressionUUID->"bfb8440f-f35f-49c2-9886-095a3a49f3ef"],
Cell[64429, 1835, 445, 8, 32, "Output",ExpressionUUID->"926a898e-c84d-4c69-a883-aedd460e384d"]
}, Open  ]],
Cell[64889, 1846, 255, 6, 28, "Input",ExpressionUUID->"0e587610-bb34-4d58-abbe-fe93dffb605b"],
Cell[CellGroupData[{
Cell[65169, 1856, 578, 15, 28, "Input",ExpressionUUID->"a377e6a3-b3fb-4d52-b726-c02375bf7fd8"],
Cell[65750, 1873, 446, 8, 32, "Output",ExpressionUUID->"8a3ed59a-b772-442c-bdc8-d2738500a163"]
}, Open  ]],
Cell[66211, 1884, 256, 6, 28, "Input",ExpressionUUID->"002105cc-82fc-4fc4-853c-4a936952a4b0"],
Cell[CellGroupData[{
Cell[66492, 1894, 583, 15, 28, "Input",ExpressionUUID->"5946f446-cd82-423b-831a-442b9c11eba0"],
Cell[67078, 1911, 391, 8, 32, "Output",ExpressionUUID->"3d15a109-ae23-4ed6-b6dc-ff73208351e3"]
}, Open  ]],
Cell[67484, 1922, 255, 6, 28, "Input",ExpressionUUID->"47812704-9240-4c6c-8555-5918028e87fe"],
Cell[CellGroupData[{
Cell[67764, 1932, 578, 15, 28, "Input",ExpressionUUID->"831ff0ee-f037-41f5-be60-b8c8668658cb"],
Cell[68345, 1949, 412, 8, 32, "Output",ExpressionUUID->"1b83eb1d-1db5-4e63-a389-90ef851c9c24"]
}, Open  ]],
Cell[68772, 1960, 258, 6, 28, "Input",ExpressionUUID->"dae5b866-d1d7-4cf2-8128-ca020700d56c"],
Cell[CellGroupData[{
Cell[69055, 1970, 575, 15, 28, "Input",ExpressionUUID->"1b173c7f-4194-4645-8551-de691f552bca"],
Cell[69633, 1987, 389, 7, 32, "Output",ExpressionUUID->"b6b8eda7-e819-4694-b4cf-acb2386e42e8"]
}, Open  ]],
Cell[70037, 1997, 257, 6, 28, "Input",ExpressionUUID->"4b205124-8c98-450e-9c0a-c18f3e570f09"],
Cell[CellGroupData[{
Cell[70319, 2007, 578, 15, 28, "Input",ExpressionUUID->"edcf4baa-02b7-441c-909c-7a6a05e7b890"],
Cell[70900, 2024, 391, 7, 32, "Output",ExpressionUUID->"0ecefc65-bb59-4174-b2b1-780a12f888e3"]
}, Open  ]],
Cell[71306, 2034, 311, 7, 28, "Input",ExpressionUUID->"2f557585-5eee-4c59-9a3e-d6de02001d1a"],
Cell[CellGroupData[{
Cell[71642, 2045, 583, 15, 28, "Input",ExpressionUUID->"468e7c10-21ca-4a3e-9d78-d005beb0e95c"],
Cell[72228, 2062, 366, 7, 32, "Output",ExpressionUUID->"86cea88b-c5d2-4d3f-9bc5-e8c277efbb1b"]
}, Open  ]],
Cell[72609, 2072, 753, 18, 48, "Input",ExpressionUUID->"408ebb22-84cd-4a6f-a939-b4f7dc129766"],
Cell[CellGroupData[{
Cell[73387, 2094, 691, 17, 32, "Input",ExpressionUUID->"6d819ec8-21fb-4bcf-8e5c-561b6ec08b55"],
Cell[74081, 2113, 682, 18, 32, "Output",ExpressionUUID->"30ddf808-e573-4936-afe4-f19f4516e29a"]
}, Open  ]],
Cell[74778, 2134, 260, 6, 28, "Input",ExpressionUUID->"eed68b5d-2a11-448e-9321-1fbcf0803b84"],
Cell[75041, 2142, 361, 8, 28, "Input",ExpressionUUID->"8c1c3639-cf0b-43c1-bde2-23679b2aa919"],
Cell[CellGroupData[{
Cell[75427, 2154, 865, 25, 28, "Input",ExpressionUUID->"c0938977-9ac8-4d14-9140-dc63fb1cf07a"],
Cell[76295, 2181, 258, 4, 32, "Output",ExpressionUUID->"8c9ee89f-9266-49c6-a2af-1a5b53a47442"]
}, Open  ]],
Cell[76568, 2188, 258, 6, 28, "Input",ExpressionUUID->"6f3887f6-6597-4868-834b-b5ca2d1095b7"],
Cell[CellGroupData[{
Cell[76851, 2198, 578, 15, 28, "Input",ExpressionUUID->"9c02b00a-20ff-44a6-833f-a31723f6cff2"],
Cell[77432, 2215, 418, 8, 32, "Output",ExpressionUUID->"cf7927dc-47bc-454d-a20a-f6d574a1640a"]
}, Open  ]],
Cell[77865, 2226, 177, 3, 31, "Item",ExpressionUUID->"1b846c01-075e-47b6-94fe-6ce22e4f644c"],
Cell[CellGroupData[{
Cell[78067, 2233, 350, 7, 28, "Input",ExpressionUUID->"c24fa1ba-ffd9-4b34-b54e-e9bd07f58f6b"],
Cell[78420, 2242, 278, 5, 32, "Output",ExpressionUUID->"245a019c-2d41-4d62-9dcb-406626fb5f01"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78735, 2252, 327, 7, 28, "Input",ExpressionUUID->"9e268e35-f19f-416f-90e3-605bac5a04ed"],
Cell[79065, 2261, 282, 5, 32, "Output",ExpressionUUID->"e1f767e2-cccd-4f0e-ab63-a098105adeb3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79384, 2271, 331, 7, 28, "Input",ExpressionUUID->"26ea7fae-9152-4145-a878-4831a68e20aa"],
Cell[79718, 2280, 250, 4, 32, "Output",ExpressionUUID->"9a78ace3-f37c-4ed6-a60d-3eedaad94450"]
}, Open  ]],
Cell[79983, 2287, 368, 8, 28, "Input",ExpressionUUID->"2c5b1b14-f1c7-4c22-96d6-f25321e08128"],
Cell[80354, 2297, 297, 6, 31, "Item",ExpressionUUID->"45c101b3-7f6b-4f55-b074-cfeae5df464b"],
Cell[80654, 2305, 647, 13, 28, "Input",ExpressionUUID->"5e29c698-fade-4f62-afe6-079fbb2276b1"],
Cell[CellGroupData[{
Cell[81326, 2322, 279, 6, 31, "Item",ExpressionUUID->"8c1f2f0b-e745-4832-b213-dcf45ac9ae20"],
Cell[81608, 2330, 353, 7, 31, "Item",ExpressionUUID->"df532079-9fdc-41ea-915b-115041347db6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81998, 2342, 594, 13, 28, "Input",ExpressionUUID->"ae61f027-2f5c-44b7-be12-6fbc3d24725b"],
Cell[82595, 2357, 752, 11, 32, "Output",ExpressionUUID->"850eb9e0-78d5-4098-9fe2-6a4f3b8f2642"]
}, Open  ]],
Cell[83362, 2371, 828, 20, 28, "Input",ExpressionUUID->"fe676a93-ff82-4ad5-b5f6-ae74efddd4b7"],
Cell[84193, 2393, 399, 8, 31, "Item",ExpressionUUID->"8d8465d5-e189-4d95-addb-92ff440c1821"],
Cell[CellGroupData[{
Cell[84617, 2405, 735, 15, 28, "Input",ExpressionUUID->"c1faaf62-684b-4e71-9089-da1a93bece7e"],
Cell[85355, 2422, 793, 12, 32, "Output",ExpressionUUID->"bfc2e347-e4ac-4b18-855b-e47c4ae710d1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86185, 2439, 500, 12, 28, "Input",ExpressionUUID->"ce227395-1bcc-4d68-a5d0-9fe4cdae6c32"],
Cell[86688, 2453, 233, 4, 32, "Output",ExpressionUUID->"697c5f6c-0e13-4302-97a7-26e6c5cfc689"]
}, Open  ]],
Cell[86936, 2460, 837, 21, 48, "Input",ExpressionUUID->"aef00b03-a8d0-48bd-a71c-6fabb5925403"],
Cell[87776, 2483, 419, 10, 28, "Input",ExpressionUUID->"ccbb51c5-8705-4dbd-b8a9-5ef8c99b76d5"],
Cell[88198, 2495, 344, 8, 28, "Input",ExpressionUUID->"ce457090-b5cb-4ed0-b92b-0e03e42e40c7"],
Cell[CellGroupData[{
Cell[88567, 2507, 601, 13, 28, "Input",ExpressionUUID->"b4b39af6-479b-44db-900e-0f2faefa2010"],
Cell[89171, 2522, 407, 7, 32, "Output",ExpressionUUID->"47921449-0fea-45ef-afd8-0902f4c25c55"]
}, Open  ]],
Cell[89593, 2532, 490, 13, 28, "Input",ExpressionUUID->"c46d2c36-fc65-4e71-b054-c7dbde082040"],
Cell[CellGroupData[{
Cell[90108, 2549, 463, 12, 28, "Input",ExpressionUUID->"da87d639-9de1-4a7d-9f32-7b102d4cbb7a"],
Cell[90574, 2563, 233, 4, 32, "Output",ExpressionUUID->"505e1519-ee94-45aa-bda6-bc4cc1aad49a"]
}, Open  ]],
Cell[90822, 2570, 419, 10, 28, "Input",ExpressionUUID->"55036f34-5064-4621-81e9-642160d01a32"],
Cell[91244, 2582, 229, 4, 28, "Input",ExpressionUUID->"ff491822-8a88-494e-a1fe-5c7ad0a27cd5"],
Cell[91476, 2588, 357, 7, 31, "Item",ExpressionUUID->"49b10ca6-7f41-4ca2-9fcd-da96d4f45d33"],
Cell[CellGroupData[{
Cell[91858, 2599, 663, 15, 28, "Input",ExpressionUUID->"bc876d78-4b8f-4a1f-a3ca-e949aec15ad0"],
Cell[92524, 2616, 705, 10, 32, "Output",ExpressionUUID->"ef9dbc99-e641-495f-9d9b-bfb3ac99e726"]
}, Open  ]],
Cell[CellGroupData[{
Cell[93266, 2631, 630, 14, 28, "Input",ExpressionUUID->"3d84409f-2aeb-4841-a68a-bbab948282b8"],
Cell[93899, 2647, 479, 8, 32, "Output",ExpressionUUID->"07b6c95d-fc22-450a-b795-0e6e21c2207b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[94415, 2660, 734, 16, 28, "Input",ExpressionUUID->"33735d13-6713-4e9e-8679-d449b6b710d1"],
Cell[95152, 2678, 1182, 29, 32, "Output",ExpressionUUID->"36c57532-8f6b-47ef-984e-879a9903c56d"]
}, Open  ]],
Cell[96349, 2710, 297, 7, 28, "Input",ExpressionUUID->"161a8f00-978a-43f7-b7f1-4f9864464c4c"],
Cell[96649, 2719, 235, 5, 28, "Input",ExpressionUUID->"bf0263dc-c4e6-41f6-b8a5-0ddfe0903bde"],
Cell[96887, 2726, 1514, 39, 67, "Input",ExpressionUUID->"c2034ead-6bef-45b7-b470-8c94c6e63239"],
Cell[98404, 2767, 1476, 38, 67, "Input",ExpressionUUID->"b4ddc541-4f58-40b6-9541-5b6dc283435b"],
Cell[99883, 2807, 353, 9, 28, "Input",ExpressionUUID->"91159531-0ea8-4ea7-a348-5b82970e5184"],
Cell[CellGroupData[{
Cell[100261, 2820, 491, 12, 28, "Input",ExpressionUUID->"a0ef544f-cdc7-4f4e-a02c-2b7061b780f4"],
Cell[100755, 2834, 513, 14, 32, "Output",ExpressionUUID->"7d4e129a-45d9-4681-b3de-1aa91abbde2b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101305, 2853, 352, 9, 28, "Input",ExpressionUUID->"0f81ffdd-9123-4092-a7a7-c08f2a10d48b"],
Cell[101660, 2864, 181, 3, 32, "Output",ExpressionUUID->"58e85d0c-e64a-4402-9542-e852258fbe8b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101878, 2872, 405, 10, 28, "Input",ExpressionUUID->"1f84b684-3d04-44e4-aff3-de18901d9116"],
Cell[102286, 2884, 210, 4, 32, "Output",ExpressionUUID->"fbb12477-45f2-40b9-8b10-3ef7d717e9cb"]
}, Open  ]],
Cell[102511, 2891, 235, 5, 28, "Input",ExpressionUUID->"dab112af-35d5-4242-a0ee-bebdda2e6523"],
Cell[102749, 2898, 297, 7, 28, "Input",ExpressionUUID->"1ad79906-e234-4b9f-9374-5b8172cf37be"],
Cell[CellGroupData[{
Cell[103071, 2909, 280, 6, 31, "Item",ExpressionUUID->"52dbb6d4-bbf6-4753-86ae-5aa2b122f513"],
Cell[103354, 2917, 303, 6, 31, "Item",ExpressionUUID->"f50e9d9f-0d05-4bb4-b9ce-1ccce6ae23c4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103694, 2928, 543, 13, 28, "Input",ExpressionUUID->"a65062b2-2131-456b-b16f-f7f3e603b16e"],
Cell[104240, 2943, 326, 5, 32, "Output",ExpressionUUID->"9e5590a4-9584-462e-818a-ce3752656a50"]
}, Open  ]],
Cell[104581, 2951, 608, 15, 28, "Input",ExpressionUUID->"95fd4b48-b4bb-430d-b190-e54ce0cf4a0d"],
Cell[105192, 2968, 359, 7, 31, "Item",ExpressionUUID->"d16b9172-9c56-44e8-a132-906fd0ce0d39"],
Cell[CellGroupData[{
Cell[105576, 2979, 749, 17, 28, "Input",ExpressionUUID->"562f40d4-081b-4cfd-8b6f-96af6996f6e7"],
Cell[106328, 2998, 373, 6, 32, "Output",ExpressionUUID->"27725d7b-9e4c-4daa-9e97-5c19f70af934"]
}, Open  ]],
Cell[CellGroupData[{
Cell[106738, 3009, 622, 15, 28, "Input",ExpressionUUID->"f92e5d60-4002-49a5-a131-c964af7e7619"],
Cell[107363, 3026, 210, 4, 32, "Output",ExpressionUUID->"132ed257-47a0-4e38-93e2-b0b4840dd4c1"]
}, Open  ]],
Cell[107588, 3033, 911, 24, 48, "Input",ExpressionUUID->"248f2ee6-dee2-4c65-9bf4-f1498cb70dc6"],
Cell[108502, 3059, 366, 8, 31, "Item",ExpressionUUID->"4ef815b1-1130-49bc-9fc4-ebb394a83c2f"],
Cell[CellGroupData[{
Cell[108893, 3071, 518, 13, 28, "Input",ExpressionUUID->"84c490bb-78f3-4acf-a08b-00fd67d11c1d"],
Cell[109414, 3086, 274, 5, 32, "Output",ExpressionUUID->"cbb21208-422a-413b-bd64-f81f96bcd164"]
}, Open  ]],
Cell[CellGroupData[{
Cell[109725, 3096, 634, 14, 28, "Input",ExpressionUUID->"c27940f1-48be-4b40-8a00-b34f1992e63b"],
Cell[110362, 3112, 359, 6, 32, "Output",ExpressionUUID->"7edd8da6-1d56-433e-b56c-e641df44c9b6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[110758, 3123, 658, 15, 28, "Input",ExpressionUUID->"0498c2b1-30a1-4320-874e-872ddf69c7d0"],
Cell[111419, 3140, 877, 25, 32, "Output",ExpressionUUID->"965bb7be-82a2-4dee-9e18-b33b8aada296"]
}, Open  ]],
Cell[112311, 3168, 303, 7, 28, "Input",ExpressionUUID->"e924949a-bf9e-4842-a64d-ddf041736896"],
Cell[112617, 3177, 1512, 39, 67, "Input",ExpressionUUID->"0bef379c-15ef-4d45-8c6e-83331fc0ba0f"],
Cell[114132, 3218, 1472, 38, 67, "Input",ExpressionUUID->"8ea902be-a67a-4932-b4af-dad4d60e30c9"],
Cell[115607, 3258, 353, 9, 28, "Input",ExpressionUUID->"d1ca531d-d3ce-4db1-99d5-e2ac68890615"],
Cell[CellGroupData[{
Cell[115985, 3271, 487, 11, 28, "Input",ExpressionUUID->"ba8b0e2c-e1a6-44b6-b124-1d4855b8dd0c"],
Cell[116475, 3284, 565, 14, 32, "Output",ExpressionUUID->"1f81a15e-3d74-4d56-87dc-04fec6a086f9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[117077, 3303, 358, 9, 28, "Input",ExpressionUUID->"8b916296-9309-44e2-a5e8-a8722df916a9"],
Cell[117438, 3314, 179, 3, 32, "Output",ExpressionUUID->"861266a1-4504-46fe-be94-9a61bd1d0ab7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[117654, 3322, 350, 9, 28, "Input",ExpressionUUID->"73ec23df-9ff3-44f4-9b3d-ed9833022465"],
Cell[118007, 3333, 211, 4, 32, "Output",ExpressionUUID->"47359eae-ade2-410b-b618-0ba07bec9a1d"]
}, Open  ]],
Cell[118233, 3340, 231, 5, 28, "Input",ExpressionUUID->"d3ba4789-1217-4490-b66e-db26f47c0803"],
Cell[118467, 3347, 431, 9, 51, "Item",ExpressionUUID->"bf3f932d-09ce-4aea-a2c4-5ee9b969ea7f"],
Cell[118901, 3358, 179, 3, 28, "Input",ExpressionUUID->"0faf7d25-bde5-455a-ac9e-ec26a688bcc6"],
Cell[CellGroupData[{
Cell[119105, 3365, 194, 4, 31, "Item",ExpressionUUID->"c9a590ed-fa41-42aa-b916-016a1621b293"],
Cell[119302, 3371, 182, 3, 31, "Item",ExpressionUUID->"0d45dcbe-7096-431f-a19f-5b92e7e2889e"]
}, Open  ]],
Cell[119499, 3377, 505, 12, 28, "Input",ExpressionUUID->"de383d5e-6962-4d9a-adef-28fd784098e6"],
Cell[120007, 3391, 506, 12, 28, "Input",ExpressionUUID->"7412bdf7-ebe9-4610-a52c-632c8d6645e8"],
Cell[120516, 3405, 401, 8, 28, "Input",ExpressionUUID->"e07b8348-6b24-4abd-b573-74c8777a16d8"],
Cell[120920, 3415, 409, 12, 28, "Input",ExpressionUUID->"4de908da-3be7-4ce6-a980-9fa784096b14"],
Cell[121332, 3429, 377, 10, 28, "Input",ExpressionUUID->"aad8fc6a-08b9-49e5-9b98-881429b7e406"],
Cell[121712, 3441, 598, 15, 28, "Input",ExpressionUUID->"d5a28efb-d0fe-45ae-8501-944ed62ab8ca"],
Cell[122313, 3458, 745, 17, 28, "Input",ExpressionUUID->"c40c45f4-6ecf-4a13-814b-0a25aea92360"],
Cell[123061, 3477, 826, 22, 28, "Input",ExpressionUUID->"2455a6c6-67f9-4237-b418-cea0fda020c7"],
Cell[CellGroupData[{
Cell[123912, 3503, 1008, 25, 105, "Input",ExpressionUUID->"22cabbf4-01b7-47c5-beb9-d68e71515811"],
Cell[124923, 3530, 454, 11, 32, "Output",ExpressionUUID->"896c7785-614f-417c-96b1-cca78434981b"],
Cell[125380, 3543, 717, 18, 32, "Output",ExpressionUUID->"5a5828b9-7a9e-46cb-bee8-2f5b16a9203b"],
Cell[126100, 3563, 789, 22, 32, "Output",ExpressionUUID->"9e052636-1a90-444d-94fe-9fa7db4e5020"]
}, Open  ]],
Cell[126904, 3588, 342, 8, 28, "Input",ExpressionUUID->"7c57a6d6-80a7-4435-9015-610c5d2c80f9"],
Cell[CellGroupData[{
Cell[127271, 3600, 335, 9, 28, "Input",ExpressionUUID->"3faf2a0c-748e-41e3-b07f-89731a9033c2"],
Cell[127609, 3611, 506, 15, 52, "Output",ExpressionUUID->"a9f0d50d-4f06-457f-b074-97bcc771a449"]
}, Open  ]],
Cell[128130, 3629, 615, 17, 28, "Input",ExpressionUUID->"cb419960-ed25-4f23-8487-06fe6c1aa8cf"],
Cell[CellGroupData[{
Cell[128770, 3650, 338, 9, 28, "Input",ExpressionUUID->"e831348c-8096-4acf-b57f-f28c8d92e40b"],
Cell[129111, 3661, 577, 17, 51, "Output",ExpressionUUID->"dff4d4d8-3f4f-4503-b800-4c0e6e120d95"]
}, Open  ]],
Cell[129703, 3681, 564, 16, 28, "Input",ExpressionUUID->"76f72975-ad4b-40fa-878c-27cccb3602ed"],
Cell[CellGroupData[{
Cell[130292, 3701, 337, 9, 28, "Input",ExpressionUUID->"0fca3d6a-0657-4bb8-a5ca-dbbd65ce02fc"],
Cell[130632, 3712, 663, 19, 51, "Output",ExpressionUUID->"b5c938d0-df9b-488c-9204-4e51917f8127"]
}, Open  ]],
Cell[131310, 3734, 570, 16, 28, "Input",ExpressionUUID->"2d8a0488-91c0-4c2a-8218-a29ae129178b"],
Cell[131883, 3752, 336, 8, 28, "Input",ExpressionUUID->"50249b2e-0238-48c2-8fc0-2c101dead0ff"],
Cell[CellGroupData[{
Cell[132244, 3764, 602, 13, 28, "Input",ExpressionUUID->"4c60230e-ada8-4426-8935-4bcb1313842c"],
Cell[132849, 3779, 946, 19, 51, "Output",ExpressionUUID->"70769b38-fd6c-4af3-b00e-d0ea62f64773"]
}, Open  ]],
Cell[CellGroupData[{
Cell[133832, 3803, 514, 12, 28, "Input",ExpressionUUID->"b9d6742c-71f2-4124-a62c-4466940f302d"],
Cell[134349, 3817, 335, 6, 32, "Output",ExpressionUUID->"300870a2-5555-484d-a4c6-2f3e85428766"]
}, Open  ]],
Cell[CellGroupData[{
Cell[134721, 3828, 381, 10, 28, "Input",ExpressionUUID->"1abb37b2-ba7d-42dd-9688-19ff6b70418f"],
Cell[135105, 3840, 422, 8, 32, "Output",ExpressionUUID->"18a864e4-603e-4681-a6da-a590ce0ec774"]
}, Open  ]],
Cell[135542, 3851, 724, 16, 48, "Input",ExpressionUUID->"c02d3a42-de5e-447e-aeb1-6aae15709edc"],
Cell[CellGroupData[{
Cell[136291, 3871, 343, 8, 28, "Input",ExpressionUUID->"8b17ca81-ed27-47d7-a13d-d6057d01a5a9"],
Cell[136637, 3881, 416, 8, 32, "Output",ExpressionUUID->"de46163c-db9b-4b81-994e-a5a333e08bf0"]
}, Open  ]],
Cell[137068, 3892, 313, 7, 31, "Item",ExpressionUUID->"85409bfb-4c5d-483c-8897-cea1217a33f6"],
Cell[CellGroupData[{
Cell[137406, 3903, 704, 15, 28, "Input",ExpressionUUID->"0d67f472-8c29-4623-911f-6e4254943f88"],
Cell[138113, 3920, 677, 10, 32, "Output",ExpressionUUID->"fd197f56-0d53-4a31-8b14-c9b3412af810"]
}, Open  ]],
Cell[138805, 3933, 740, 20, 28, "Input",ExpressionUUID->"9be51503-d6b5-4e4d-8bc9-89f3a2c0b0fe"],
Cell[139548, 3955, 301, 6, 31, "Item",ExpressionUUID->"0ab36ae1-2ceb-43e1-8c91-a2c21b167d79"],
Cell[CellGroupData[{
Cell[139874, 3965, 690, 15, 28, "Input",ExpressionUUID->"2acc072e-f264-4044-b510-134efc00991d"],
Cell[140567, 3982, 603, 9, 32, "Output",ExpressionUUID->"eb83e7e2-78f8-4f32-b48d-0b1bfbd4c43c"]
}, Open  ]],
Cell[141185, 3994, 600, 15, 28, "Input",ExpressionUUID->"474f81c6-a9d3-410d-a9ed-d1f5fa0b7b09"],
Cell[141788, 4011, 294, 6, 31, "Item",ExpressionUUID->"25b3188c-ae6d-48e6-a6d0-0b591fb05d8d"],
Cell[142085, 4019, 306, 8, 28, "Input",ExpressionUUID->"d4be9464-2a93-4256-aeab-e5937eb22d70"],
Cell[142394, 4029, 309, 7, 28, "Input",ExpressionUUID->"0f2a77c2-53ea-4dd1-85ae-2dc78b01ab45"],
Cell[CellGroupData[{
Cell[142728, 4040, 708, 17, 28, "Input",ExpressionUUID->"284fda3d-ed29-4309-8ff1-d434b8468357"],
Cell[143439, 4059, 543, 9, 32, "Output",ExpressionUUID->"278a731b-b9be-4445-9689-c821efb6abe0"]
}, Open  ]],
Cell[143997, 4071, 255, 6, 28, "Input",ExpressionUUID->"d303490d-5c9d-44ae-864e-720faef2e9ee"],
Cell[CellGroupData[{
Cell[144277, 4081, 683, 17, 28, "Input",ExpressionUUID->"0269f3ce-a9fe-4e50-b18a-1f0358fefc5b"],
Cell[144963, 4100, 516, 9, 32, "Output",ExpressionUUID->"b3a566e2-54bc-44be-b2d8-b5776e3b947f"]
}, Open  ]],
Cell[145494, 4112, 256, 6, 28, "Input",ExpressionUUID->"e3531ee6-d57e-4925-8f45-3d4ae549cfe4"],
Cell[CellGroupData[{
Cell[145775, 4122, 633, 16, 28, "Input",ExpressionUUID->"4d58b6fa-17d2-422d-b9b1-d80948ec8314"],
Cell[146411, 4140, 434, 8, 32, "Output",ExpressionUUID->"1d7f403b-def8-4aa8-9fb1-02b6762213db"]
}, Open  ]],
Cell[146860, 4151, 255, 6, 28, "Input",ExpressionUUID->"3949713b-f8d5-4433-9b0a-6a496ca9cede"],
Cell[CellGroupData[{
Cell[147140, 4161, 606, 16, 28, "Input",ExpressionUUID->"a52a954c-fdba-4b31-8cac-ef0b3d51a94f"],
Cell[147749, 4179, 439, 8, 32, "Output",ExpressionUUID->"01b46301-1259-4e85-9f06-3f3b8144ce52"]
}, Open  ]],
Cell[148203, 4190, 444, 11, 28, "Input",ExpressionUUID->"ee346067-02e0-42dc-babb-f40a0eb94f2d"],
Cell[CellGroupData[{
Cell[148672, 4205, 1043, 24, 28, "Input",ExpressionUUID->"6b145bc4-29f9-4faf-9ef3-6f4edf41f1db"],
Cell[149718, 4231, 644, 13, 32, "Output",ExpressionUUID->"1ae5ae77-475d-47f4-97c0-ac3874871cc7"]
}, Open  ]],
Cell[150377, 4247, 237, 5, 28, "Input",ExpressionUUID->"acd2a6bd-463a-42ec-aa19-c78dc252ecef"],
Cell[150617, 4254, 257, 6, 28, "Input",ExpressionUUID->"5b35d1d3-2de1-4991-b7a3-dcbcc50c28e7"],
Cell[CellGroupData[{
Cell[150899, 4264, 675, 17, 28, "Input",ExpressionUUID->"8db0e3bd-0ac0-42cc-8cd2-1b8d82990a76"],
Cell[151577, 4283, 521, 9, 32, "Output",ExpressionUUID->"676f3784-6a17-468b-9d99-a50972cfa79f"]
}, Open  ]],
Cell[152113, 4295, 311, 7, 28, "Input",ExpressionUUID->"a3e52c3e-a179-4a5b-95c9-730e2ce32455"],
Cell[CellGroupData[{
Cell[152449, 4306, 637, 16, 28, "Input",ExpressionUUID->"f464fdff-7fdb-482e-951c-5b68e0fae34d"],
Cell[153089, 4324, 435, 8, 32, "Output",ExpressionUUID->"d6172909-5379-4e7c-a06b-a005bcc4c828"]
}, Open  ]],
Cell[153539, 4335, 308, 7, 28, "Input",ExpressionUUID->"3ebeaad2-d0f0-4ec7-b54e-7a93517ff7cf"],
Cell[CellGroupData[{
Cell[153872, 4346, 1039, 25, 28, "Input",ExpressionUUID->"73eed31d-bb78-4233-bdfe-9d399a1e9b06"],
Cell[154914, 4373, 695, 17, 32, "Output",ExpressionUUID->"ba138da5-b03a-44e0-84f7-aa8e94a4fad1"]
}, Open  ]],
Cell[155624, 4393, 233, 5, 28, "Input",ExpressionUUID->"8fe333df-ad0c-442e-abe9-b6010c7452d6"],
Cell[155860, 4400, 258, 6, 28, "Input",ExpressionUUID->"b9f5c125-e834-4754-ba9f-89e4c42f95cc"],
Cell[CellGroupData[{
Cell[156143, 4410, 744, 18, 28, "Input",ExpressionUUID->"faa689ee-58bf-423b-a41c-235a83e2fa0b"],
Cell[156890, 4430, 613, 15, 32, "Output",ExpressionUUID->"02a7b89b-7aaf-44f1-8c66-f0d645844339"]
}, Open  ]],
Cell[157518, 4448, 237, 5, 28, "Input",ExpressionUUID->"ad70fe85-097a-40f6-9990-c0a545431176"],
Cell[157758, 4455, 689, 15, 28, "Input",ExpressionUUID->"43aa664c-2ed9-40ed-8b65-d0a5a8a13c36"],
Cell[158450, 4472, 159, 3, 31, "Item",ExpressionUUID->"58f35464-6d41-4c2b-bc4f-19a243a9716b"],
Cell[158612, 4477, 289, 7, 28, "Input",ExpressionUUID->"12290bc7-3712-4eeb-b372-023c53f4cee5"],
Cell[CellGroupData[{
Cell[158926, 4488, 437, 11, 28, "Input",ExpressionUUID->"58315453-adfe-47d0-a083-143e3d32a629"],
Cell[159366, 4501, 1010, 30, 36, "Output",ExpressionUUID->"7e743743-cb9d-432e-be6a-7c142ba3fec9"]
}, Open  ]],
Cell[160391, 4534, 256, 6, 28, "Input",ExpressionUUID->"e6166c77-8745-431b-86fe-f57d76012346"],
Cell[160650, 4542, 411, 9, 28, "Input",ExpressionUUID->"7c6bb948-2eee-421f-bfc4-b41208639945"],
Cell[CellGroupData[{
Cell[161086, 4555, 603, 13, 28, "Input",ExpressionUUID->"4ef3603f-4753-4d52-bbba-0e5c013caf56"],
Cell[161692, 4570, 1161, 28, 60, "Output",ExpressionUUID->"55ab99fc-43b2-4026-8cc8-f1656dd8314b"]
}, Open  ]],
Cell[162868, 4601, 233, 5, 28, "Input",ExpressionUUID->"76cef099-002e-4b67-a712-1734b99ff8d8"],
Cell[CellGroupData[{
Cell[163126, 4610, 344, 8, 28, "Input",ExpressionUUID->"73d64ccb-f95b-45b1-b69c-319f1840b2b2"],
Cell[163473, 4620, 379, 7, 32, "Output",ExpressionUUID->"d0a93727-595a-43ff-b532-c5b4c174fd87"]
}, Open  ]],
Cell[163867, 4630, 328, 7, 28, "Input",ExpressionUUID->"34cfde63-cf76-4a58-99ac-a1201f34818f"],
Cell[CellGroupData[{
Cell[164220, 4641, 571, 12, 28, "Input",ExpressionUUID->"44483e94-29e8-45bc-8bec-b2751a1d86a6"],
Cell[164794, 4655, 631, 9, 32, "Output",ExpressionUUID->"0f6ace6a-d73f-428c-875a-a1060ffd8c49"]
}, Open  ]],
Cell[CellGroupData[{
Cell[165462, 4669, 383, 8, 28, "Input",ExpressionUUID->"c5e27224-32b1-47b7-b7ac-19be4b8bf5aa"],
Cell[165848, 4679, 583, 9, 32, "Output",ExpressionUUID->"bc4bea8b-755e-4b8f-8613-830d1ff4beab"]
}, Open  ]],
Cell[CellGroupData[{
Cell[166468, 4693, 214, 4, 31, "Item",ExpressionUUID->"d6d93089-aa83-4473-b0f9-97284af3384a"],
Cell[166685, 4699, 287, 5, 31, "Item",ExpressionUUID->"48a8af9d-b249-4d77-b151-38d041bed4bc"]
}, Open  ]],
Cell[166987, 4707, 754, 17, 28, "Input",ExpressionUUID->"acc14d0b-ad3b-4c51-a507-ededbc721e4a"],
Cell[CellGroupData[{
Cell[167766, 4728, 776, 16, 28, "Input",ExpressionUUID->"00a82675-7090-478e-876e-d7fdd0a9e75f"],
Cell[168545, 4746, 734, 11, 32, "Output",ExpressionUUID->"c40eadf9-6996-46fe-8865-542386f072b0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[169316, 4762, 980, 19, 28, "Input",ExpressionUUID->"384d2caa-d1b0-4074-a98c-3c097787984f"],
Cell[170299, 4783, 1389, 32, 52, "Output",ExpressionUUID->"d5e8e8aa-8ec1-41fc-ab94-11dcd54c2b97"]
}, Open  ]],
Cell[171703, 4818, 239, 5, 28, "Input",ExpressionUUID->"2137ff33-c735-4b60-9170-2aea39190d44"],
Cell[171945, 4825, 1153, 28, 48, "Input",ExpressionUUID->"7ce9de8a-47e7-411a-9677-37456e7c092d"],
Cell[173101, 4855, 1050, 27, 67, "Input",ExpressionUUID->"9e370b45-79bd-4a0b-9bce-80a7cd53a9a1"],
Cell[174154, 4884, 405, 10, 28, "Input",ExpressionUUID->"183cf63d-15d1-4477-9a3d-3672acd847d0"],
Cell[CellGroupData[{
Cell[174584, 4898, 523, 12, 28, "Input",ExpressionUUID->"35ff71a9-ad94-4a96-be1d-fc5f9dc166c5"],
Cell[175110, 4912, 422, 7, 32, "Output",ExpressionUUID->"c4119b02-5750-4b99-8390-3330bb1acbcc"]
}, Open  ]],
Cell[175547, 4922, 474, 11, 28, "Input",ExpressionUUID->"8b0c5c1d-a4e9-456b-969c-35c901371303"],
Cell[CellGroupData[{
Cell[176046, 4937, 843, 18, 28, "Input",ExpressionUUID->"4cce0a16-9921-42c0-b279-746ef4c1819d"],
Cell[176892, 4957, 577, 9, 32, "Output",ExpressionUUID->"c736d3ed-4015-4eaf-b6b7-717e894a7bf9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[177506, 4971, 571, 15, 28, "Input",ExpressionUUID->"fa24f395-03f1-4d1b-b744-ccc5205a145c"],
Cell[178080, 4988, 229, 4, 32, "Output",ExpressionUUID->"5bb4ec20-ab16-499b-9127-bdb937326790"]
}, Open  ]],
Cell[178324, 4995, 233, 5, 28, "Input",ExpressionUUID->"61d970d6-e5d0-42e5-88ea-6c89ab9f7849"],
Cell[178560, 5002, 179, 4, 28, "Input",ExpressionUUID->"83303b85-9335-4308-ac9a-dffff72f54f5"],
Cell[178742, 5008, 638, 16, 28, "Input",ExpressionUUID->"e6eda3e8-5554-441b-8642-80020412faf1"],
Cell[CellGroupData[{
Cell[179405, 5028, 678, 15, 28, "Input",ExpressionUUID->"4f98869f-f8a8-4d50-8dd2-5d1fc0612df9"],
Cell[180086, 5045, 622, 9, 32, "Output",ExpressionUUID->"0cac3f77-10fc-4205-a864-0805d1de67ff"]
}, Open  ]],
Cell[CellGroupData[{
Cell[180745, 5059, 690, 15, 28, "Input",ExpressionUUID->"1ba2bed2-9086-4285-bd14-2036c4824af7"],
Cell[181438, 5076, 667, 12, 32, "Output",ExpressionUUID->"f0da6dd2-7cb9-43f5-849e-e9129a8f78ba"]
}, Open  ]],
Cell[CellGroupData[{
Cell[182142, 5093, 664, 15, 28, "Input",ExpressionUUID->"f4336064-565a-4e07-b4bc-753ea2c2edda"],
Cell[182809, 5110, 1123, 31, 36, "Output",ExpressionUUID->"b7a1ee64-0eaf-457c-8aac-9f30578cd6ea"]
}, Open  ]],
Cell[183947, 5144, 239, 5, 28, "Input",ExpressionUUID->"5dfa3757-82b0-43cb-83e4-66133e456ec1"],
Cell[184189, 5151, 1274, 32, 67, "Input",ExpressionUUID->"9b329f2e-c081-4729-9d98-d13c1b7e42c4"],
Cell[185466, 5185, 1296, 33, 67, "Input",ExpressionUUID->"9b2db124-c303-4dc5-8d39-6ffceb681f4f"],
Cell[186765, 5220, 1350, 34, 67, "Input",ExpressionUUID->"aa8233bc-57e6-4bb0-afc3-951087219b65"],
Cell[188118, 5256, 385, 8, 28, "Input",ExpressionUUID->"87d69a7f-e2a6-480a-b134-ca22933ef172"],
Cell[CellGroupData[{
Cell[188528, 5268, 766, 16, 28, "Input",ExpressionUUID->"0371ae6b-93d7-46c5-bf04-cf2a247b5324"],
Cell[189297, 5286, 583, 10, 32, "Output",ExpressionUUID->"6ac2e017-2455-4e11-959e-5b42a7299fd3"]
}, Open  ]],
Cell[189895, 5299, 387, 8, 28, "Input",ExpressionUUID->"d127919e-2224-4fc6-850d-0375ceff2d3b"],
Cell[CellGroupData[{
Cell[190307, 5311, 747, 16, 28, "Input",ExpressionUUID->"d389b1ec-8714-4ebb-93b9-4d2964b10913"],
Cell[191057, 5329, 683, 14, 32, "Output",ExpressionUUID->"fe1b4f10-cb1f-40ac-8b1e-02fabe07f0d8"]
}, Open  ]],
Cell[191755, 5346, 303, 7, 28, "Input",ExpressionUUID->"31b72f86-0b4f-45bf-80c5-cede12e7c86c"],
Cell[CellGroupData[{
Cell[192083, 5357, 719, 15, 28, "Input",ExpressionUUID->"ee019bc1-6160-41eb-b958-43d0d43c0edc"],
Cell[192805, 5374, 491, 11, 32, "Output",ExpressionUUID->"63b00453-ea42-454f-803f-922906ac0bb5"]
}, Open  ]],
Cell[193311, 5388, 106, 1, 28, "Input",ExpressionUUID->"78550ac3-5b41-456a-92bd-232557428933"],
Cell[193420, 5391, 601, 15, 28, "Input",ExpressionUUID->"f6de49d8-b43e-415c-8c61-f1d3240421e2"],
Cell[CellGroupData[{
Cell[194046, 5410, 658, 15, 28, "Input",ExpressionUUID->"b7b2f29d-8c84-4d05-898b-2a46415214a2"],
Cell[194707, 5427, 614, 9, 32, "Output",ExpressionUUID->"1632d9f2-5c43-4424-8c3f-2ef315bf7409"]
}, Open  ]],
Cell[CellGroupData[{
Cell[195358, 5441, 630, 14, 28, "Input",ExpressionUUID->"6de332b1-2f26-46ce-a262-4213ca86f382"],
Cell[195991, 5457, 1092, 27, 36, "Output",ExpressionUUID->"17cd57bd-0122-4195-be7a-db5baff8491b"]
}, Open  ]],
Cell[197098, 5487, 168, 3, 28, "Input",ExpressionUUID->"c7f66f77-094f-496d-81a8-9b3a505f6d2b"],
Cell[197269, 5492, 1048, 27, 48, "Input",ExpressionUUID->"e075ce31-7b34-46af-96ba-a0d4f2d65cdc"],
Cell[198320, 5521, 1051, 27, 48, "Input",ExpressionUUID->"0379f88f-9c26-4231-b110-627df5833b7e"],
Cell[199374, 5550, 301, 7, 28, "Input",ExpressionUUID->"9276c5c3-57de-40bc-a948-1221990d4417"],
Cell[CellGroupData[{
Cell[199700, 5561, 636, 14, 28, "Input",ExpressionUUID->"112abea3-89b2-4f44-90ec-d231cac771e7"],
Cell[200339, 5577, 463, 10, 32, "Output",ExpressionUUID->"741458cd-996a-45da-a2da-ab6b800cee85"]
}, Open  ]],
Cell[200817, 5590, 289, 5, 31, "Item",ExpressionUUID->"7d1df804-e7a3-4614-b0d2-bab225c4e017"],
Cell[201109, 5597, 609, 15, 28, "Input",ExpressionUUID->"66c4db27-e6d3-4448-a150-f264649ce561"],
Cell[CellGroupData[{
Cell[201743, 5616, 777, 16, 28, "Input",ExpressionUUID->"04f63cb6-86a0-482f-92ad-60d4565b57b6"],
Cell[202523, 5634, 1199, 33, 32, "Output",ExpressionUUID->"35d429e9-3877-4b6f-97c9-7724a1520971"]
}, Open  ]],
Cell[CellGroupData[{
Cell[203759, 5672, 722, 15, 28, "Input",ExpressionUUID->"8745c497-ec69-493b-8dea-5b9490838ef8"],
Cell[204484, 5689, 1190, 30, 52, "Output",ExpressionUUID->"4327832c-5667-4939-b51f-835335c0f0e7"]
}, Open  ]],
Cell[205689, 5722, 480, 11, 28, "Input",ExpressionUUID->"08b08e1e-57b4-4ef0-b354-3fb60d2465bb"],
Cell[206172, 5735, 239, 5, 28, "Input",ExpressionUUID->"72ad1318-d91a-497d-a327-eba163e212e3"],
Cell[206414, 5742, 1102, 28, 67, "Input",ExpressionUUID->"3f29aad0-aadd-44c5-b6e0-77a9715976e7"],
Cell[207519, 5772, 1173, 29, 67, "Input",ExpressionUUID->"c0533c33-6bac-445f-9350-c7b3fcc293a7"],
Cell[208695, 5803, 1208, 29, 67, "Input",ExpressionUUID->"492fb126-4415-4c2e-b457-c611bcc6589c"],
Cell[209906, 5834, 301, 7, 28, "Input",ExpressionUUID->"7f81ee38-29f9-4f77-89fe-a5decf234392"],
Cell[CellGroupData[{
Cell[210232, 5845, 575, 13, 28, "Input",ExpressionUUID->"ee2250de-b4ae-4c2b-a27d-597d637a2360"],
Cell[210810, 5860, 427, 7, 32, "Output",ExpressionUUID->"d04cd59c-e259-4bf0-9b7b-9479c5f4f7f3"]
}, Open  ]],
Cell[211252, 5870, 301, 7, 28, "Input",ExpressionUUID->"ae877cea-7996-44b3-9138-857eac9359b2"],
Cell[CellGroupData[{
Cell[211578, 5881, 634, 14, 28, "Input",ExpressionUUID->"b5dd1f8a-bc0b-4d6f-a868-f5b9c2dcc2bc"],
Cell[212215, 5897, 306, 5, 32, "Output",ExpressionUUID->"2527158b-e12c-405d-9e3b-dc5d1b36a18f"]
}, Open  ]],
Cell[212536, 5905, 179, 4, 28, "Input",ExpressionUUID->"1ac04e55-d637-491a-a5ae-6fd039027f46"],
Cell[212718, 5911, 577, 14, 28, "Input",ExpressionUUID->"1323af8b-f289-485f-8a93-bcc3e3816172"],
Cell[CellGroupData[{
Cell[213320, 5929, 776, 17, 28, "Input",ExpressionUUID->"6734b9b4-87dd-4628-983c-83c9c5ae624d"],
Cell[214099, 5948, 1228, 32, 36, "Output",ExpressionUUID->"dfe77a77-20b2-44a3-b798-8a9b79a3a93b"]
}, Open  ]],
Cell[215342, 5983, 246, 6, 28, "Input",ExpressionUUID->"04d6e626-a8a0-444a-b91a-6d51016b3597"],
Cell[215591, 5991, 808, 21, 28, "Input",ExpressionUUID->"d85f2ac3-319c-4c2c-bda5-130b1b73c841"],
Cell[216402, 6014, 806, 21, 28, "Input",ExpressionUUID->"bda86138-afde-4715-81ad-802868f1306f"],
Cell[217211, 6037, 303, 7, 28, "Input",ExpressionUUID->"19cf8043-5025-40e5-9709-24d331eddd1c"],
Cell[CellGroupData[{
Cell[217539, 6048, 675, 15, 28, "Input",ExpressionUUID->"729549d1-25b8-4a2f-aca3-e97003a3f40c"],
Cell[218217, 6065, 333, 6, 32, "Output",ExpressionUUID->"c409b845-8b22-42bb-8f57-8bdb1ff7c076"]
}, Open  ]],
Cell[218565, 6074, 106, 1, 28, "Input",ExpressionUUID->"19224acd-b770-4b35-9141-c83e0a37a2d4"],
Cell[218674, 6077, 644, 16, 28, "Input",ExpressionUUID->"dd01d159-1e07-47ea-a349-04da4a3b1fd0"],
Cell[CellGroupData[{
Cell[219343, 6097, 715, 16, 28, "Input",ExpressionUUID->"cb4023a0-e752-4181-9446-fe3cfe633231"],
Cell[220061, 6115, 1248, 34, 32, "Output",ExpressionUUID->"ee811822-0144-44a7-981e-09c73b9a8b1e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[221346, 6154, 691, 16, 28, "Input",ExpressionUUID->"057352ac-3fcf-4a6c-a276-c3cb722fbd1f"],
Cell[222040, 6172, 1040, 26, 36, "Output",ExpressionUUID->"fda0241b-dbf2-4118-ae00-73004981f657"]
}, Open  ]],
Cell[223095, 6201, 461, 8, 28, "Input",ExpressionUUID->"4b683972-b59c-4f70-98f7-640f147bd4e7"],
Cell[223559, 6211, 284, 5, 28, "Input",ExpressionUUID->"5a27ab1c-d34c-423a-b034-86f87b695d7d"],
Cell[223846, 6218, 1048, 27, 48, "Input",ExpressionUUID->"b5de5c71-2201-4f1e-bf6b-36a9d0dc351c"],
Cell[224897, 6247, 1050, 27, 48, "Input",ExpressionUUID->"06e69a27-4e31-467c-b4b3-2ddb5b84a17d"],
Cell[225950, 6276, 1046, 27, 48, "Input",ExpressionUUID->"0c8c00cc-3067-4ee8-abe8-6646b3a62c85"],
Cell[226999, 6305, 305, 7, 28, "Input",ExpressionUUID->"c96690ce-a5b7-4944-bffd-726405c756c9"],
Cell[CellGroupData[{
Cell[227329, 6316, 721, 16, 28, "Input",ExpressionUUID->"e635c153-7fa7-4817-8fc2-0ba6c9eb22f7"],
Cell[228053, 6334, 484, 11, 32, "Output",ExpressionUUID->"df1743d4-eb0f-433b-9c39-5ca756edd27b"]
}, Open  ]],
Cell[228552, 6348, 554, 13, 28, "Input",ExpressionUUID->"8db99c3a-ac7c-4dc6-9ef3-5eb35c4de1ff"]
}
]
*)

